@@ -23,17 +23,17 @@
  *
  */
 
-
 #ifndef _AUTOMATION_EDITOR_H
 #define _AUTOMATION_EDITOR_H
 
+#include <QtCore/QMutex>
 #include <QtGui/QWidget>
 
 #include "lmms_basics.h"
-#include "journalling_object.h"
+#include "JournallingObject.h"
 #include "midi_time.h"
 #include "automation_pattern.h"
-#include "combobox_model.h"
+#include "ComboBoxModel.h"
 
 
 class QPainter;
@@ -46,35 +46,36 @@ class timeLine;
 class toolButton;
 
 
-class automationEditor : public QWidget, public journallingObject
+class automationEditor : public QWidget, public JournallingObject
 {
 	Q_OBJECT
 public:
 	void setCurrentPattern( automationPattern * _new_pattern );
 
-	inline const automationPattern * currentPattern( void ) const
+	inline const automationPattern * currentPattern() const
 	{
 		return( m_pattern );
 	}
 
-	inline bool validPattern( void ) const
+	inline bool validPattern() const
 	{
 		return( m_pattern != NULL );
 	}
 
-	int quantization( void ) const;
+	int quantization() const;
 
 
 	virtual void saveSettings( QDomDocument & _doc, QDomElement & _parent );
 	virtual void loadSettings( const QDomElement & _this );
-	inline virtual QString nodeName( void ) const
+	inline virtual QString nodeName() const
 	{
 		return( "automationeditor" );
 	}
 
 
 public slots:
-	void update( void );
+	void update();
+	void updateAfterPatternChange();
 
 
 protected:
@@ -94,33 +95,33 @@ protected:
 	static inline void drawValueRect( QPainter & _p, int _x, int _y,
 						int _width, int _height,
 						const bool _is_selected );
-	void removeSelection( void );
-	void selectAll( void );
+	void removeSelection();
+	void selectAll();
 	void getSelectedValues( timeMap & _selected_values );
 
 	void drawLine( int x0, float y0, int x1, float y1 );
 
 protected slots:
-	void play( void );
-	void stop( void );
+	void play();
+	void stop();
 
 	void horScrolled( int _new_pos );
 	void verScrolled( int _new_pos );
 
-	void drawButtonToggled( void );
-	void eraseButtonToggled( void );
-	void selectButtonToggled( void );
-	void moveButtonToggled( void );
+	void drawButtonToggled();
+	void eraseButtonToggled();
+	void selectButtonToggled();
+	void moveButtonToggled();
 
-	void copySelectedValues( void );
-	void cutSelectedValues( void );
-	void pasteValues( void );
-	void deleteSelectedValues( void );
+	void copySelectedValues();
+	void cutSelectedValues();
+	void pasteValues();
+	void deleteSelectedValues();
 
 	void updatePosition( const midiTime & _t );
 
-	void zoomingXChanged( void );
-	void zoomingYChanged( void );
+	void zoomingXChanged();
+	void zoomingYChanged();
 
 
 private:
@@ -154,7 +155,7 @@ private:
 
 	static const int VALUES_WIDTH = 64;
 
-	automationEditor( void );
+	automationEditor();
 	automationEditor( const automationEditor & );
 	virtual ~automationEditor();
 
@@ -183,10 +184,11 @@ private:
 	comboBox * m_zoomingYComboBox;
 	comboBox * m_quantizeComboBox;
 
-	comboBoxModel m_zoomingXModel;
-	comboBoxModel m_zoomingYModel;
-	comboBoxModel m_quantizeModel;
+	ComboBoxModel m_zoomingXModel;
+	ComboBoxModel m_zoomingYModel;
+	ComboBoxModel m_quantizeModel;
 
+	QMutex m_patternMutex;
 	automationPattern * m_pattern;
 	float m_minLevel;
 	float m_maxLevel;
@@ -195,7 +197,7 @@ private:
 	float m_bottomLevel;
 	float m_topLevel;
 
-	void updateTopBottomLevels( void );
+	void updateTopBottomLevels();
 
 	QScrollBar * m_leftRightScroll;
 	QScrollBar * m_topBottomScroll;
@@ -231,7 +233,7 @@ private:
 	bool m_scrollBack;
 
 	void drawCross( QPainter & _p );
-	bool inBBEditor( void );
+	bool inBBEditor();
 
 
 
@@ -239,6 +241,7 @@ private:
 
 
 signals:
+	void currentPatternChanged();
 	void positionChanged( const midiTime & );
 
 } ;
