@@ -1,7 +1,7 @@
 /*
  * led_checkbox.h - class ledCheckBox, an improved QCheckBox
  *
- * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -32,22 +32,25 @@
 class QPixmap;
 
 
-class ledCheckBox : public automatableButton
+class EXPORT ledCheckBox : public automatableButton
 {
 	Q_OBJECT
 public:
-	enum ledColors
+	enum LedColors
 	{
-		YELLOW, GREEN, TOTAL_COLORS
+		Yellow,
+		Green,
+		Red,
+		NumColors
 	} ;
 
 	ledCheckBox( const QString & _txt, QWidget * _parent,
-				const QString & _name, engine * _engine,
-				track * _track, ledColors _color = YELLOW );
+				const QString & _name = QString::null,
+						LedColors _color = Yellow );
 	virtual ~ledCheckBox();
 
 
-	inline const QString & text( void )
+	inline const QString & text()
 	{
 		return( m_text );
 	}
