@@ -2,7 +2,7 @@
  * piano_roll.h - declaration of class pianoRoll which is a window where you
  *                can set and edit notes in an easy way
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * Copyright (c) 2008 Andrew Kelley <superjoe30/at/gmail/dot/com>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
@@ -30,10 +30,11 @@
 
 #include <QtGui/QWidget>
 
-#include "combobox_model.h"
-#include "serializing_object.h"
+#include "ComboBoxModel.h"
+#include "SerializingObject.h"
 #include "note.h"
 #include "lmms_basics.h"
+#include "song.h"
 
 
 class QPainter;
@@ -50,34 +51,41 @@ class timeLine;
 class toolButton;
 
 
-class pianoRoll : public QWidget, public serializingObject
+class pianoRoll : public QWidget, public SerializingObject
 {
 	Q_OBJECT
 public:
 	void setCurrentPattern( pattern * _new_pattern );
 
-	inline bool isRecording( void ) const
+	inline void stopRecording()
+	{
+		m_recording = false;
+	}
+
+	inline bool isRecording() const
 	{
 		return m_recording;
 	}
 
-	inline const pattern * currentPattern( void ) const
+	inline const pattern * currentPattern() const
 	{
 		return m_pattern;
 	}
 
-	inline bool validPattern( void ) const
+	inline bool validPattern() const
 	{
 		return m_pattern != NULL;
 	}
 
-	int quantization( void ) const;
+	song::PlayModes desiredPlayModeForAccompany() const;
+
+	int quantization() const;
 
 
 	virtual void saveSettings( QDomDocument & _doc, QDomElement & _parent );
 	virtual void loadSettings( const QDomElement & _this );
 
-	inline virtual QString nodeName( void ) const
+	inline virtual QString nodeName() const
 	{
 		return "pianoroll";
 	}
@@ -99,36 +107,38 @@ protected:
 	int getKey( int _y ) const;
 	static inline void drawNoteRect( QPainter & _p, int _x, int _y,
 					int  _width, note * _n );
-	void removeSelection( void );
-	void selectAll( void );
-	void getSelectedNotes( noteVector & _selected_notes );
+	void removeSelection();
+	void selectAll();
+	void getSelectedNotes( NoteVector & _selected_notes );
 
 
 protected slots:
-	void play( void );
-	void record( void );
-	void recordAccompany( void );
-	void stop( void );
+	void play();
+	void record();
+	void recordAccompany();
+	void stop();
 
-	void recordNote( const note & _n );
+	void startRecordNote( const note & _n );
+	void finishRecordNote( const note & _n );
 
 	void horScrolled( int _new_pos );
 	void verScrolled( int _new_pos );
 
-	void drawButtonToggled( void );
-	void eraseButtonToggled( void );
-	void selectButtonToggled( void );
-	void detuneButtonToggled( void );
+	void drawButtonToggled();
+	void eraseButtonToggled();
+	void selectButtonToggled();
+	void detuneButtonToggled();
 
-	void copySelectedNotes( void );
-	void cutSelectedNotes( void );
-	void pasteNotes( void );
-	void deleteSelectedNotes( void );
+	void copySelectedNotes();
+	void cutSelectedNotes();
+	void pasteNotes();
+	void deleteSelectedNotes();
 
 	void updatePosition( const midiTime & _t );
+	void updatePositionAccompany( const midiTime & _t );
 
-	void zoomingChanged( void );
-	void quantizeChanged( void );
+	void zoomingChanged();
+	void quantizeChanged();
 		
 	void changeNoteEditMode( int i );
 
@@ -140,7 +150,7 @@ private:
 		ModeDraw,
 		ModeErase,
 		ModeSelect,
-		ModeOpen
+		ModeEditDetuning,
 	};
 
 	enum actions
@@ -171,11 +181,13 @@ private:
 	QMenu * m_noteEditMenu; // when you right click below the key area
 	QSignalMapper * m_signalMapper; // to keep track of edit mode events
 
-	pianoRoll( void );
+	pianoRoll();
 	pianoRoll( const pianoRoll & );
 	virtual ~pianoRoll();
 
-	midiTime newNoteLen( void ) const;
+	void autoScroll( const midiTime & _t );
+
+	midiTime newNoteLen() const;
 	
 	void shiftPos(int amount);
 	void shiftSemiTone(int amount);
@@ -229,9 +241,9 @@ private:
 	comboBox * m_quantizeComboBox;
 	comboBox * m_noteLenComboBox;
 
-	comboBoxModel m_zoomingModel;
-	comboBoxModel m_quantizeModel;
-	comboBoxModel m_noteLenModel;
+	ComboBoxModel m_zoomingModel;
+	ComboBoxModel m_quantizeModel;
+	ComboBoxModel m_noteLenModel;
 
 
 
@@ -241,6 +253,7 @@ private:
 
 	midiTime m_currentPosition;
 	bool m_recording;
+	QList<note> m_recordingNotes;
 
 	note * m_currentNote;
 	actions m_action;
@@ -278,8 +291,8 @@ private:
 	// remember these values to use them 
 	// for the next note that is set
 	midiTime m_lenOfNewNotes;
-	volume m_lastNoteVolume;
-	panning m_lastNotePanning;
+	volume_t m_lastNoteVolume;
+	panning_t m_lastNotePanning;
 
 	int m_startKey;			// first key when drawing
 	int m_lastKey;
@@ -293,16 +306,15 @@ private:
 	timeLine * m_timeLine;
 	bool m_scrollBack;
 
-	void copy_to_clipboard( const noteVector & _notes ) const;
+	void copy_to_clipboard( const NoteVector & _notes ) const;
 
 	void drawDetuningInfo( QPainter & _p, note * _n, int _x, int _y );
-	bool mouseOverNote( void );
-	note * noteUnderMouse( void );
-	noteVector::const_iterator noteIteratorUnderMouse( void );
-	
+	bool mouseOverNote();
+	note * noteUnderMouse();
+
 	// turn a selection rectangle into selected notes
 	void computeSelectedNotes( bool shift ); 
-	void clearSelectedNotes( void );
+	void clearSelectedNotes();
 
 	friend class engine;
 
