@@ -2,8 +2,8 @@
  * sample_track.h - class sampleTrack, a track which provides arrangement of
  *                  samples
  *
- * Copyright (c) 2005-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
- * 
+ * Copyright (c) 2005-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or
@@ -23,16 +23,15 @@
  *
  */
 
-
 #ifndef _SAMPLE_TRACK_H
 #define _SAMPLE_TRACK_H
 
 #include <QtGui/QDialog>
 
-#include "audio_port.h"
+#include "AudioPort.h"
 #include "track.h"
 
-class effectRackView;
+class EffectRackView;
 class knob;
 class sampleBuffer;
 
@@ -46,21 +45,21 @@ public:
 	virtual ~sampleTCO();
 
 	virtual void changeLength( const midiTime & _length );
-	const QString & sampleFile( void ) const;
+	const QString & sampleFile() const;
 
 	virtual void saveSettings( QDomDocument & _doc, QDomElement & _parent );
 	virtual void loadSettings( const QDomElement & _this );
-	inline virtual QString nodeName( void ) const
+	inline virtual QString nodeName() const
 	{
-		return( "sampletco" );
+		return "sampletco";
 	}
 
-	sampleBuffer * getSampleBuffer( void )
+	sampleBuffer * getSampleBuffer()
 	{
-		return( m_sampleBuffer );
+		return m_sampleBuffer;
 	}
 
-	midiTime sampleLength( void ) const;
+	midiTime sampleLength() const;
 
 	virtual trackContentObjectView * createView( trackView * _tv );
 
@@ -69,19 +68,19 @@ public slots:
 	void setSampleBuffer( sampleBuffer * _sb );
 	void setSampleFile( const QString & _sf );
 	void updateLength( bpm_t = 0 );
-	void toggleRecord( void );
+	void toggleRecord();
 
 
 private:
 	sampleBuffer * m_sampleBuffer;
-	boolModel m_recordModel;
+	BoolModel m_recordModel;
 
 
 	friend class sampleTCOView;
 
 
 signals:
-	void sampleChanged( void );
+	void sampleChanged();
 
 } ;
 
@@ -96,7 +95,7 @@ public:
 
 
 public slots:
-	void updateSample( void );
+	void updateSample();
 
 
 protected:
@@ -134,20 +133,20 @@ public:
 							QDomElement & _parent );
 	virtual void loadTrackSpecificSettings( const QDomElement & _this );
 
-	inline audioPort * getAudioPort( void )
+	inline AudioPort * audioPort()
 	{
-		return( &m_audioPort );
+		return &m_audioPort;
 	}
 
-	virtual QString nodeName( void ) const
+	virtual QString nodeName() const
 	{
-		return( "sampletrack" );
+		return "sampletrack";
 	}
 
 
 private:
-	audioPort m_audioPort;
-	floatModel m_volumeModel;
+	AudioPort m_audioPort;
+	FloatModel m_volumeModel;
 
 
 	friend class sampleTrackView;
@@ -165,11 +164,11 @@ public:
 
 
 public slots:
-	void showEffects( void );
+	void showEffects();
 
 
 private:
-	effectRackView * m_effectRack;
+	EffectRackView * m_effectRack;
 	QWidget * m_effWindow;
 	knob * m_volumeKnob;
 
