@@ -30,7 +30,7 @@
 
 #include <QtGui/QWidget>
 
-#include "automatable_model.h"
+#include "AutomatableModel.h"
 #include "mixer.h"
 
 
@@ -41,14 +41,14 @@ class knob;
 const int SURROUND_AREA_SIZE = 1024;
 
 
-class surroundAreaModel : public model
+class surroundAreaModel : public Model
 {
 	Q_OBJECT
 	mapPropertyFromModel(int,x,setX,m_posX);
 	mapPropertyFromModel(int,y,setY,m_posY);
 public:
-	surroundAreaModel( ::model * _parent,
-					bool _default_constructed = FALSE );
+	surroundAreaModel( Model * _parent,
+					bool _default_constructed = false );
 
 	surroundVolumeVector getVolumeVector( float _v_scale ) const;
 
@@ -57,31 +57,31 @@ public:
 	void loadSettings( const QDomElement & _this,
 					const QString & _name = "surpos" );
 
-	inline void prepareJournalEntryFromOldVal( void )
+	inline void prepareJournalEntryFromOldVal()
 	{
 		m_posX.prepareJournalEntryFromOldVal();
 		m_posY.prepareJournalEntryFromOldVal();
 	}
 
-	inline void addJournalEntryFromOldToCurVal( void )
+	inline void addJournalEntryFromOldToCurVal()
 	{
 		m_posX.addJournalEntryFromOldToCurVal();
 		m_posY.addJournalEntryFromOldToCurVal();
 	}
 
-//	automationPattern * automationPatternX( void );
-//	automationPattern * automationPatternY( void );
+//	automationPattern * automationPatternX();
+//	automationPattern * automationPatternY();
 
 
 private:
-	intModel m_posX;
-	intModel m_posY;
+	IntModel m_posX;
+	IntModel m_posY;
 
 } ;
 
 
 /*
-class surroundArea : public QWidget, public modelView
+class surroundArea : public QWidget, public ModelView
 {
 	Q_OBJECT
 public:
@@ -89,12 +89,12 @@ public:
 	virtual ~surroundArea();
 
 
-	surroundAreaModel * model( void )
+	surroundAreaModel * model()
 	{
 		return( castModel<surroundAreaModel>() );
 	}
 
-	const surroundAreaModel * model( void ) const
+	const surroundAreaModel * model() const
 	{
 		return( castModel<surroundAreaModel>() );
 	}
