@@ -27,8 +27,8 @@
 #define _KICKER_H
 
 #include <QtCore/QObject>
-#include "instrument.h"
-#include "instrument_view.h"
+#include "Instrument.h"
+#include "InstrumentView.h"
 #include "knob.h"
 
 
@@ -36,10 +36,10 @@ class kickerInstrumentView;
 class notePlayHandle;
 
 
-class kickerInstrument : public instrument
+class kickerInstrument : public Instrument
 {
 public:
-	kickerInstrument( instrumentTrack * _instrument_track );
+	kickerInstrument( InstrumentTrack * _instrument_track );
 	virtual ~kickerInstrument();
 
 	virtual void playNote( notePlayHandle * _n,
@@ -50,22 +50,22 @@ public:
 	virtual void saveSettings( QDomDocument & _doc, QDomElement & _parent );
 	virtual void loadSettings( const QDomElement & _this );
 
-	virtual QString nodeName( void ) const;
+	virtual QString nodeName() const;
 
-	virtual f_cnt_t desiredReleaseFrames( void ) const
+	virtual f_cnt_t desiredReleaseFrames() const
 	{
 		return( 512 );
 	}
 
-	virtual pluginView * instantiateView( QWidget * _parent );
+	virtual PluginView * instantiateView( QWidget * _parent );
 
 
 private:
-	knobModel m_startFreqModel;
-	knobModel m_endFreqModel;
-	knobModel m_decayModel;
-	knobModel m_distModel;
-	knobModel m_gainModel;
+	FloatModel m_startFreqModel;
+	FloatModel m_endFreqModel;
+	FloatModel m_decayModel;
+	FloatModel m_distModel;
+	FloatModel m_gainModel;
 
 	friend class kickerInstrumentView;
 
@@ -73,15 +73,15 @@ private:
 
 
 
-class kickerInstrumentView : public instrumentView
+class kickerInstrumentView : public InstrumentView
 {
 	Q_OBJECT
 public:
-	kickerInstrumentView( instrument * _instrument, QWidget * _parent );
+	kickerInstrumentView( Instrument * _instrument, QWidget * _parent );
 	virtual ~kickerInstrumentView();
 
 private:
-	virtual void modelChanged( void );
+	virtual void modelChanged();
 
 	knob * m_startFreqKnob;
 	knob * m_endFreqKnob;
