@@ -33,14 +33,13 @@
 
 #include "lb303.h"
 #include "engine.h"
-#include "instrument_play_handle.h"
-#include "instrument_track.h"
+#include "InstrumentPlayHandle.h"
+#include "InstrumentTrack.h"
 #include "knob.h"
 #include "note_play_handle.h"
 #include "templates.h"
 #include "audio_port.h"
 
-#undef SINGLE_SOURCE_COMPILE
 #include "embed.cpp"
 #include "moc_lb303.cxx"
 
@@ -77,7 +76,7 @@
 extern "C"
 {
 
-plugin::descriptor PLUGIN_EXPORT lb303_plugin_descriptor =
+Plugin::Descriptor PLUGIN_EXPORT lb303_plugin_descriptor =
 {
 	STRINGIFY( PLUGIN_NAME ),
 	"LB303",
@@ -85,8 +84,8 @@ plugin::descriptor PLUGIN_EXPORT lb303_plugin_descriptor =
 			"Incomplete monophonic immitation tb303" ),
 	"Paul Giblock <pgib/at/users.sf.net>",
 	0x0100,
-	plugin::Instrument,
-	new pluginPixmapLoader( "logo" ),
+	Plugin::Instrument,
+	new PluginPixmapLoader( "logo" ),
 	NULL
 };
 
@@ -268,8 +267,8 @@ float lb303Filter3Pole::process(const float& samp)
 // LBSynth
 //
 
-lb303Synth::lb303Synth( instrumentTrack * _instrumentTrack ) :
-	instrument( _instrumentTrack, &lb303_plugin_descriptor ),
+lb303Synth::lb303Synth( InstrumentTrack * _InstrumentTrack ) :
+	instrument( _InstrumentTrack, &lb303_plugin_descriptor ),
 	vcf_cut_knob( 0.75f, 0.0f, 1.5f, 0.005f, this, tr( "VCF Cutoff Frequency" ) ),
 	vcf_res_knob( 0.75f, 0.0f, 1.25f, 0.005f, this, tr( "VCF Resonance" ) ),
 	vcf_mod_knob( 0.1f, 0.0f, 1.0f, 0.005f, this, tr( "VCF Envelope Mod" ) ),
@@ -277,10 +276,10 @@ lb303Synth::lb303Synth( instrumentTrack * _instrumentTrack ) :
 	dist_knob( 0.0f, 0.0f, 1.0f, 0.01f, this, tr( "Distortion" ) ),
 	wave_knob( 0.0f, 0.0f, 5.0f, 1.0f, this, tr( "Waveform" ) ),
 	slide_dec_knob( 0.6f, 0.0f, 1.0f, 0.005f, this, tr( "Slide Decay" ) ),
-	slideToggle( FALSE, this, tr( "Slide" ) ),
-	accentToggle( FALSE, this, tr( "Accent" ) ),
-	deadToggle( FALSE, this, tr( "Dead" ) ),
-	db24Toggle( FALSE, this, tr( "24dB/oct Filter" ) )	
+	slideToggle( false, this, tr( "Slide" ) ),
+	accentToggle( false, this, tr( "Accent" ) ),
+	deadToggle( false, this, tr( "Dead" ) ),
+	db24Toggle( false, this, tr( "24dB/oct Filter" ) )	
 
 {
 
@@ -404,7 +403,7 @@ void lb303Synth::loadSettings( const QDomElement & _this )
 
 // TODO: Split into one function per knob.  envdecay doesn't require
 // recalcFilter.
-void lb303Synth::filterChanged( void )
+void lb303Synth::filterChanged()
 {
 	fs.cutoff = vcf_cut_knob.value();
 	fs.reso   = vcf_res_knob.value();
@@ -421,7 +420,7 @@ void lb303Synth::filterChanged( void )
 }
 
 
-void lb303Synth::db24Toggled( void )
+void lb303Synth::db24Toggled()
 {
 	delete vcf;
 	if(db24Toggle.value()) {
@@ -435,7 +434,7 @@ void lb303Synth::db24Toggled( void )
 
 
 
-QString lb303Synth::nodeName( void ) const
+QString lb303Synth::nodeName() const
 {
 	return( lb303_plugin_descriptor.name );
 }
@@ -714,7 +713,7 @@ void lb303Synth::play( sampleFrame * _working_buffer )
 	const fpp_t frames = engine::getMixer()->framesPerPeriod();
 
 	process( _working_buffer, frames); 
-	getInstrumentTrack()->processAudioBuffer( _working_buffer, frames,
+	instrumentTrack()->processAudioBuffer( _working_buffer, frames,
 									NULL );
 }
 
@@ -730,14 +729,14 @@ void lb303Synth::deleteNotePluginData( notePlayHandle * _n )
 }
 
 
-pluginView * lb303Synth::instantiateView( QWidget * _parent )
+PluginView * lb303Synth::instantiateView( QWidget * _parent )
 {
 	return( new lb303SynthView( this, _parent ) );
 }
 
 
-lb303SynthView::lb303SynthView( instrument * _instrument, QWidget * _parent ) :
-	instrumentView( _instrument, _parent )
+lb303SynthView::lb303SynthView( Instrument * _instrument, QWidget * _parent ) :
+	InstrumentView( _instrument, _parent )
 {
 	// GUI
 	m_vcfCutKnob = new knob( knobBright_26, this );
@@ -793,7 +792,7 @@ lb303SynthView::lb303SynthView( instrument * _instrument, QWidget * _parent ) :
 	m_waveKnob->setLabel( tr( "WAVE"));
 
 
-	setAutoFillBackground( TRUE );
+	setAutoFillBackground( true );
 	QPalette pal;
 	pal.setBrush( backgroundRole(), PLUGIN_NAME::getIconPixmap(
 			"artwork" ) );
@@ -806,7 +805,7 @@ lb303SynthView::~lb303SynthView()
 }
 
 
-void lb303SynthView::modelChanged( void )
+void lb303SynthView::modelChanged()
 {
 	lb303Synth * syn = castModel<lb303Synth>();
 	
@@ -830,12 +829,12 @@ void lb303SynthView::modelChanged( void )
 extern "C"
 {
 
-// neccessary for getting instance out of shared lib
-plugin * PLUGIN_EXPORT lmms_plugin_main( model *, void * _data )
+// necessary for getting instance out of shared lib
+Plugin * PLUGIN_EXPORT lmms_plugin_main( Model *, void * _data )
 {
 
 	return( new lb303Synth(
-	        static_cast<instrumentTrack *>( _data ) ) );
+	        static_cast<InstrumentTrack *>( _data ) ) );
 }
 
 
