@@ -1,5 +1,5 @@
 /*
- * stereomatrix_controls.cpp - controls for stereoMatrix-effect
+ * peak_controller_effect_controls.cpp - controls for PeakController effect
  *
  * Copyright (c) 2008 Paul Giblock <drfaygo/at/gmail/dot/com>
  * 
@@ -30,20 +30,20 @@
 #include "peak_controller_effect.h"
 
 
-peakControllerEffectControls::
-peakControllerEffectControls( peakControllerEffect * _eff ) :
-	effectControls( _eff ),
+PeakControllerEffectControls::
+PeakControllerEffectControls( PeakControllerEffect * _eff ) :
+	EffectControls( _eff ),
 	m_effect( _eff ),
 	m_baseModel( 0.5, 0.0, 1.0, 0.001, this, tr( "Base value" ) ),
 	m_amountModel( 1.0, -1.0, 1.0, 0.005, this, tr( "Modulation amount" ) ),
-	m_decayModel( 0.1, 0.01, 5.0, 0.0001, 20000.0, this, tr( "Release decay" ) ),
+	m_decayModel( 0.1, 0.01, 5.0, 0.0001, this, tr( "Release decay" ) ),
 	m_muteModel( FALSE, this, tr( "Mute output" ) )
 {
 }
 
 
 
-void peakControllerEffectControls::loadSettings( const QDomElement & _this )
+void PeakControllerEffectControls::loadSettings( const QDomElement & _this )
 {
 	m_baseModel.setValue( _this.attribute( "base" ).toFloat() );
 	m_amountModel.setValue( _this.attribute( "amount" ).toFloat() );
@@ -66,7 +66,7 @@ void peakControllerEffectControls::loadSettings( const QDomElement & _this )
 
 
 
-void peakControllerEffectControls::saveSettings( QDomDocument & _doc, 
+void PeakControllerEffectControls::saveSettings( QDomDocument & _doc, 
 							QDomElement & _this )
 {
 	_this.setAttribute( "base", m_baseModel.value() );
