@@ -2,7 +2,8 @@
  * sf2_player.cpp - a soundfont2 player using fluidSynth
  *
  * Copyright (c) 2008 Paul Giblock <drfaygo/at/gmail/dot/com>
- * 
+ * Copyright (c) 2009-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or
@@ -31,25 +32,23 @@
 
 #include "sf2_player.h"
 #include "engine.h"
-#include "instrument_track.h"
-#include "instrument_play_handle.h"
+#include "InstrumentTrack.h"
+#include "InstrumentPlayHandle.h"
 #include "note_play_handle.h"
 #include "knob.h"
 #include "song.h"
 
-#include "main_window.h"
 #include "patches_dialog.h"
 #include "tooltip.h"
 #include "lcd_spinbox.h"
 
-#undef SINGLE_SOURCE_COMPILE
 #include "embed.cpp"
 
 
 extern "C"
 {
 
-plugin::descriptor sf2player_plugin_descriptor =
+Plugin::Descriptor PLUGIN_EXPORT sf2player_plugin_descriptor =
 {
 	STRINGIFY( PLUGIN_NAME ),
 	"Sf2 Player",
@@ -57,8 +56,8 @@ plugin::descriptor sf2player_plugin_descriptor =
 			"Player for SoundFont files" ),
 	"Paul Giblock <drfaygo/at/gmail/dot/com>",
 	0x0100,
-	plugin::Instrument,
-	new pluginPixmapLoader( "logo" ),
+	Plugin::Instrument,
+	new PluginPixmapLoader( "logo" ),
 	"sf2",
 	NULL
 } ;
@@ -66,39 +65,50 @@ plugin::descriptor sf2player_plugin_descriptor =
 }
 
 
+struct SF2PluginData
+{
+	int midiNote;
+	int lastPanning;
+	float lastVelocity;
+	fluid_voice_t * fluidVoice;
+} ;
+
+
+
 // Static map of current sfonts
 QMap<QString, sf2Font*> sf2Instrument::s_fonts;
 QMutex sf2Instrument::s_fontsMutex;
 
 
 
-sf2Instrument::sf2Instrument( instrumentTrack * _instrument_track ) :
-	instrument( _instrument_track, &sf2player_plugin_descriptor ),
+sf2Instrument::sf2Instrument( InstrumentTrack * _instrument_track ) :
+	Instrument( _instrument_track, &sf2player_plugin_descriptor ),
 	m_srcState( NULL ),
 	m_font( NULL ),
 	m_fontId( 0 ),
 	m_filename( "" ),
 	m_lastMidiPitch( 8192 ),
+	m_channel( 1 ),
 	m_bankNum( 0, 0, 999, this, tr("Bank") ),
 	m_patchNum( 0, 0, 127, this, tr("Patch") ),
 	m_gain( 1.0f, 0.0f, 5.0f, 0.01f, this, tr( "Gain" ) ),
-	m_reverbOn( FALSE, this, tr( "Reverb" ) ),
-	m_reverbRoomSize( FLUID_REVERB_DEFAULT_ROOMSIZE, 0, 1.0, 0.01f, 
+	m_reverbOn( false, this, tr( "Reverb" ) ),
+	m_reverbRoomSize( FLUID_REVERB_DEFAULT_ROOMSIZE, 0, 1.0, 0.01f,
 			this, tr( "Reverb Roomsize" ) ),
-	m_reverbDamping( FLUID_REVERB_DEFAULT_DAMP, 0, 1.0, 0.01, 
+	m_reverbDamping( FLUID_REVERB_DEFAULT_DAMP, 0, 1.0, 0.01,
 			this, tr( "Reverb Damping" ) ),
-	m_reverbWidth( FLUID_REVERB_DEFAULT_WIDTH, 0, 1.0, 0.01f, 
+	m_reverbWidth( FLUID_REVERB_DEFAULT_WIDTH, 0, 1.0, 0.01f,
 			this, tr( "Reverb Width" ) ),
-	m_reverbLevel( FLUID_REVERB_DEFAULT_LEVEL, 0, 1.0, 0.01f, 
+	m_reverbLevel( FLUID_REVERB_DEFAULT_LEVEL, 0, 1.0, 0.01f,
 			this, tr( "Reverb Level" ) ),
-	m_chorusOn( FALSE, this, tr( "Chorus" ) ),
-	m_chorusNum( FLUID_CHORUS_DEFAULT_N, 0, 10.0, 1.0, 
+	m_chorusOn( false, this, tr( "Chorus" ) ),
+	m_chorusNum( FLUID_CHORUS_DEFAULT_N, 0, 10.0, 1.0,
 			this, tr( "Chorus Lines" ) ),
-	m_chorusLevel( FLUID_CHORUS_DEFAULT_LEVEL, 0, 10.0, 0.01, 
+	m_chorusLevel( FLUID_CHORUS_DEFAULT_LEVEL, 0, 10.0, 0.01,
 			this, tr( "Chorus Level" ) ),
-	m_chorusSpeed( FLUID_CHORUS_DEFAULT_SPEED, 0.29, 5.0, 0.01, 
+	m_chorusSpeed( FLUID_CHORUS_DEFAULT_SPEED, 0.29, 5.0, 0.01,
 			this, tr( "Chorus Speed" ) ),
-	m_chorusDepth( FLUID_CHORUS_DEFAULT_DEPTH, 0, 46.0, 0.05, 
+	m_chorusDepth( FLUID_CHORUS_DEFAULT_DEPTH, 0, 46.0, 0.05,
 			this, tr( "Chorus Depth" ) )
 {
 	for( int i = 0; i < 128; ++i )
@@ -115,7 +125,7 @@ sf2Instrument::sf2Instrument( instrumentTrack * _instrument_track ) :
 	// everytime we load a new soundfont.
 	m_synth = new_fluid_synth( m_settings );
 
-	instrumentPlayHandle * iph = new instrumentPlayHandle( this );
+	InstrumentPlayHandle * iph = new InstrumentPlayHandle( this );
 	engine::getMixer()->addPlayHandle( iph );
 
 	//loadFile( configManager::inst()->defaultSoundfont() );
@@ -179,7 +189,7 @@ sf2Instrument::sf2Instrument( instrumentTrack * _instrument_track ) :
 
 sf2Instrument::~sf2Instrument()
 {
-	engine::getMixer()->removePlayHandles( getInstrumentTrack() );
+	engine::getMixer()->removePlayHandles( instrumentTrack() );
 	freeFont();
 	delete_fluid_synth( m_synth );
 	delete_fluid_settings( m_settings );
@@ -236,6 +246,7 @@ void sf2Instrument::loadSettings( const QDomElement & _this )
 	m_chorusSpeed.loadSettings( _this, "chorusSpeed" );
 	m_chorusDepth.loadSettings( _this, "chorusDepth" );
 
+	updatePatch();
 	updateGain();
 }
 
@@ -258,7 +269,7 @@ void sf2Instrument::loadFile( const QString & _file )
 
 
 
-automatableModel * sf2Instrument::getChildModel( const QString & _modelName )
+AutomatableModel * sf2Instrument::childModel( const QString & _modelName )
 {
 	if( _modelName == "bank" )
 	{
@@ -274,7 +285,7 @@ automatableModel * sf2Instrument::getChildModel( const QString & _modelName )
 
 
 
-QString sf2Instrument::nodeName( void ) const
+QString sf2Instrument::nodeName() const
 {
 	return( sf2player_plugin_descriptor.name );
 }
@@ -282,7 +293,7 @@ QString sf2Instrument::nodeName( void ) const
 
 
 
-void sf2Instrument::freeFont( void )
+void sf2Instrument::freeFont()
 {
 	QTextStream cout( stdout, QIODevice::WriteOnly );
 
@@ -298,7 +309,7 @@ void sf2Instrument::freeFont( void )
 		{
 			cout << "Really deleting " << m_filename << endl;
 
-			fluid_synth_sfunload( m_synth, m_fontId, TRUE );
+			fluid_synth_sfunload( m_synth, m_fontId, true );
 			s_fonts.remove( m_filename );
 			delete m_font;
 		}
@@ -346,10 +357,10 @@ void sf2Instrument::openFile( const QString & _sf2File )
 		m_fontId = fluid_synth_add_sfont( m_synth, m_font->fluidFont );		
 	}
 
-	// Add to map, if doesn't exist.  
+	// Add to map, if doesn't exist.
 	else
 	{
-		m_fontId = fluid_synth_sfload( m_synth, sf2Ascii, TRUE );
+		m_fontId = fluid_synth_sfload( m_synth, sf2Ascii, true );
 
 		if( fluid_synth_sfcount( m_synth ) > 0 )
 		{
@@ -383,11 +394,11 @@ void sf2Instrument::openFile( const QString & _sf2File )
 
 
 
-void sf2Instrument::updatePatch( void )
+void sf2Instrument::updatePatch()
 {
 	if( m_bankNum.value() >= 0 && m_patchNum.value() >= 0 )
 	{
-		fluid_synth_program_select( m_synth, 1, m_fontId,
+		fluid_synth_program_select( m_synth, m_channel, m_fontId,
 				m_bankNum.value(), m_patchNum.value() );
 	}
 }
@@ -395,7 +406,7 @@ void sf2Instrument::updatePatch( void )
 
 
 
-QString sf2Instrument::getCurrentPatchName( void )
+QString sf2Instrument::getCurrentPatchName()
 {
 	int iBankSelected = m_bankNum.value();
 	int iProgSelected = m_patchNum.value();
@@ -406,7 +417,8 @@ QString sf2Instrument::getCurrentPatchName( void )
 	for( int i = 0; i < cSoundFonts; i++ )
 	{
 		fluid_sfont_t *pSoundFont = fluid_synth_get_sfont( m_synth, i );
-		if (pSoundFont) {
+		if ( pSoundFont )
+		{
 #ifdef CONFIG_FLUID_BANK_OFFSET
 			int iBankOffset =
 				fluid_synth_get_bank_offset(
@@ -435,7 +447,7 @@ QString sf2Instrument::getCurrentPatchName( void )
 
 
 
-void sf2Instrument::updateGain( void )
+void sf2Instrument::updateGain()
 {
 	fluid_synth_set_gain( m_synth, m_gain.value() );
 }
@@ -443,7 +455,7 @@ void sf2Instrument::updateGain( void )
 
 
 
-void sf2Instrument::updateReverbOn( void )
+void sf2Instrument::updateReverbOn()
 {
 	fluid_synth_set_reverb_on( m_synth, m_reverbOn.value() ? 1 : 0 );
 }
@@ -451,7 +463,7 @@ void sf2Instrument::updateReverbOn( void )
 
 
 
-void sf2Instrument::updateReverb( void )
+void sf2Instrument::updateReverb()
 {
 	fluid_synth_set_reverb( m_synth, m_reverbRoomSize.value(),
 			m_reverbDamping.value(), m_reverbWidth.value(),
@@ -461,7 +473,7 @@ void sf2Instrument::updateReverb( void )
 
 
 
-void  sf2Instrument::updateChorusOn( void )
+void  sf2Instrument::updateChorusOn()
 {
 	fluid_synth_set_chorus_on( m_synth, m_chorusOn.value() ? 1 : 0 );
 }
@@ -469,7 +481,7 @@ void  sf2Instrument::updateChorusOn( void )
 
 
 
-void  sf2Instrument::updateChorus( void )
+void  sf2Instrument::updateChorus()
 {
 	fluid_synth_set_chorus( m_synth, static_cast<int>( m_chorusNum.value() ),
 			m_chorusLevel.value(), m_chorusSpeed.value(),
@@ -478,7 +490,7 @@ void  sf2Instrument::updateChorus( void )
 
 
 
-void sf2Instrument::updateSampleRate( void )
+void sf2Instrument::updateSampleRate()
 {	
 	double tempRate;
 	
@@ -493,7 +505,7 @@ void sf2Instrument::updateSampleRate( void )
 	{
 		// Now, delete the old one and replace
 		m_synthMutex.lock();
-		fluid_synth_remove_sfont( m_synth, m_font->fluidFont ); 
+		fluid_synth_remove_sfont( m_synth, m_font->fluidFont );
 		delete_fluid_synth( m_synth );
 
 		// New synth
@@ -555,7 +567,7 @@ void sf2Instrument::updateSampleRate( void )
 
 void sf2Instrument::playNote( notePlayHandle * _n, sampleFrame * )
 {
-	const double LOG440 = 2.643452676486187424842455584439449012279510498046875f;
+	const float LOG440 = 2.643452676f;
 
 	const f_cnt_t tfp = _n->totalFramesPlayed();
 
@@ -570,31 +582,103 @@ void sf2Instrument::playNote( notePlayHandle * _n, sampleFrame * )
 
 	if( tfp == 0 )
 	{
-		_n->m_pluginData = new int( midiNote );
+		SF2PluginData * pluginData = new SF2PluginData;
+		pluginData->midiNote = midiNote;
+		pluginData->lastPanning = -1;
+		pluginData->lastVelocity = 127;
+		pluginData->fluidVoice = NULL;
+
+		_n->m_pluginData = pluginData;
 
 		m_synthMutex.lock();
-		fluid_synth_noteon( m_synth, 1, midiNote,
+
+		// get list of current voice IDs so we can easily spot the new
+		// voice after the fluid_synth_noteon() call
+		const int poly = fluid_synth_get_polyphony( m_synth );
+		fluid_voice_t * voices[poly];
+		unsigned int id[poly];
+		fluid_synth_get_voicelist( m_synth, voices, poly, -1 );
+		for( int i = 0; i < poly; ++i )
+		{
+			id[i] = 0;
+		}
+		for( int i = 0; i < poly && voices[i]; ++i )
+		{
+			id[i] = fluid_voice_get_id( voices[i] );
+		}
+
+		fluid_synth_noteon( m_synth, m_channel, midiNote,
 							_n->getMidiVelocity() );
+
+		// get new voice and save it
+		fluid_synth_get_voicelist( m_synth, voices, poly, -1 );
+		for( int i = 0; i < poly && voices[i]; ++i )
+		{
+			const unsigned int newID = fluid_voice_get_id( voices[i] );
+			if( id[i] != newID || newID == 0 )
+			{
+				pluginData->fluidVoice = voices[i];
+				break;
+			}
+		}
+
 		m_synthMutex.unlock();
 
 		m_notesRunningMutex.lock();
 		++m_notesRunning[midiNote];
 		m_notesRunningMutex.unlock();
 	}
+
+	SF2PluginData * pluginData = static_cast<SF2PluginData *>(
+							_n->m_pluginData );
+#ifdef SOMEONE_FIXED_PER_NOTE_PANNING
+	if( pluginData->fluidVoice &&
+			pluginData->lastPanning != _n->getPanning() )
+	{
+		const float pan = -500 +
+			  ( (float)( _n->getPanning() - PanningLeft ) ) /
+			  ( (float)( PanningRight - PanningLeft ) ) * 1000;
+
+		m_synthMutex.lock();
+		fluid_voice_gen_set( pluginData->fluidVoice, GEN_PAN, pan );
+		fluid_voice_update_param( pluginData->fluidVoice, GEN_PAN );
+		m_synthMutex.unlock();
+
+		pluginData->lastPanning = _n->getPanning();
+	}
+#endif
+
+	const float currentVelocity = _n->volumeLevel( tfp ) * 127;
+	if( pluginData->fluidVoice &&
+			pluginData->lastVelocity != currentVelocity )
+	{
+		m_synthMutex.lock();
+		fluid_voice_gen_set( pluginData->fluidVoice, GEN_VELOCITY,
+													currentVelocity );
+		fluid_voice_update_param( pluginData->fluidVoice, GEN_VELOCITY );
+		// make sure, FluidSynth modulates our changed GEN_VELOCITY via internal
+		// attenuation modulator, so changes take effect (7=Volume CC)
+		fluid_synth_cc( m_synth, m_channel, 7, 127 );
+		m_synthMutex.unlock();
+
+		pluginData->lastVelocity = currentVelocity;
+	}
 }
 
 
-// Could we get iph-based instruments support sample-exact models by using a 
+
+
+// Could we get iph-based instruments support sample-exact models by using a
 // frame-length of 1 while rendering?
 void sf2Instrument::play( sampleFrame * _working_buffer )
 {
 	const fpp_t frames = engine::getMixer()->framesPerPeriod();
 
 	m_synthMutex.lock();
-	if( m_lastMidiPitch != getInstrumentTrack()->midiPitch() )
+	if( m_lastMidiPitch != instrumentTrack()->midiPitch() )
 	{
-		m_lastMidiPitch = getInstrumentTrack()->midiPitch();
-		fluid_synth_pitch_bend( m_synth, 1, m_lastMidiPitch );
+		m_lastMidiPitch = instrumentTrack()->midiPitch();
+		fluid_synth_pitch_bend( m_synth, m_channel, m_lastMidiPitch );
 	}
 
 	if( m_internalSampleRate < engine::getMixer()->processingSampleRate() &&
@@ -602,7 +686,11 @@ void sf2Instrument::play( sampleFrame * _working_buffer )
 	{
 		const fpp_t f = frames * m_internalSampleRate /
 				engine::getMixer()->processingSampleRate();
+#ifdef __GNUC__
+		sampleFrame tmp[f];
+#else
 		sampleFrame * tmp = new sampleFrame[f];
+#endif
 		fluid_synth_write_float( m_synth, f, tmp, 0, 2, tmp, 1, 2 );
 
 		SRC_DATA src_data;
@@ -613,7 +701,9 @@ void sf2Instrument::play( sampleFrame * _working_buffer )
 		src_data.src_ratio = (double) frames / f;
 		src_data.end_of_input = 0;
 		int error = src_process( m_srcState, &src_data );
+#ifndef __GNUC__
 		delete[] tmp;
+#endif
 		if( error )
 		{
 			printf( "sf2Instrument: error while resampling: %s\n",
@@ -632,7 +722,7 @@ void sf2Instrument::play( sampleFrame * _working_buffer )
 	}
 	m_synthMutex.unlock();
 
-	getInstrumentTrack()->processAudioBuffer( _working_buffer, frames,
+	instrumentTrack()->processAudioBuffer( _working_buffer, frames,
 									NULL );
 }
 
@@ -641,26 +731,28 @@ void sf2Instrument::play( sampleFrame * _working_buffer )
 
 void sf2Instrument::deleteNotePluginData( notePlayHandle * _n )
 {
-	int * midiNote = static_cast<int *>( _n->m_pluginData );
+	SF2PluginData * pluginData = static_cast<SF2PluginData *>(
+							_n->m_pluginData );
 	m_notesRunningMutex.lock();
-	const int n = --m_notesRunning[*midiNote];
+	const int n = --m_notesRunning[pluginData->midiNote];
 	m_notesRunningMutex.unlock();
+
 	if( n <= 0 )
 	{
 		m_synthMutex.lock();
-		fluid_synth_noteoff( m_synth, 1, *midiNote );
+		fluid_synth_noteoff( m_synth, m_channel, pluginData->midiNote );
 		m_synthMutex.unlock();
 	}
 
-	delete midiNote;
+	delete pluginData;
 }
 
 
 
 
-pluginView * sf2Instrument::instantiateView( QWidget * _parent )
+PluginView * sf2Instrument::instantiateView( QWidget * _parent )
 {
-	return( new sf2InstrumentView( this, _parent ) );
+	return new sf2InstrumentView( this, _parent );
 }
 
 
@@ -681,9 +773,9 @@ public:
 
 
 
-sf2InstrumentView::sf2InstrumentView( instrument * _instrument,
+sf2InstrumentView::sf2InstrumentView( Instrument * _instrument,
 			QWidget * _parent ) :
-	instrumentView( _instrument, _parent )
+	InstrumentView( _instrument, _parent )
 {
 //	QVBoxLayout * vl = new QVBoxLayout( this );
 //	QHBoxLayout * hl = new QHBoxLayout();
@@ -717,7 +809,7 @@ sf2InstrumentView::sf2InstrumentView( instrument * _instrument,
 							"patches_on" ) );
 	m_patchDialogButton->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
 							"patches_off" ) );
-	m_patchDialogButton->setEnabled( FALSE );
+	m_patchDialogButton->setEnabled( false );
 	m_patchDialogButton->move( 217, 125 );
 
 	connect( m_patchDialogButton, SIGNAL( clicked() ),
@@ -729,12 +821,12 @@ sf2InstrumentView::sf2InstrumentView( instrument * _instrument,
 	m_bankNumLcd = new lcdSpinBox( 3, "21pink", this );
 	m_bankNumLcd->move(131, 62);
 //	m_bankNumLcd->addTextForValue( -1, "---" );
-//	m_bankNumLcd->setEnabled( FALSE );
+//	m_bankNumLcd->setEnabled( false );
 
 	m_patchNumLcd = new lcdSpinBox( 3, "21pink", this );
 	m_patchNumLcd->move(190, 62);
 //	m_patchNumLcd->addTextForValue( -1, "---" );
-//	m_patchNumLcd->setEnabled( FALSE );
+//	m_patchNumLcd->setEnabled( false );
 
 	/*hl->addWidget( m_fileDialogButton );
 	hl->addWidget( m_bankNumLcd );
@@ -766,7 +858,7 @@ sf2InstrumentView::sf2InstrumentView( instrument * _instrument,
 
 	
 	m_reverbButton = new pixmapButton( this );
-	m_reverbButton->setCheckable( TRUE );
+	m_reverbButton->setCheckable( true );
 	m_reverbButton->move( 24, 176 );
 	m_reverbButton->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 							"reverb_on" ) );
@@ -808,7 +900,7 @@ sf2InstrumentView::sf2InstrumentView( instrument * _instrument,
 //	hl = new QHBoxLayout();
 
 	m_chorusButton = new pixmapButton( this );
-	m_chorusButton->setCheckable( TRUE );
+	m_chorusButton->setCheckable( true );
 	m_chorusButton->move( 24, 222 );
 	m_chorusButton->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 							"chorus_on" ) );
@@ -844,7 +936,7 @@ sf2InstrumentView::sf2InstrumentView( instrument * _instrument,
 
 	vl->addLayout( hl );
 */
-	setAutoFillBackground( TRUE );
+	setAutoFillBackground( true );
 	QPalette pal;
 	pal.setBrush( backgroundRole(), PLUGIN_NAME::getIconPixmap(
 								"artwork" ) );
@@ -864,7 +956,7 @@ sf2InstrumentView::~sf2InstrumentView()
 
 
 
-void sf2InstrumentView::modelChanged( void )
+void sf2InstrumentView::modelChanged()
 {
 	sf2Instrument * k = castModel<sf2Instrument>();
 	m_bankNumLcd->setModel( &k->m_bankNum );
@@ -885,11 +977,11 @@ void sf2InstrumentView::modelChanged( void )
 	m_chorusDepthKnob->setModel( &k->m_chorusDepth );
 
 
-	connect(k, SIGNAL( fileChanged( void ) ),
-			this, SLOT( updateFilename( void ) ) );
+	connect(k, SIGNAL( fileChanged() ),
+			this, SLOT( updateFilename() ) );
 
-	connect(k, SIGNAL( fileLoading( void ) ),
-			this, SLOT( invalidateFile( void ) ) );
+	connect(k, SIGNAL( fileLoading() ),
+			this, SLOT( invalidateFile() ) );
 
 	updateFilename();
 
@@ -898,7 +990,7 @@ void sf2InstrumentView::modelChanged( void )
 
 
 
-void sf2InstrumentView::updateFilename( void )
+void sf2InstrumentView::updateFilename()
 {
 	sf2Instrument * i = castModel<sf2Instrument>();
 	QFontMetrics fm( m_filenameLabel->font() );
@@ -906,7 +998,7 @@ void sf2InstrumentView::updateFilename( void )
 			i->m_filename.left( i->m_filename.length() - 4 ) :
 			i->m_filename;
 	m_filenameLabel->setText(
-			fm.elidedText( file, Qt::ElideLeft, 
+			fm.elidedText( file, Qt::ElideLeft,
 			m_filenameLabel->width() ) );
 			//		i->m_filename + "\nPatch: TODO" );
 
@@ -920,13 +1012,13 @@ void sf2InstrumentView::updateFilename( void )
 
 
 
-void sf2InstrumentView::updatePatchName( void )
+void sf2InstrumentView::updatePatchName()
 {
 	sf2Instrument * i = castModel<sf2Instrument>();
 	QFontMetrics fm( font() );
 	QString patch = i->getCurrentPatchName();
 	m_patchLabel->setText(
-			fm.elidedText( patch, Qt::ElideLeft, 
+			fm.elidedText( patch, Qt::ElideLeft,
 			m_patchLabel->width() ) );
 
 
@@ -936,7 +1028,7 @@ void sf2InstrumentView::updatePatchName( void )
 
 
 
-void sf2InstrumentView::invalidateFile( void )
+void sf2InstrumentView::invalidateFile()
 {
 	m_patchDialogButton->setEnabled( false );
 }
@@ -944,7 +1036,7 @@ void sf2InstrumentView::invalidateFile( void )
 
 
 
-void sf2InstrumentView::showFileDialog( void )
+void sf2InstrumentView::showFileDialog()
 {
 	sf2Instrument * k = castModel<sf2Instrument>();
 
@@ -962,7 +1054,7 @@ void sf2InstrumentView::showFileDialog( void )
 		if( QFileInfo( f ).isRelative() )
 		{
 			f = configManager::inst()->userSamplesDir() + f;
-			if( QFileInfo( f ).exists() == FALSE )
+			if( QFileInfo( f ).exists() == false )
 			{
 				f = configManager::inst()->factorySamplesDir() +
 						k->m_filename;
@@ -994,13 +1086,13 @@ void sf2InstrumentView::showFileDialog( void )
 
 
 
-void sf2InstrumentView::showPatchDialog( void )
+void sf2InstrumentView::showPatchDialog()
 {
 	sf2Instrument * k = castModel<sf2Instrument>();
 
 	patchesDialog pd( this );
 
-	pd.setup( k->m_synth, 1, k->getInstrumentTrack()->name(),
+	pd.setup( k->m_synth, 1, k->instrumentTrack()->name(),
 		&k->m_bankNum, &k->m_patchNum, m_patchLabel );
 
 	pd.exec();
@@ -1011,11 +1103,10 @@ void sf2InstrumentView::showPatchDialog( void )
 extern "C"
 {
 
-// neccessary for getting instance out of shared lib
-plugin * lmms_plugin_main( model *, void * _data )
+// necessary for getting instance out of shared lib
+Plugin * PLUGIN_EXPORT lmms_plugin_main( Model *, void * _data )
 {
-	return( new sf2Instrument(
-			static_cast<instrumentTrack *>( _data ) ) );
+	return new sf2Instrument( static_cast<InstrumentTrack *>( _data ) );
 }
 
 
