@@ -29,9 +29,9 @@
 
 #include <QtCore/QMutex>
 
-#include "instrument.h"
+#include "Instrument.h"
 #include "pixmap_button.h"
-#include "instrument_view.h"
+#include "InstrumentView.h"
 #include "knob.h"
 #include "lcd_spinbox.h"
 #include "led_checkbox.h"
@@ -46,14 +46,14 @@ class patchesDialog;
 class QLabel;
 
 
-class sf2Instrument : public instrument
+class sf2Instrument : public Instrument
 {
 	Q_OBJECT
 	mapPropertyFromModel(int,getBank,setBank,m_bankNum);
 	mapPropertyFromModel(int,getPatch,setPatch,m_patchNum);
 
 public:
-	sf2Instrument( instrumentTrack * _instrument_track );
+	sf2Instrument( InstrumentTrack * _instrument_track );
 	virtual ~sf2Instrument();
 
 	virtual void play( sampleFrame * _working_buffer );
@@ -68,7 +68,7 @@ public:
 
 	virtual void loadFile( const QString & _file );
 
-	virtual automatableModel * getChildModel( const QString & _modelName );
+	virtual AutomatableModel * childModel( const QString & _modelName );
 
 	virtual QString nodeName() const;
 
@@ -82,7 +82,7 @@ public:
 		return true;
 	}
 
-	virtual pluginView * instantiateView( QWidget * _parent );
+	virtual PluginView * instantiateView( QWidget * _parent );
 	
 	QString getCurrentPatchName();
 
@@ -134,19 +134,19 @@ private:
 	lcdSpinBoxModel m_bankNum;
 	lcdSpinBoxModel m_patchNum;
 
-	knobModel m_gain;
+	FloatModel m_gain;
 
-	boolModel m_reverbOn;
-	knobModel m_reverbRoomSize;
-	knobModel m_reverbDamping;
-	knobModel m_reverbWidth;
-	knobModel m_reverbLevel;
+	BoolModel m_reverbOn;
+	FloatModel m_reverbRoomSize;
+	FloatModel m_reverbDamping;
+	FloatModel m_reverbWidth;
+	FloatModel m_reverbLevel;
 
-	boolModel m_chorusOn;
-	knobModel m_chorusNum;
-	knobModel m_chorusLevel;
-	knobModel m_chorusSpeed;
-	knobModel m_chorusDepth;
+	BoolModel m_chorusOn;
+	FloatModel m_chorusNum;
+	FloatModel m_chorusLevel;
+	FloatModel m_chorusSpeed;
+	FloatModel m_chorusDepth;
 
 
 private:
@@ -178,11 +178,11 @@ public:
 
 
 
-class sf2InstrumentView : public instrumentView
+class sf2InstrumentView : public InstrumentView
 {
 	Q_OBJECT
 public:
-	sf2InstrumentView( instrument * _instrument,
+	sf2InstrumentView( Instrument * _instrument,
 					QWidget * _parent );
 	virtual ~sf2InstrumentView();
 
