@@ -2,7 +2,8 @@
  * mallets.cpp - tuned instruments that one would bang upon
  *
  * Copyright (c) 2006-2008 Danny McRae <khjklujn/at/users.sourceforge.net>
- * 
+ * Copyright (c) 2009-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or
@@ -33,7 +34,7 @@
 
 #include "engine.h"
 #include "gui_templates.h"
-#include "instrument_track.h"
+#include "InstrumentTrack.h"
 
 #include "embed.cpp"
 
@@ -41,7 +42,7 @@
 extern "C"
 {
 
-plugin::descriptor malletsstk_plugin_descriptor =
+Plugin::Descriptor PLUGIN_EXPORT malletsstk_plugin_descriptor =
 {
 	STRINGIFY( PLUGIN_NAME ),
 	"Mallets",
@@ -49,8 +50,8 @@ plugin::descriptor malletsstk_plugin_descriptor =
 				"Tuneful things to bang on" ),
 	"Danny McRae <khjklujn/at/users.sf.net>",
 	0x0100,
-	plugin::Instrument,
-	new pluginPixmapLoader( "logo" ),
+	Plugin::Instrument,
+	new PluginPixmapLoader( "logo" ),
 	NULL,
 	NULL
 } ;
@@ -58,8 +59,8 @@ plugin::descriptor malletsstk_plugin_descriptor =
 }
 
 
-malletsInstrument::malletsInstrument( instrumentTrack * _instrument_track ):
-	instrument( _instrument_track, &malletsstk_plugin_descriptor ),
+malletsInstrument::malletsInstrument( InstrumentTrack * _instrument_track ):
+	Instrument( _instrument_track, &malletsstk_plugin_descriptor ),
 	m_hardnessModel(64.0f, 0.0f, 128.0f, 0.1f, this, tr( "Hardness" )),
 	m_positionModel(64.0f, 0.0f, 128.0f, 0.1f, this, tr( "Position" )),
 	m_vibratoGainModel(64.0f, 0.0f, 128.0f, 0.1f, this, tr( "Vibrato Gain" )),
@@ -73,7 +74,7 @@ malletsInstrument::malletsInstrument( instrumentTrack * _instrument_track ):
 	m_pressureModel(64.0f, 0.0f, 128.0f, 0.1f, this, tr( "Pressure" )),
 	m_motionModel(64.0f, 0.0f, 128.0f, 0.1f, this, tr( "Motion" )),
 	m_velocityModel(64.0f, 0.0f, 128.0f, 0.1f, this, tr( "Speed" )),
-	m_strikeModel( FALSE, this, tr( "Bowed" ) ),
+	m_strikeModel( false, this, tr( "Bowed" ) ),
 	m_presetsModel(this),
 	m_spreadModel(0, 0, 255, 1, this, tr( "Spread" )),
 	m_filesMissing( !QDir( configManager::inst()->stkDir() ).exists() ||
@@ -195,7 +196,7 @@ void malletsInstrument::loadSettings( const QDomElement & _this )
 
 
 
-QString malletsInstrument::nodeName( void ) const
+QString malletsInstrument::nodeName() const
 {
 	return( malletsstk_plugin_descriptor.name );
 }
@@ -281,7 +282,7 @@ void malletsInstrument::playNote( notePlayHandle * _n,
 				( m_scalers[m_presetsModel.value()] + add_scale );
 	}
 	
-	getInstrumentTrack()->processAudioBuffer( _working_buffer, frames, _n );
+	instrumentTrack()->processAudioBuffer( _working_buffer, frames, _n );
 }
 
 
@@ -295,7 +296,7 @@ void malletsInstrument::deleteNotePluginData( notePlayHandle * _n )
 
 
 
-pluginView * malletsInstrument::instantiateView( QWidget * _parent )
+PluginView * malletsInstrument::instantiateView( QWidget * _parent )
 {
 	return( new malletsInstrumentView( this, _parent ) );
 }
@@ -305,7 +306,7 @@ pluginView * malletsInstrument::instantiateView( QWidget * _parent )
 
 malletsInstrumentView::malletsInstrumentView( malletsInstrument * _instrument,
 							QWidget * _parent ) :
-	instrumentView( _instrument, _parent )
+	InstrumentView( _instrument, _parent )
 {
 	m_modalBarWidget = setupModalBarControls( this );
 	setWidgetBackground( m_modalBarWidget, "artwork" );
@@ -342,7 +343,7 @@ malletsInstrumentView::~malletsInstrumentView()
 
 void malletsInstrumentView::setWidgetBackground( QWidget * _widget, const QString & _pic )
 {
-	_widget->setAutoFillBackground( TRUE );
+	_widget->setAutoFillBackground( true );
 	QPalette pal;
 	pal.setBrush( _widget->backgroundRole(),
 		PLUGIN_NAME::getIconPixmap( _pic.toAscii().constData() ) );
@@ -459,7 +460,7 @@ QWidget * malletsInstrumentView::setupBandedWGControls( QWidget * _parent )
 
 
 
-void malletsInstrumentView::modelChanged( void )
+void malletsInstrumentView::modelChanged()
 {
 	malletsInstrument * inst = castModel<malletsInstrument>();
 	m_hardnessKnob->setModel( &inst->m_hardnessModel );
@@ -654,10 +655,10 @@ malletsSynth::malletsSynth( const StkFloat _pitch,
 extern "C"
 {
 
-// neccessary for getting instance out of shared lib
-plugin * lmms_plugin_main( model *, void * _data )
+// necessary for getting instance out of shared lib
+Plugin * PLUGIN_EXPORT lmms_plugin_main( Model *, void * _data )
 {
-	return( new malletsInstrument( static_cast<instrumentTrack *>( _data ) ) );
+	return new malletsInstrument( static_cast<InstrumentTrack *>( _data ) );
 }
 
 
