@@ -20,25 +20,12 @@
  * Boston, MA 02110-1301 USA.
  *
  */
-#ifndef _TWO_STRINGS_H
-#define _TWO_STRINGS_H
 
-
-#include "qt3support.h"
-
-#ifndef QT3
+#ifndef _STRING_CONTAINER_H
+#define _STRING_CONTAINER_H
 
 #include <QtCore/QVector>
 
-#else
-
-#include <qvaluevector.h>
-
-#endif
-
-
-#include "config.h"
-#include "types.h"
 #include "vibrating_string.h"
 
 
@@ -54,7 +41,7 @@ public:
 	void addString(	Uint8 _harm,
 			const float _pick,
 			const float _pickup,
-			float * _impluse,
+			const float * _impluse,
 			const float _randomize,
 			const float _string_loss,
 			const float _detune,
@@ -82,11 +69,11 @@ public:
 	}
 	
 private:
-	vvector<vibratingString *> m_strings;
+	QVector<vibratingString *> m_strings;
 	const float m_pitch;
 	const sample_rate_t m_sampleRate;
 	const Uint32 m_bufferLength;
-	vvector<bool> m_exists;
+	QVector<bool> m_exists;
 } ;
 
 #endif
