@@ -1,7 +1,7 @@
 /*
- * remote_vst_plugin.cpp - LMMS VST Support Layer (remotePlugin client)
+ * remote_vst_plugin.cpp - LMMS VST Support Layer (RemotePlugin client)
  *
- * Copyright (c) 2005-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -32,14 +32,22 @@
 
 #define BUILD_REMOTE_PLUGIN_CLIENT
 
-#include "remote_plugin.h"
+#include "RemotePlugin.h"
 
 #ifdef LMMS_HAVE_PTHREAD_H
 #include <pthread.h>
 #endif
 
+#ifdef LMMS_HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+
 #ifdef LMMS_BUILD_LINUX
 
+#ifndef O_BINARY
+#define O_BINARY 0
+#endif
+
 #ifdef LMMS_HAVE_SCHED_H
 #include <sched.h>
 #endif
@@ -59,7 +67,7 @@
 #endif
 
 
-#include <list>
+#include <vector>
 #include <string>
 
 
@@ -91,34 +99,25 @@ struct ERect
 
 static VstHostLanguages hlang = LanguageEnglish;
 
-enum VstThreadingModel
-{
-	TraditionalThreading,	// all GUI related code in separate thread
-	SplittedThreading,	// sound processing in separate thread
-	
-} ;
 
+class RemoteVstPlugin;
 
-class remoteVstPlugin;
+RemoteVstPlugin * __plugin = NULL;
 
-remoteVstPlugin * __plugin = NULL;
-
-DWORD __threadID = NULL;
-
-VstThreadingModel __threadingModel = TraditionalThreading;
+DWORD __GuiThreadID = 0;
 
 
 
-class remoteVstPlugin : public remotePluginClient
+class RemoteVstPlugin : public RemotePluginClient
 {
 public:
-	remoteVstPlugin( key_t _shm_in, key_t _shm_out );
-	virtual ~remoteVstPlugin();
+	RemoteVstPlugin( key_t _shm_in, key_t _shm_out );
+	virtual ~RemoteVstPlugin();
 
 	virtual bool processMessage( const message & _m );
 
 	void init( const std::string & _plugin_file );
-	void initEditor( void );
+	void initEditor();
 
 	virtual void process( const sampleFrame * _in, sampleFrame * _out );
 
@@ -127,27 +126,20 @@ public:
 							const f_cnt_t _offset );
 
 	// set given sample-rate for plugin
-	virtual void updateSampleRate( void )
+	virtual void updateSampleRate()
 	{
-		if( m_plugin )
-		{
-			m_plugin->dispatcher( m_plugin, effSetSampleRate, 0, 0,
+		pluginDispatch( effSetSampleRate, 0, 0,
 						NULL, (float) sampleRate() );
-		}
 	}
 
 	// set given buffer-size for plugin
-	virtual void updateBufferSize( void )
+	virtual void updateBufferSize()
 	{
-		if( m_plugin )
-		{
-			m_plugin->dispatcher( m_plugin, effSetBlockSize, 0,
-						bufferSize(), NULL, 0.0f );
-		}
+		pluginDispatch( effSetBlockSize, 0, bufferSize() );
 	}
 
 
-	inline bool isInitialized( void ) const
+	inline bool isInitialized() const
 	{
 		return m_initialized;
 	}
@@ -160,23 +152,22 @@ public:
 	}
 
 	// determine VST-version the plugin uses
-	int pluginVersion( void ) const
+	inline int pluginVersion()
 	{
-		return m_plugin->dispatcher( m_plugin,
-				effGetVendorVersion, 0, 0, NULL, 0.0f );
+		return pluginDispatch( effGetVendorVersion );
 	}
 
 	// determine name of plugin
-	const char * pluginName( void ) const;
+	const char * pluginName();
 
 	// determine vendor of plugin
-	const char * pluginVendorString( void ) const;
+	const char * pluginVendorString();
 
 	// determine product-string of plugin
-	const char * pluginProductString( void ) const;
+	const char * pluginProductString();
 
 	// do a complete parameter-dump and post it
-	void getParameterDump( void );
+	void getParameterDump();
 
 	// read parameter-dump and set it for plugin
 	void setParameterDump( const message & _m );
@@ -184,20 +175,44 @@ public:
 	// post properties of specified parameter
 	void getParameterProperties( const int _idx );
 
+	// save settings chunk of plugin into file
+	void saveChunkToFile( const std::string & _file );
+
+	// restore settings chunk of plugin from file
+	void loadChunkFromFile( const std::string & _file, int _len );
+
 	// number of inputs
-	virtual int inputCount( void ) const
+	virtual int inputCount() const
 	{
-		return m_plugin->numInputs;
+		if( m_plugin )
+		{
+			return m_plugin->numInputs;
+		}
+		return 0;
 	}
 
 	// number of outputs
-	virtual int outputCount( void ) const
+	virtual int outputCount() const
 	{
-		return m_plugin->numOutputs;
+		if( m_plugin )
+		{
+			return m_plugin->numOutputs;
+		}
+		return 0;
 	}
 
 	// has to be called as soon as input- or output-count changes
-	void updateInOutCount( void );
+	void updateInOutCount();
+
+	inline void lock()
+	{
+		pthread_mutex_lock( &m_pluginLock );
+	}
+
+	inline void unlock()
+	{
+		pthread_mutex_unlock( &m_pluginLock );
+	}
 
 	static DWORD WINAPI processingThread( LPVOID _param );
 	static DWORD WINAPI guiEventLoop( LPVOID _param );
@@ -208,6 +223,7 @@ private:
 	{
 		None,
 		ProcessPluginMessage,
+		GiveIdle,
 		ClosePlugin
 	} ;
 
@@ -219,6 +235,20 @@ private:
 
 	bool load( const std::string & _plugin_file );
 
+	// thread-safe dispatching of plugin
+	int pluginDispatch( int cmd, int param1 = 0, int param2 = 0,
+					void * p = NULL, float f = 0 )
+	{
+		int ret = 0;
+		lock();
+		if( m_plugin )
+		{
+			ret = m_plugin->dispatcher( m_plugin, cmd, param1,
+							param2, p, f );
+		}
+		unlock();
+		return ret;
+	}
 
 	std::string m_shortName;
 
@@ -232,14 +262,14 @@ private:
 
 	bool m_initialized;
 
-	pthread_mutex_t m_lock;
-	pthread_cond_t m_windowStatusChange;
+	pthread_mutex_t m_pluginLock;
 
 
 	float * * m_inputs;
 	float * * m_outputs;
 
-	std::list<VstMidiEvent> m_midiEvents;
+	typedef std::vector<VstMidiEvent> VstMidiEventList;
+	VstMidiEventList m_midiEvents;
 
 	bpm_t m_bpm;
 	double m_currentSamplePos;
@@ -249,8 +279,8 @@ private:
 
 
 
-remoteVstPlugin::remoteVstPlugin( key_t _shm_in, key_t _shm_out ) :
-	remotePluginClient( _shm_in, _shm_out ),
+RemoteVstPlugin::RemoteVstPlugin( key_t _shm_in, key_t _shm_out ) :
+	RemotePluginClient( _shm_in, _shm_out ),
 	m_shortName( "" ),
 	m_libInst( NULL ),
 	m_plugin( NULL ),
@@ -259,37 +289,37 @@ remoteVstPlugin::remoteVstPlugin( key_t _shm_in, key_t _shm_out ) :
 	m_windowWidth( 0 ),
 	m_windowHeight( 0 ),
 	m_initialized( false ),
-	m_lock(),
-	m_windowStatusChange(),
+	m_pluginLock(),
 	m_inputs( NULL ),
 	m_outputs( NULL ),
 	m_midiEvents(),
 	m_bpm( 0 ),
 	m_currentSamplePos( 0 )
 {
-	pthread_mutex_init( &m_lock, NULL );
-	pthread_cond_init( &m_windowStatusChange, NULL );
+	pthread_mutex_init( &m_pluginLock, NULL );
+
+	__plugin = this;
+
+	// process until we have loaded the plugin
+	while( 1 )
+        {
+		message m = receiveMessage();
+		processMessage( m );
+		if( m.id == IdVstLoadPlugin || m.id == IdQuit )
+		{
+			break;
+		}
+	}
 }
 
 
 
 
-remoteVstPlugin::~remoteVstPlugin()
+RemoteVstPlugin::~RemoteVstPlugin()
 {
 	if( m_window != NULL )
 	{
-		if( __threadingModel == TraditionalThreading )
-		{
-			// notify GUI-thread
-			if( !PostThreadMessage( __threadID, WM_USER,
-							ClosePlugin, 0 ) )
-			{
-				//lvsMessage( "could not post message to gui thread" );
-			}
-			pthread_mutex_lock( &m_lock );
-			pthread_cond_wait( &m_windowStatusChange, &m_lock );
-		}
-		m_plugin->dispatcher( m_plugin, effEditClose, 0, 0, NULL, 0.0 );
+		pluginDispatch( effEditClose );
 #ifdef LMMS_BUILD_LINUX
 		CloseWindow( m_window );
 #endif
@@ -305,14 +335,13 @@ remoteVstPlugin::~remoteVstPlugin()
 	delete[] m_inputs;
 	delete[] m_outputs;
 
-	pthread_mutex_destroy( &m_lock );
-	pthread_cond_destroy( &m_windowStatusChange );
+	pthread_mutex_destroy( &m_pluginLock );
 }
 
 
 
 
-bool remoteVstPlugin::processMessage( const message & _m )
+bool RemoteVstPlugin::processMessage( const message & _m )
 {
 	switch( _m.id )
 	{
@@ -350,8 +379,18 @@ bool remoteVstPlugin::processMessage( const message & _m )
 			getParameterProperties( _m.getInt() );
 			break;
 
+		case IdSaveSettingsToFile:
+			saveChunkToFile( _m.getString() );
+			sendMessage( IdSaveSettingsToFile );
+			break;
+
+		case IdLoadSettingsFromFile:
+			loadChunkFromFile( _m.getString( 0 ), _m.getInt( 1 ) );
+			sendMessage( IdLoadSettingsFromFile );
+			break;
+
 		default:
-			return remotePluginClient::processMessage( _m );
+			return RemotePluginClient::processMessage( _m );
 	}
 	return true;
 }
@@ -359,7 +398,7 @@ bool remoteVstPlugin::processMessage( const message & _m )
 
 
 
-void remoteVstPlugin::init( const std::string & _plugin_file )
+void RemoteVstPlugin::init( const std::string & _plugin_file )
 {
 	if( load( _plugin_file ) == false )
 	{
@@ -373,27 +412,13 @@ void remoteVstPlugin::init( const std::string & _plugin_file )
 	/* i comment this out because it breaks dfx Geometer
 	 * looks like we cant set programs for it
 	 *
-	m_plugin->dispatcher( m_plugin, effSetProgram, 0, 0, NULL, 0.0f); */
+	pluginDispatch( effSetProgram, 0, 0 ); */
 	// request rate and blocksize
 
-	m_plugin->dispatcher( m_plugin, effMainsChanged, 0, 1, NULL, 0.0f );
+	pluginDispatch( effMainsChanged, 0, 1 );
 
 	debugMessage( "creating editor\n" );
-	if( __threadingModel == TraditionalThreading )
-	{
-		debugMessage( "creating GUI thread\n" );
-		if( !CreateThread( NULL, 0, guiEventLoop, this, 0, NULL ) )
-		{
-			debugMessage( "init(): could not create GUI thread\n" );
-			return;
-		}
-		pthread_mutex_lock( &m_lock );
-		pthread_cond_wait( &m_windowStatusChange, &m_lock );
-	}
-	else
-	{
-		initEditor();
-	}
+	initEditor();
 	debugMessage( "editor successfully created\n" );
 
 
@@ -421,7 +446,7 @@ void remoteVstPlugin::init( const std::string & _plugin_file )
 
 
 
-void remoteVstPlugin::initEditor( void )
+void RemoteVstPlugin::initEditor()
 {
 	if( !( m_plugin->flags & effFlagsHasEditor ) )
 	{
@@ -454,7 +479,6 @@ void remoteVstPlugin::initEditor( void )
 		return;
 	}
 
-
 #ifdef LMMS_BUILD_LINUX
 	m_window = CreateWindowEx( 0, "LVSL", m_shortName.c_str(),
 			       ( WS_OVERLAPPEDWINDOW | WS_THICKFRAME ) &
@@ -476,10 +500,10 @@ void remoteVstPlugin::initEditor( void )
 	}
 
 
-	m_plugin->dispatcher( m_plugin, effEditOpen, 0, 0, m_window, 0 );
+	pluginDispatch( effEditOpen, 0, 0, m_window );
 
 	ERect * er;
-	m_plugin->dispatcher( m_plugin, effEditGetRect, 0, 0, &er, 0 );
+	pluginDispatch( effEditGetRect, 0, 0, &er );
 
 	m_windowWidth = er->right - er->left;
 	m_windowHeight = er->bottom - er->top;
@@ -487,7 +511,7 @@ void remoteVstPlugin::initEditor( void )
 	SetWindowPos( m_window, 0, 0, 0, m_windowWidth + 8,
 			m_windowHeight + 26, SWP_NOACTIVATE |
 						SWP_NOMOVE | SWP_NOZORDER );
-	m_plugin->dispatcher( m_plugin, effEditTop, 0, 0, NULL, 0 );
+	pluginDispatch( effEditTop );
 
 	ShowWindow( m_window, SW_SHOWNORMAL );
 	UpdateWindow( m_window );
@@ -500,10 +524,9 @@ void remoteVstPlugin::initEditor( void )
 
 
 
-bool remoteVstPlugin::load( const std::string & _plugin_file )
+bool RemoteVstPlugin::load( const std::string & _plugin_file )
 {
-	if( ( m_libInst = LoadLibrary( _plugin_file.c_str() ) ) ==
-								NULL )
+	if( ( m_libInst = LoadLibrary( _plugin_file.c_str() ) ) == NULL )
 	{
 		return false;
 	}
@@ -551,32 +574,15 @@ bool remoteVstPlugin::load( const std::string & _plugin_file )
 	}
 
 
-	char id[8];
-	sprintf( id, "%c%c%c%c\n", ((char *)&m_plugin->uniqueID)[3],
+	char id[5];
+	sprintf( id, "%c%c%c%c", ((char *)&m_plugin->uniqueID)[3],
 					 ((char *)&m_plugin->uniqueID)[2],
 					 ((char *)&m_plugin->uniqueID)[1],
 					 ((char *)&m_plugin->uniqueID)[0] );
+	id[4] = 0;
 	sendMessage( message( IdVstPluginUniqueID ).addString( id ) );
 
-	// switch to appropriate threading model
-	switch( m_plugin->uniqueID )
-	{
-		// some plugins require processing to happen from within
-		// another thread
-		case CCONST( 'z', '3', 't', 'a' ):	// z3ta+
-		case CCONST( 'T', 'C', '_', 'S' ):	// Cygnus
-		case CCONST( 'S', 'y', 't', 'r' ):	// Sytrus
-			debugMessage( "switching to splitted threading "
-								"model\n" );
-			__threadingModel = SplittedThreading;
-			break;
-
-		default:
-			break;
-	}
-
-
-	m_plugin->dispatcher( m_plugin, effOpen, 0, 0, 0, 0 );
+	pluginDispatch( effOpen );
 
 	return true;
 }
@@ -584,7 +590,7 @@ bool remoteVstPlugin::load( const std::string & _plugin_file )
 
 
 
-void remoteVstPlugin::process( const sampleFrame * _in, sampleFrame * _out )
+void RemoteVstPlugin::process( const sampleFrame * _in, sampleFrame * _out )
 {
 	// first we gonna post all MIDI-events we enqueued so far
 	if( m_midiEvents.size() )
@@ -602,8 +608,7 @@ void remoteVstPlugin::process( const sampleFrame * _in, sampleFrame * _out )
 		events->reserved = 0;
 		events->numEvents = m_midiEvents.size();
 		int idx = 0;
-		for( std::list<VstMidiEvent>::iterator it =
-							m_midiEvents.begin();
+		for( VstMidiEventList::iterator it = m_midiEvents.begin();
 					it != m_midiEvents.end(); ++it, ++idx )
 		{
 			memcpy( &vme[idx], &*it, sizeof( VstMidiEvent ) );
@@ -611,8 +616,7 @@ void remoteVstPlugin::process( const sampleFrame * _in, sampleFrame * _out )
 		}
 
 		m_midiEvents.clear();
-		m_plugin->dispatcher( m_plugin, effProcessEvents, 0, 0, events,
-									0.0f );
+		pluginDispatch( effProcessEvents, 0, 0, events );
 	}
 
 	// now we're ready to fetch sound from VST-plugin
@@ -650,7 +654,7 @@ void remoteVstPlugin::process( const sampleFrame * _in, sampleFrame * _out )
 
 
 
-void remoteVstPlugin::processMidiEvent( const midiEvent & _event,
+void RemoteVstPlugin::processMidiEvent( const midiEvent & _event,
 							const f_cnt_t _offset )
 {
 	VstMidiEvent event;
@@ -685,11 +689,11 @@ void remoteVstPlugin::processMidiEvent( const midiEvent & _event,
 
 
 
-const char * remoteVstPlugin::pluginName( void ) const
+const char * RemoteVstPlugin::pluginName()
 {
 	static char buf[32];
 	buf[0] = 0;
-	m_plugin->dispatcher( m_plugin, effGetEffectName, 0, 0, buf, 0.0f );
+	pluginDispatch( effGetEffectName, 0, 0, buf );
 	buf[31] = 0;
 	return buf;
 }
@@ -697,11 +701,11 @@ const char * remoteVstPlugin::pluginName( void ) const
 
 
 
-const char * remoteVstPlugin::pluginVendorString( void ) const
+const char * RemoteVstPlugin::pluginVendorString()
 {
 	static char buf[64];
 	buf[0] = 0;
-	m_plugin->dispatcher( m_plugin, effGetVendorString, 0, 0, buf, 0.0f );
+	pluginDispatch( effGetVendorString, 0, 0, buf );
 	buf[63] = 0;
 	return buf;
 }
@@ -709,11 +713,11 @@ const char * remoteVstPlugin::pluginVendorString( void ) const
 
 
 
-const char * remoteVstPlugin::pluginProductString( void ) const
+const char * RemoteVstPlugin::pluginProductString()
 {
 	static char buf[64];
 	buf[0] = 0;
-	m_plugin->dispatcher( m_plugin, effGetProductString, 0, 0, buf, 0.0f );
+	pluginDispatch( effGetProductString, 0, 0, buf );
 	buf[63] = 0;
 	return buf;
 }
@@ -721,15 +725,14 @@ const char * remoteVstPlugin::pluginProductString( void ) const
 
 
 
-void remoteVstPlugin::getParameterDump( void )
+void RemoteVstPlugin::getParameterDump()
 {
 	VstParameterProperties vst_props;
 	message m( IdVstParameterDump );
 	m.addInt( m_plugin->numParams );
 	for( int i = 0; i < m_plugin->numParams; ++i )
 	{
-		m_plugin->dispatcher( m_plugin, effGetParameterProperties, i,
-							0, &vst_props, 0.0f );
+		pluginDispatch( effGetParameterProperties, i, 0, &vst_props );
 		m.addInt( i );
 		m.addString( vst_props.shortLabel );
 		m.addFloat( m_plugin->getParameter( m_plugin, i ) );
@@ -740,7 +743,7 @@ void remoteVstPlugin::getParameterDump( void )
 
 
 
-void remoteVstPlugin::setParameterDump( const message & _m )
+void RemoteVstPlugin::setParameterDump( const message & _m )
 {
 	const int n = _m.getInt( 0 );
 	const int params = ( n > m_plugin->numParams ) ?
@@ -748,7 +751,7 @@ void remoteVstPlugin::setParameterDump( const message & _m )
 	int p = 0;
 	for( int i = 0; i < params; ++i )
 	{
-		vstParameterDumpItem item;
+		VstParameterDumpItem item;
 		item.index = _m.getInt( ++p );
 		item.shortLabel = _m.getString( ++p );
 		item.value = _m.getFloat( ++p );
@@ -759,11 +762,10 @@ void remoteVstPlugin::setParameterDump( const message & _m )
 
 
 
-void remoteVstPlugin::getParameterProperties( const int _idx )
+void RemoteVstPlugin::getParameterProperties( const int _idx )
 {
 	VstParameterProperties p;
-	m_plugin->dispatcher( m_plugin, effGetParameterProperties, _idx, 0,
-								&p, 0.0f );
+	pluginDispatch( effGetParameterProperties, _idx, 0, &p );
 	message m( IdVstParameterProperties );
 	m.addString( p.label );
 	m.addString( p.shortLabel );
@@ -791,14 +793,67 @@ void remoteVstPlugin::getParameterProperties( const int _idx )
 
 
 
-void remoteVstPlugin::updateInOutCount( void )
+void RemoteVstPlugin::saveChunkToFile( const std::string & _file )
+{
+	if( m_plugin->flags & 32 )
+	{
+		void * chunk = NULL;
+		const int len = pluginDispatch( 23, 0, 0, &chunk );
+		if( len > 0 )
+		{
+			int fd = open( _file.c_str(), O_WRONLY | O_BINARY );
+			write( fd, chunk, len );
+			close( fd );
+		}
+	}
+}
+
+
+
+
+void RemoteVstPlugin::loadChunkFromFile( const std::string & _file, int _len )
+{
+	char * buf = NULL;
+
+	void * chunk = NULL;
+	// various plugins need this in order to not crash when setting
+	// chunk (also we let the plugin allocate "safe" memory this way)
+	const int actualLen = pluginDispatch( 23, 0, 0, &chunk );
+
+	// allocated buffer big enough?
+	if( _len > actualLen )
+	{
+		// no, then manually allocate a buffer
+		buf = new char[_len];
+		chunk = buf;
+	}
+
+	const int fd = open( _file.c_str(), O_RDONLY | O_BINARY );
+	read( fd, chunk, _len );
+	close( fd );
+	pluginDispatch( 24, 0, _len, chunk );
+
+	delete[] buf;
+}
+
+
+
+
+void RemoteVstPlugin::updateInOutCount()
 {
 	delete[] m_inputs;
 	delete[] m_outputs;
 
+	m_inputs = NULL;
+	m_outputs = NULL;
+
 	setInputCount( inputCount() );
 	setOutputCount( outputCount() );
 
+	char buf[64];
+	sprintf( buf, "inputs: %d  output: %d\n", inputCount(), outputCount() );
+	debugMessage( buf );
+
 	if( inputCount() > 0 )
 	{
 		m_inputs = new float * [inputCount()];
@@ -827,7 +882,7 @@ void remoteVstPlugin::updateInOutCount( void )
  * - audioMasterGetDirectory: return either VST-plugin-dir or LMMS-workingdir
  * - audioMasterOpenFileSelector: show QFileDialog?
  */
-VstIntPtr remoteVstPlugin::hostCallback( AEffect * _effect, VstInt32 _opcode,
+VstIntPtr RemoteVstPlugin::hostCallback( AEffect * _effect, VstInt32 _opcode,
 					VstInt32 _index, VstIntPtr _value,
 						void * _ptr, float _opt )
 {
@@ -838,6 +893,12 @@ VstIntPtr remoteVstPlugin::hostCallback( AEffect * _effect, VstInt32 _opcode,
 	SHOW_CALLBACK( buf );
 #endif
 
+	// workaround for early callbacks by some plugins
+	if( __plugin && __plugin->m_plugin == NULL )
+	{
+		__plugin->m_plugin = _effect;
+	}
+
 	switch( _opcode )
 	{
 		case audioMasterAutomate:
@@ -860,8 +921,8 @@ VstIntPtr remoteVstPlugin::hostCallback( AEffect * _effect, VstInt32 _opcode,
 			SHOW_CALLBACK ("amc: audioMasterIdle\n" );
 			// call application idle routine (this will
 			// call effEditIdle for all open editors too) 
-			_effect->dispatcher( _effect, effEditIdle, 0, 0, NULL,
-									0.0f );
+			PostThreadMessage( __GuiThreadID,
+						WM_USER, GiveIdle, 0 );
 			return 0;
 
 		case audioMasterPinConnected:		
@@ -1011,14 +1072,10 @@ VstIntPtr remoteVstPlugin::hostCallback( AEffect * _effect, VstInt32 _opcode,
 
 		case audioMasterGetSampleRate:
 			SHOW_CALLBACK( "amc: audioMasterGetSampleRate\n" );
-			_effect->dispatcher( _effect, effSetSampleRate,
-				0, 0, NULL, (float)__plugin->sampleRate() );
 			return __plugin->sampleRate();
 
 		case audioMasterGetBlockSize:
 			SHOW_CALLBACK( "amc: audioMasterGetBlockSize\n" );
-			_effect->dispatcher( _effect, effSetBlockSize,
-					0, __plugin->bufferSize(), NULL, 0 );
 
 			return __plugin->bufferSize();
 
@@ -1120,8 +1177,8 @@ VstIntPtr remoteVstPlugin::hostCallback( AEffect * _effect, VstInt32 _opcode,
 		case audioMasterUpdateDisplay:
 			SHOW_CALLBACK( "amc: audioMasterUpdateDisplay\n" );
 			// something has changed, update 'multi-fx' display
-			_effect->dispatcher( _effect, effEditIdle, 0, 0, NULL,
-									0.0f );
+			PostThreadMessage( __GuiThreadID,
+						WM_USER, GiveIdle, 0 );
 			return 0;
 
 #if kVstVersion > 2
@@ -1154,50 +1211,38 @@ VstIntPtr remoteVstPlugin::hostCallback( AEffect * _effect, VstInt32 _opcode,
 
 
 
-DWORD WINAPI remoteVstPlugin::processingThread( LPVOID _param )
+DWORD WINAPI RemoteVstPlugin::processingThread( LPVOID _param )
 {
-	remoteVstPlugin * _this = static_cast<remoteVstPlugin *>( _param );
+	RemoteVstPlugin * _this = static_cast<RemoteVstPlugin *>( _param );
 
-	remotePluginClient::message m;
+	RemotePluginClient::message m;
 	while( ( m = _this->receiveMessage() ).id != IdQuit )
         {
-		VstThreadingModel oldModel = __threadingModel;
-#ifndef LMMS_BUILD_LINUX
-		if( __threadingModel == TraditionalThreading ||
-					m.id == IdStartProcessing )
-#endif
+		if( m.id == IdStartProcessing || m.id == IdMidiEvent )
 		{
 			_this->processMessage( m );
 		}
-#ifndef LMMS_BUILD_LINUX
 		else
 		{
-			PostThreadMessage( __threadID,
+			PostThreadMessage( __GuiThreadID,
 					WM_USER,
 					ProcessPluginMessage,
 					(LPARAM) new message( m ) );
 		}
-#endif
-
-		// did we load plugin and recognized a plugin which requires
-		// a different threading model?
-		if( m.id == IdVstLoadPlugin || __threadingModel != oldModel )
-		{
-			// then get out of here
-			return 0;
-		}
 	}
 
+	// notify GUI thread about shutdown
+	PostThreadMessage( __GuiThreadID, WM_USER, ClosePlugin, 0 );
+
 	return 0;
 }
 
 
 
 
-DWORD WINAPI remoteVstPlugin::guiEventLoop( LPVOID _param )
+DWORD WINAPI RemoteVstPlugin::guiEventLoop( LPVOID _param )
 {
-	remoteVstPlugin * _this = static_cast<remoteVstPlugin *>( _param );
-	__threadID = GetCurrentThreadId();
+	RemoteVstPlugin * _this = static_cast<RemoteVstPlugin *>( _param );
 
 	HMODULE hInst = GetModuleHandle( NULL );
 	if( hInst == NULL )
@@ -1207,13 +1252,6 @@ DWORD WINAPI remoteVstPlugin::guiEventLoop( LPVOID _param )
 		return -1;
 	}
 
-	if( __threadingModel == TraditionalThreading )
-	{
-		_this->initEditor();
-		pthread_cond_signal( &_this->m_windowStatusChange );
-	}
-
-
 	HWND timerWindow = CreateWindowEx( 0, "LVSL", "dummy",
 						0, 0, 0, 0, 0, NULL, NULL,
 								hInst, NULL );
@@ -1231,9 +1269,7 @@ DWORD WINAPI remoteVstPlugin::guiEventLoop( LPVOID _param )
 		if( msg.message == WM_TIMER && _this->isInitialized() )
 		{
 			// give plugin some idle-time for GUI-update
-			_this->m_plugin->dispatcher( _this->m_plugin,
-							effEditIdle, 0, 0,
-								NULL, 0 );
+			_this->pluginDispatch( effEditIdle );
 		}
 		else if( msg.message == WM_USER )
 		{
@@ -1247,6 +1283,10 @@ DWORD WINAPI remoteVstPlugin::guiEventLoop( LPVOID _param )
 					break;
 				}
 
+				case GiveIdle:
+					_this->pluginDispatch( effEditIdle );
+					break;
+
 				case ClosePlugin:
 					quit = true;
 					break;
@@ -1257,11 +1297,6 @@ DWORD WINAPI remoteVstPlugin::guiEventLoop( LPVOID _param )
 		}
 	}
 
-	if( __threadingModel == TraditionalThreading )
-	{
-		pthread_cond_signal( &_this->m_windowStatusChange );
-	}
-
 	return 0;
 }
 
@@ -1288,39 +1323,25 @@ int main( int _argc, char * * _argv )
 	struct sched_param sparam;
 	sparam.sched_priority = ( sched_get_priority_max( SCHED_FIFO ) +
 				sched_get_priority_min( SCHED_FIFO ) ) / 2;
-	if( sched_setscheduler( 0, SCHED_FIFO, &sparam ) == -1 )
-	{
-		fprintf( stderr, "could not set realtime priority for "
-							"remoteVstPlugin\n" );
-	}
+	sched_setscheduler( 0, SCHED_FIFO, &sparam );
 #endif
 #endif
 
-	__plugin = new remoteVstPlugin( atoi( _argv[1] ), atoi( _argv[2] ) );
-
-	// process until we have loaded the plugin
-	remoteVstPlugin::processingThread( __plugin );
+	// constructor automatically will process messages until it receives
+	// a IdVstLoadPlugin message and processes it
+	__plugin = new RemoteVstPlugin( atoi( _argv[1] ), atoi( _argv[2] ) );
 
 	if( __plugin->isInitialized() )
 	{
-		if( __threadingModel == TraditionalThreading )
-		{
-			remoteVstPlugin::processingThread( __plugin );
-		}
-		else
-		{
-			__threadID = GetCurrentThreadId();
-
-			if( CreateThread( NULL, 0,
-					remoteVstPlugin::processingThread,
+		__GuiThreadID = GetCurrentThreadId();
+		if( CreateThread( NULL, 0, RemoteVstPlugin::processingThread,
 						__plugin, 0, NULL ) == NULL )
-			{
-				__plugin->debugMessage( "could not create "
+		{
+			__plugin->debugMessage( "could not create "
 							"processingThread\n" );
-				return -1;
-			}
-			remoteVstPlugin::guiEventLoop( __plugin );
+			return -1;
 		}
+		RemoteVstPlugin::guiEventLoop( __plugin );
 	}
 
 
