@@ -2,7 +2,7 @@
  * automation_pattern.cpp - implementation of class automationPattern which
  *                          holds dynamic values
  *
- * Copyright (c) 2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2008-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * Copyright (c) 2006-2008 Javier Serrano Polo <jasp00/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
@@ -33,7 +33,7 @@
 #include "automation_pattern_view.h"
 #include "automation_editor.h"
 #include "automation_track.h"
-#include "project_journal.h"
+#include "ProjectJournal.h"
 #include "bb_track_container.h"
 #include "song.h"
 
@@ -80,7 +80,7 @@ automationPattern::~automationPattern()
 
 
 
-void automationPattern::addObject( automatableModel * _obj, bool _search_dup )
+void automationPattern::addObject( AutomatableModel * _obj, bool _search_dup )
 {
 	bool addIt = true;
 
@@ -117,15 +117,15 @@ void automationPattern::addObject( automatableModel * _obj, bool _search_dup )
 
 
 
-const automatableModel * automationPattern::firstObject( void ) const
+const AutomatableModel * automationPattern::firstObject() const
 {
-	automatableModel * m;
+	AutomatableModel * m;
 	if( !m_objects.isEmpty() && ( m = m_objects.first() ) != NULL )
 	{
 		return m;
 	}
 
-	static floatModel _fm( 0, 0, 1, 0.001 );
+	static FloatModel _fm( 0, 0, 1, 0.001 );
 	return &_fm;
 }
 
@@ -134,14 +134,14 @@ const automatableModel * automationPattern::firstObject( void ) const
 
 
 //TODO: Improve this
-midiTime automationPattern::length( void ) const
+midiTime automationPattern::length() const
 {
-	tick max_length = 0;
+	tick_t max_length = 0;
 
 	for( timeMap::const_iterator it = m_timeMap.begin();
 						it != m_timeMap.end(); ++it )
 	{
-		max_length = qMax<tick>( max_length, it.key() );
+		max_length = qMax<tick_t>( max_length, it.key() );
 	}
 	return midiTime( qMax( midiTime( max_length ).getTact() + 1, 1 ), 0 );
 }
@@ -273,6 +273,7 @@ float automationPattern::valueAt( const midiTime & _time ) const
 void automationPattern::saveSettings( QDomDocument & _doc, QDomElement & _this )
 {
 	_this.setAttribute( "pos", startPosition() );
+	_this.setAttribute( "len", trackContentObject::length() );
 	_this.setAttribute( "name", name() );
 
 	for( timeMap::const_iterator it = m_timeMap.begin();
@@ -337,14 +338,18 @@ void automationPattern::loadSettings( const QDomElement & _this )
 			}
 		}
 	}
-
-	changeLength( length() );
+	int len = _this.attribute( "len" ).toInt();
+	if( len <= 0 )
+	{
+		len = length();
+	}
+	changeLength( len );
 }
 
 
 
 
-const QString automationPattern::name( void ) const
+const QString automationPattern::name() const
 {
 	if( !trackContentObject::name().isEmpty() )
 	{
@@ -390,7 +395,7 @@ trackContentObjectView * automationPattern::createView( trackView * _tv )
 
 
 
-bool automationPattern::isAutomated( const automatableModel * _m )
+bool automationPattern::isAutomated( const AutomatableModel * _m )
 {
 	trackContainer::trackList l = engine::getSong()->tracks() +
 				engine::getBBTrackContainer()->tracks();
@@ -430,7 +435,7 @@ bool automationPattern::isAutomated( const automatableModel * _m )
 
 
 automationPattern * automationPattern::globalAutomationPattern(
-							automatableModel * _m )
+							AutomatableModel * _m )
 {
 	automationTrack * t = engine::getSong()->globalAutomationTrack();
 	track::tcoVector v = t->getTCOs();
@@ -459,7 +464,7 @@ automationPattern * automationPattern::globalAutomationPattern(
 
 
 
-void automationPattern::resolveAllIDs( void )
+void automationPattern::resolveAllIDs()
 {
 	trackContainer::trackList l = engine::getSong()->tracks() +
 				engine::getBBTrackContainer()->tracks();
@@ -478,14 +483,14 @@ void automationPattern::resolveAllIDs( void )
 					dynamic_cast<automationPattern *>( *j );
 				if( a )
 				{
-	for( QVector<jo_id_t>::iterator k = a->m_idsToResolve.begin();
+	for( QVector<jo_id_t>::Iterator k = a->m_idsToResolve.begin();
 					k != a->m_idsToResolve.end(); ++k )
 	{
-		journallingObject * o = engine::getProjectJournal()->
-						getJournallingObject( *k );
-		if( o && dynamic_cast<automatableModel *>( o ) )
+		JournallingObject * o = engine::projectJournal()->
+										journallingObject( *k );
+		if( o && dynamic_cast<AutomatableModel *>( o ) )
 		{
-			a->addObject( dynamic_cast<automatableModel *>( o ), false );
+			a->addObject( dynamic_cast<AutomatableModel *>( o ), false );
 		}
 	}
 	a->m_idsToResolve.clear();
@@ -499,7 +504,7 @@ void automationPattern::resolveAllIDs( void )
 
 
 
-void automationPattern::clear( void )
+void automationPattern::clear()
 {
 	const float val = firstObject()->value<float>();
 	m_timeMap.clear();
@@ -515,7 +520,7 @@ void automationPattern::clear( void )
 
 
 
-void automationPattern::openInAutomationEditor( void )
+void automationPattern::openInAutomationEditor()
 {
 	engine::getAutomationEditor()->setCurrentPattern( this );
 	engine::getAutomationEditor()->parentWidget()->show();
