@@ -3,8 +3,8 @@
 /*
  * engine.cpp - implementation of LMMS' engine-system
  *
- * Copyright (c) 2006-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
- * 
+ * Copyright (c) 2006-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or
@@ -30,17 +30,19 @@
 #include "bb_editor.h"
 #include "bb_track_container.h"
 #include "config_mgr.h"
-#include "controller_rack_view.h"
-#include "fx_mixer.h"
-#include "fx_mixer_view.h"
+#include "ControllerRackView.h"
+#include "FxMixer.h"
+#include "FxMixerView.h"
+#include "InstrumentTrack.h"
 #include "ladspa_2_lmms.h"
-#include "main_window.h"
+#include "MainWindow.h"
 #include "mixer.h"
 #include "pattern.h"
 #include "piano_roll.h"
 #include "preset_preview_play_handle.h"
-#include "project_journal.h"
+#include "ProjectJournal.h"
 #include "project_notes.h"
+#include "Plugin.h"
 #include "song_editor.h"
 #include "song.h"
 
@@ -49,9 +51,9 @@ bool engine::s_hasGUI = true;
 bool engine::s_suppressMessages = false;
 float engine::s_framesPerTick;
 mixer * engine::s_mixer = NULL;
-fxMixer * engine::s_fxMixer = NULL;
-fxMixerView * engine::s_fxMixerView = NULL;
-mainWindow * engine::s_mainWindow = NULL;
+FxMixer * engine::s_fxMixer = NULL;
+FxMixerView * engine::s_fxMixerView = NULL;
+MainWindow * engine::s_mainWindow = NULL;
 bbTrackContainer * engine::s_bbTrackContainer = NULL;
 song * engine::s_song = NULL;
 songEditor * engine::s_songEditor = NULL;
@@ -59,10 +61,10 @@ automationEditor * engine::s_automationEditor = NULL;
 bbEditor * engine::s_bbEditor = NULL;
 pianoRoll * engine::s_pianoRoll = NULL;
 projectNotes * engine::s_projectNotes = NULL;
-projectJournal * engine::s_projectJournal = NULL;
+ProjectJournal * engine::s_projectJournal = NULL;
 ladspa2LMMS * engine::s_ladspaManager = NULL;
-dummyTrackContainer * engine::s_dummyTC = NULL;
-controllerRackView * engine::s_controllerRackView = NULL;
+DummyTrackContainer * engine::s_dummyTC = NULL;
+ControllerRackView * engine::s_controllerRackView = NULL;
 QMap<QString, QString> engine::s_pluginFileHandling;
 
 
@@ -74,24 +76,24 @@ void engine::init( const bool _has_gui )
 
 	initPluginFileHandling();
 
-	s_projectJournal = new projectJournal;
+	s_projectJournal = new ProjectJournal;
 	s_mixer = new mixer;
 	s_song = new song;
-	s_fxMixer = new fxMixer;
+	s_fxMixer = new FxMixer;
 	s_bbTrackContainer = new bbTrackContainer;
 
 	s_ladspaManager = new ladspa2LMMS;
 
-	s_projectJournal->setJournalling( TRUE );
+	s_projectJournal->setJournalling( true );
 
 	s_mixer->initDevices();
 
 	if( s_hasGUI )
 	{
-		s_mainWindow = new mainWindow;
+		s_mainWindow = new MainWindow;
 		s_songEditor = new songEditor( s_song, s_songEditor );
-		s_fxMixerView = new fxMixerView;
-		s_controllerRackView = new controllerRackView;
+		s_fxMixerView = new FxMixerView;
+		s_controllerRackView = new ControllerRackView;
 		s_projectNotes = new projectNotes;
 		s_bbEditor = new bbEditor( s_bbTrackContainer );
 		s_pianoRoll = new pianoRoll;
@@ -101,7 +103,7 @@ void engine::init( const bool _has_gui )
 	}
 
 	presetPreviewPlayHandle::init();
-	s_dummyTC = new dummyTrackContainer;
+	s_dummyTC = new DummyTrackContainer;
 
 	s_mixer->startProcessing();
 }
@@ -109,47 +111,36 @@ void engine::init( const bool _has_gui )
 
 
 
-void engine::destroy( void )
+void engine::destroy()
 {
 	s_mixer->stopProcessing();
 
-	delete s_projectNotes;
-	s_projectNotes = NULL;
-	delete s_songEditor;
-	s_songEditor = NULL;
-	delete s_bbEditor;
-	s_bbEditor = NULL;
-	delete s_pianoRoll;
-	s_pianoRoll = NULL;
-	delete s_automationEditor;
-	s_automationEditor = NULL;
-
-	delete s_fxMixerView;
-	s_fxMixerView = NULL;
+	deleteHelper( &s_projectNotes );
+	deleteHelper( &s_songEditor );
+	deleteHelper( &s_bbEditor );
+	deleteHelper( &s_pianoRoll );
+	deleteHelper( &s_automationEditor );
+	deleteHelper( &s_fxMixerView );
 
 	presetPreviewPlayHandle::cleanup();
-	instrumentTrackView::cleanupWindowPool();
+	InstrumentTrackView::cleanupWindowPool();
 
 	s_song->clearProject();
-	delete s_bbTrackContainer;
-	s_bbTrackContainer = NULL;
-	delete s_dummyTC;
-	s_dummyTC = NULL;
 
-	delete s_mixer;
-	s_mixer = NULL;
-	delete s_fxMixer;
-	s_fxMixer = NULL;
+	deleteHelper( &s_bbTrackContainer );
+	deleteHelper( &s_dummyTC );
 
-	delete s_ladspaManager;
+	deleteHelper( &s_mixer );
+	deleteHelper( &s_fxMixer );
+
+	deleteHelper( &s_ladspaManager );
 
 	//delete configManager::inst();
-	delete s_projectJournal;
-	s_projectJournal = NULL;
+	deleteHelper( &s_projectJournal );
+
 	s_mainWindow = NULL;
 
-	delete s_song;
-	s_song = NULL;
+	deleteHelper( &s_song );
 
 	delete configManager::inst();
 }
@@ -157,7 +148,7 @@ void engine::destroy( void )
 
 
 
-void engine::updateFramesPerTick( void )
+void engine::updateFramesPerTick()
 {
 	s_framesPerTick = s_mixer->processingSampleRate() * 60.0f * 4 /
 				DefaultTicksPerTact / s_song->getTempo();
@@ -166,15 +157,14 @@ void engine::updateFramesPerTick( void )
 
 
 
-void engine::initPluginFileHandling( void )
+void engine::initPluginFileHandling()
 {
-	QVector<plugin::descriptor> pluginDescriptors;
-	plugin::getDescriptorsOfAvailPlugins( pluginDescriptors );
-	for( QVector<plugin::descriptor>::iterator it =
-						pluginDescriptors.begin();
-					it != pluginDescriptors.end(); ++it )
+	Plugin::DescriptorList pluginDescriptors;
+	Plugin::getDescriptorsOfAvailPlugins( pluginDescriptors );
+	for( Plugin::DescriptorList::ConstIterator it = pluginDescriptors.begin();
+										it != pluginDescriptors.end(); ++it )
 	{
-		if( it->type == plugin::Instrument )
+		if( it->type == Plugin::Instrument )
 		{
 			const QStringList & ext =
 				QString( it->supportedFileTypes ).
