@@ -1,7 +1,7 @@
 /*
  * main.cpp - just main.cpp which is starting up app...
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -22,8 +22,8 @@
  *
  */
 
-
 #include "lmmsconfig.h"
+#include "lmmsversion.h"
 
 #include <QtCore/QFileInfo>
 #include <QtCore/QLocale>
@@ -55,10 +55,10 @@
 #include "config_mgr.h"
 #include "embed.h"
 #include "engine.h"
-#include "import_filter.h"
 #include "lmms_style.h"
-#include "main_window.h"
-#include "project_renderer.h"
+#include "ImportFilter.h"
+#include "MainWindow.h"
+#include "ProjectRenderer.h"
 #include "song.h"
 
 #warning TODO: move somewhere else
@@ -117,9 +117,9 @@ int main( int argc, char * * argv )
 
 
 	mixer::qualitySettings qs( mixer::qualitySettings::Mode_HighQuality );
-	projectRenderer::outputSettings os( 44100, false, 160,
-						projectRenderer::Depth_16Bit );
-	projectRenderer::ExportFileFormats eff = projectRenderer::WaveFile;
+	ProjectRenderer::OutputSettings os( 44100, false, 160,
+						ProjectRenderer::Depth_16Bit );
+	ProjectRenderer::ExportFileFormats eff = ProjectRenderer::WaveFile;
 
 
 	for( int i = 1; i < argc; ++i )
@@ -207,12 +207,12 @@ int main( int argc, char * * argv )
 			const QString ext = QString( argv[i + 1] );
 			if( ext == "wav" )
 			{
-				eff = projectRenderer::WaveFile;
+				eff = ProjectRenderer::WaveFile;
 			}
 #ifdef LMMS_HAVE_OGGVORBIS
 			else if( ext == "ogg" )
 			{
-				eff = projectRenderer::OggFile;
+				eff = ProjectRenderer::OggFile;
 			}
 #endif
 			else
@@ -417,26 +417,25 @@ int main( int argc, char * * argv )
 		// we try to load given file
 		if( !file_to_load.isEmpty() )
 		{
-			engine::getMainWindow()->show();
+			engine::mainWindow()->show();
 			if( fullscreen )
 			{
-				engine::getMainWindow()->showMaximized();
+				engine::mainWindow()->showMaximized();
 			}
 			engine::getSong()->loadProject( file_to_load );
 		}
 		else if( !file_to_import.isEmpty() )
 		{
-			importFilter::import( file_to_import,
-							engine::getSong() );
+			ImportFilter::import( file_to_import, engine::getSong() );
 			if( exit_after_import )
 			{
 				return 0;
 			}
 
-			engine::getMainWindow()->show();
+			engine::mainWindow()->show();
 			if( fullscreen )
 			{
-				engine::getMainWindow()->showMaximized();
+				engine::mainWindow()->showMaximized();
 			}
 		}
 		else
@@ -445,10 +444,10 @@ int main( int argc, char * * argv )
 
 			// [Settel] workaround: showMaximized() doesn't work with
 			// FVWM2 unless the window is already visible -> show() first
-			engine::getMainWindow()->show();
+			engine::mainWindow()->show();
 			if( fullscreen )
 			{
-				engine::getMainWindow()->showMaximized();
+				engine::mainWindow()->showMaximized();
 			}
 		}
 	}
@@ -463,10 +462,10 @@ int main( int argc, char * * argv )
 		if( !render_out.isEmpty() )
 		{
 			// create renderer
-			projectRenderer * r = new projectRenderer( qs, os, eff,
+			ProjectRenderer * r = new ProjectRenderer( qs, os, eff,
 				render_out +
 					QString( ( eff ==
-						projectRenderer::WaveFile ) ?
+						ProjectRenderer::WaveFile ) ?
 							"wav" : "ogg" ) );
 			QCoreApplication::instance()->connect( r,
 					SIGNAL( finished() ), SLOT( quit() ) );
