@@ -1,8 +1,8 @@
 /*
  * mixer.cpp - audio-device-independent mixer for LMMS
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
- * 
+ * Copyright (c) 2004-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or
@@ -22,44 +22,39 @@
  *
  */
 
-
 #include <math.h>
 
 #include "mixer.h"
-#include "fx_mixer.h"
+#include "FxMixer.h"
 #include "play_handle.h"
-#include "effect.h"
 #include "song.h"
 #include "templates.h"
-#include "envelope_and_lfo_parameters.h"
+#include "EnvelopeAndLfoParameters.h"
 #include "note_play_handle.h"
-#include "instrument_track.h"
+#include "InstrumentTrack.h"
 #include "debug.h"
 #include "engine.h"
 #include "config_mgr.h"
-#include "audio_port.h"
 #include "sample_play_handle.h"
 #include "piano_roll.h"
-#include "micro_timer.h"
-
-#include "audio_device.h"
-#include "midi_client.h"
+#include "MicroTimer.h"
+#include "atomic_int.h"
 
 // platform-specific audio-interface-classes
-#include "audio_alsa.h"
-#include "audio_jack.h"
-#include "audio_oss.h"
-#include "audio_portaudio.h"
-#include "audio_pulseaudio.h"
-#include "audio_sdl.h"
-#include "audio_dummy.h"
+#include "AudioAlsa.h"
+#include "AudioJack.h"
+#include "AudioOss.h"
+#include "AudioPortAudio.h"
+#include "AudioPulseAudio.h"
+#include "AudioSdl.h"
+#include "AudioDummy.h"
 
 // platform-specific midi-interface-classes
-#include "midi_alsa_raw.h"
-#include "midi_alsa_seq.h"
-#include "midi_oss.h"
-#include "midi_winmm.h"
-#include "midi_dummy.h"
+#include "MidiAlsaRaw.h"
+#include "MidiAlsaSeq.h"
+#include "MidiOss.h"
+#include "MidiWinMM.h"
+#include "MidiDummy.h"
 
 
 static QVector<fx_ch_t> __fx_channel_jobs( NumFxChannels );
@@ -95,7 +90,7 @@ static void * aligned_malloc( int _bytes )
 
 
 
-class mixerWorkerThread : public QThread
+class MixerWorkerThread : public QThread
 {
 public:
 	enum JobTypes
@@ -107,50 +102,47 @@ public:
 		NumJobTypes
 	} ;
 
-	struct jobQueueItem
+	struct JobQueueItem
 	{
-		jobQueueItem() :
+		JobQueueItem() :
 			type( InvalidJob ),
 			job( NULL ),
+			param( 0 ),
 			done( false )
 		{
 		}
-		jobQueueItem( JobTypes _type, void * _job ) :
+		JobQueueItem( JobTypes _type, void * _job, int _param = 0 ) :
 			type( _type ),
 			job( _job ),
+			param( _param ),
 			done( false )
 		{
 		}
 
 		JobTypes type;
+		void * job;
+		int param;
 
-		union
-		{
-			playHandle * playHandleJob;
-			audioPort * audioPortJob;
-			int effectChannelJob;
-			volatile void * job;
-		};
-
-#if QT_VERSION >= 0x040400
-		QAtomicInt done;
-#else
-		volatile bool done;
-#endif
+		AtomicInt done;
 	} ;
 
-	typedef QVector<jobQueueItem> jobQueueItems;
-	struct jobQueue
+
+	struct JobQueue
 	{
-		jobQueueItems items;
-#if QT_VERSION < 0x040400
-		QMutex lock;
-#endif
+#define JOB_QUEUE_SIZE 1024
+		JobQueue() :
+			queueSize( 0 )
+		{
+		}
+
+		JobQueueItem items[JOB_QUEUE_SIZE];
+		int queueSize;
+		AtomicInt itemsDone;
 	} ;
 
-	static jobQueue s_jobQueue;
+	static JobQueue s_jobQueue;
 
-	mixerWorkerThread( int _worker_num, mixer * _mixer ) :
+	MixerWorkerThread( int _worker_num, mixer * _mixer ) :
 		QThread( _mixer ),
 		m_workingBuf( (sampleFrame *) aligned_malloc(
 					_mixer->framesPerPeriod() *
@@ -158,79 +150,25 @@ public:
 		m_workerNum( _worker_num ),
 		m_quit( false ),
 		m_mixer( _mixer ),
-		m_queueReadySem( &m_mixer->m_queueReadySem ),
-		m_workersDoneSem( &m_mixer->m_workersDoneSem )
+		m_queueReadyWaitCond( &m_mixer->m_queueReadyWaitCond )
 	{
 	}
 
-	virtual ~mixerWorkerThread()
+	virtual ~MixerWorkerThread()
 	{
 		aligned_free( m_workingBuf );
 	}
 
-	virtual void quit( void )
+	virtual void quit()
 	{
 		m_quit = true;
 	}
 
-	void processJobQueue( void )
-	{
-		jobQueueItems::iterator end_it = s_jobQueue.items.end();
-		for( jobQueueItems::iterator it =
-						s_jobQueue.items.begin();
-							it != end_it; ++it )
-		{
-#if QT_VERSION >= 0x040400
-			if( it->done.fetchAndStoreOrdered( 1 ) == 0 )
-			{
-#else
-			s_jobQueue.lock.lock();
-			if( !it->done )
-			{
-				it->done = true;
-				s_jobQueue.lock.unlock();
-#endif
-				switch( it->type )
-				{
-					case PlayHandle:
-		it->playHandleJob->play( m_workingBuf );
-						break;
-					case AudioPortEffects:
-						{
-		audioPort * a = it->audioPortJob;
-		const bool me = a->processEffects();
-		if( me || a->m_bufferUsage != audioPort::NoUsage )
-		{
-			engine::getFxMixer()->mixToChannel( a->firstBuffer(),
-							a->nextFxChannel() );
-			a->nextPeriod();
-		}
-						}
-						break;
-					case EffectChannel:
-		engine::getFxMixer()->processChannel(
-				(fx_ch_t) it->effectChannelJob );
-						break;
-					default:
-/*fprintf( stderr, "invalid job item type %d at %ld in jobqueue(%ld:%ld)\n",
-		(int) it->type, (long int) it,
-					(long int) s_jobQueue.items.begin(),
-							(long int) end_it );*/
-						break;
-				}
-			}
-#if QT_VERSION < 0x040400
-			else
-			{
-				s_jobQueue.lock.unlock();
-			}
-#endif
-		}
-	}
+	void processJobQueue();
 
 
 private:
-	virtual void run( void )
+	virtual void run()
 	{
 #if 0
 #ifdef LMMS_BUILD_LINUX
@@ -242,12 +180,13 @@ private:
 #endif
 #endif
 #endif
-
+		QMutex m;
 		while( m_quit == false )
 		{
-			m_queueReadySem->acquire();
+			m.lock();
+			m_queueReadyWaitCond->wait( &m );
 			processJobQueue();
-			m_workersDoneSem->release();
+			m.unlock();
 		}
 	}
 
@@ -255,39 +194,108 @@ private:
 	int m_workerNum;
 	volatile bool m_quit;
 	mixer * m_mixer;
-	QSemaphore * m_queueReadySem;
-	QSemaphore * m_workersDoneSem;
+	QWaitCondition * m_queueReadyWaitCond;
 
 } ;
 
 
-mixerWorkerThread::jobQueue mixerWorkerThread::s_jobQueue;
+MixerWorkerThread::JobQueue MixerWorkerThread::s_jobQueue;
 
 
-#define FILL_JOB_QUEUE(_vec_type,_vec,_job_type,_condition)		\
-	mixerWorkerThread::s_jobQueue.items.clear();			\
-	for( _vec_type::iterator it = _vec.begin();			\
-				it != _vec.end(); ++it )		\
+
+void MixerWorkerThread::processJobQueue()
+{
+	for( int i = 0; i < s_jobQueue.queueSize; ++i )
+	{
+		JobQueueItem * it = &s_jobQueue.items[i];
+		if( it->done.fetchAndStoreOrdered( 1 ) == 0 )
+		{
+			switch( it->type )
+			{
+				case PlayHandle:
+					( (playHandle *) it->job )->
+							play( m_workingBuf );
+					break;
+				case AudioPortEffects:
+					{
+	AudioPort * a = (AudioPort *) it->job;
+	const bool me = a->processEffects();
+	if( me || a->m_bufferUsage != AudioPort::NoUsage )
+	{
+		engine::fxMixer()->mixToChannel( a->firstBuffer(),
+							a->nextFxChannel() );
+		a->nextPeriod();
+	}
+					}
+					break;
+				case EffectChannel:
+	engine::fxMixer()->processChannel( (fx_ch_t) it->param );
+					break;
+				default:
+					break;
+			}
+			s_jobQueue.itemsDone.fetchAndAddOrdered( 1 );
+		}
+	}
+}
+
+#define FILL_JOB_QUEUE_BEGIN(_vec_type,_vec,_condition)			\
+	MixerWorkerThread::s_jobQueue.queueSize = 0;			\
+	MixerWorkerThread::s_jobQueue.itemsDone = 0;			\
+	for( _vec_type::Iterator it = _vec.begin();			\
+					it != _vec.end(); ++it )	\
 	{								\
 		if( _condition )					\
-		{							\
-			mixerWorkerThread::s_jobQueue.items.		\
-					push_back(			\
-			mixerWorkerThread::jobQueueItem( _job_type,	\
-							(void *)*it ) );\
+		{
+
+#define FILL_JOB_QUEUE_END()						\
+			++MixerWorkerThread::s_jobQueue.queueSize;	\
 		}							\
 	}
 
+#define FILL_JOB_QUEUE(_vec_type,_vec,_job_type,_condition)		\
+	FILL_JOB_QUEUE_BEGIN(_vec_type,_vec,_condition)			\
+	MixerWorkerThread::s_jobQueue.items				\
+		[MixerWorkerThread::s_jobQueue.queueSize] =		\
+			MixerWorkerThread::JobQueueItem( _job_type,	\
+							(void *) *it );	\
+	FILL_JOB_QUEUE_END()
+
+#define FILL_JOB_QUEUE_PARAM(_vec_type,_vec,_job_type,_condition)	\
+	FILL_JOB_QUEUE_BEGIN(_vec_type,_vec,_condition)			\
+	MixerWorkerThread::s_jobQueue.items				\
+		[MixerWorkerThread::s_jobQueue.queueSize] =		\
+			MixerWorkerThread::JobQueueItem( _job_type,	\
+							NULL, *it );	\
+	FILL_JOB_QUEUE_END()
+
 #define START_JOBS()							\
-	m_queueReadySem.release( m_numWorkers );			\
+	m_queueReadyWaitCond.wakeAll();
+
+// define a pause instruction for spinlock-loop - merely useful on
+// HyperThreading systems with just one physical core (e.g. Intel Atom)
+#ifdef LMMS_HOST_X86
+#define SPINLOCK_PAUSE()        asm( "pause" )
+#else
+#ifdef LMMS_HOST_X86_64
+#define SPINLOCK_PAUSE()        asm( "pause" )
+#else
+#define SPINLOCK_PAUSE()
+#endif
+#endif
 
 #define WAIT_FOR_JOBS()							\
-	m_workersDoneSem.acquire( m_numWorkers );
+	m_workers[m_numWorkers]->processJobQueue();			\
+	while( MixerWorkerThread::s_jobQueue.itemsDone <		\
+			MixerWorkerThread::s_jobQueue.queueSize )	\
+	{								\
+		SPINLOCK_PAUSE();					\
+	}								\
 
 
 
 
-mixer::mixer( void ) :
+mixer::mixer() :
 	m_framesPerPeriod( DEFAULT_BUFFER_SIZE ),
 	m_workingBuf( NULL ),
 	m_inputBufferRead( 0 ),
@@ -296,10 +304,8 @@ mixer::mixer( void ) :
 	m_writeBuf( NULL ),
 	m_cpuLoad( 0 ),
 	m_workers(),
-	m_numWorkers( QThread::idealThreadCount() > 1 ?
-					QThread::idealThreadCount()-1 : 0 ),
-	m_queueReadySem( m_numWorkers ),
-	m_workersDoneSem( m_numWorkers ),
+	m_numWorkers( QThread::idealThreadCount()-1 ),
+	m_queueReadyWaitCond(),
 	m_qualitySettings( qualitySettings::Mode_Draft ),
 	m_masterGain( 1.0f ),
 	m_audioDev( NULL ),
@@ -363,14 +369,12 @@ mixer::mixer( void ) :
 		m_bufferPool.push_back( m_readBuf );
 	}
 
-	m_queueReadySem.acquire( m_numWorkers );
-	m_workersDoneSem.acquire( m_numWorkers );
 	for( int i = 0; i < m_numWorkers+1; ++i )
 	{
-		mixerWorkerThread * wt = new mixerWorkerThread( i, this );
-		if( i > 0 )
+		MixerWorkerThread * wt = new MixerWorkerThread( i, this );
+		if( i < m_numWorkers )
 		{
-			wt->start( QThread::HighestPriority );
+			wt->start( QThread::TimeCriticalPriority );
 		}
 		m_workers.push_back( wt );
 	}
@@ -387,15 +391,15 @@ mixer::~mixer()
 {
 	// distribute an empty job-queue so that worker-threads
 	// get out of their processing-loop
-	mixerWorkerThread::s_jobQueue.items.clear();
+	MixerWorkerThread::s_jobQueue.queueSize = 0;
 	for( int w = 0; w < m_numWorkers; ++w )
 	{
-		m_workers[w+1]->quit();
+		m_workers[w]->quit();
 	}
 	START_JOBS();
 	for( int w = 0; w < m_numWorkers; ++w )
 	{
-		m_workers[w+1]->wait( 500 );
+		m_workers[w]->wait( 500 );
 	}
 
 	while( m_fifo->available() )
@@ -418,7 +422,7 @@ mixer::~mixer()
 
 
 
-void mixer::initDevices( void )
+void mixer::initDevices()
 {
 	m_audioDev = tryAudioDevices();
 	m_midiClient = tryMidiClients();
@@ -432,7 +436,7 @@ void mixer::startProcessing( bool _needs_fifo )
 	if( _needs_fifo )
 	{
 		m_fifoWriter = new fifoWriter( this, m_fifo );
-		m_fifoWriter->start( QThread::TimeCriticalPriority );
+		m_fifoWriter->start( QThread::HighPriority );
 	}
 	else
 	{
@@ -445,7 +449,7 @@ void mixer::startProcessing( bool _needs_fifo )
 
 
 
-void mixer::stopProcessing( void )
+void mixer::stopProcessing()
 {
 	if( m_fifoWriter != NULL )
 	{
@@ -465,7 +469,7 @@ void mixer::stopProcessing( void )
 
 
 
-sample_rate_t mixer::baseSampleRate( void ) const
+sample_rate_t mixer::baseSampleRate() const
 {
 	sample_rate_t sr =
 		configManager::inst()->value( "mixer", "samplerate" ).toInt();
@@ -479,7 +483,7 @@ sample_rate_t mixer::baseSampleRate( void ) const
 
 
 
-sample_rate_t mixer::outputSampleRate( void ) const
+sample_rate_t mixer::outputSampleRate() const
 {
 	return m_audioDev != NULL ? m_audioDev->sampleRate() :
 							baseSampleRate();
@@ -488,7 +492,7 @@ sample_rate_t mixer::outputSampleRate( void ) const
 
 
 
-sample_rate_t mixer::inputSampleRate( void ) const
+sample_rate_t mixer::inputSampleRate() const
 {
 	return m_audioDev != NULL ? m_audioDev->sampleRate() :
 							baseSampleRate();
@@ -497,7 +501,7 @@ sample_rate_t mixer::inputSampleRate( void ) const
 
 
 
-sample_rate_t mixer::processingSampleRate( void ) const
+sample_rate_t mixer::processingSampleRate() const
 {
 	return outputSampleRate() * m_qualitySettings.sampleRateMultiplier();
 }
@@ -505,7 +509,7 @@ sample_rate_t mixer::processingSampleRate( void ) const
 
 
 
-bool mixer::criticalXRuns( void ) const
+bool mixer::criticalXRuns() const
 {
 	return m_cpuLoad >= 99 && engine::getSong()->realTimeTask() == true;
 }
@@ -543,9 +547,9 @@ void mixer::pushInputFrames( sampleFrame * _ab, const f_cnt_t _frames )
 
 
 
-const surroundSampleFrame * mixer::renderNextBuffer( void )
+const surroundSampleFrame * mixer::renderNextBuffer()
 {
-	microTimer timer;
+	MicroTimer timer;
 	static song::playPos last_metro_pos = -1;
 
 	song::playPos p = engine::getSong()->getPlayPos(
@@ -575,10 +579,10 @@ const surroundSampleFrame * mixer::renderNextBuffer( void )
 	// remove all play-handles that have to be deleted and delete
 	// them if they still exist...
 	// maybe this algorithm could be optimized...
-	constPlayHandleVector::iterator it_rem = m_playHandlesToRemove.begin();
+	ConstPlayHandleList::Iterator it_rem = m_playHandlesToRemove.begin();
 	while( it_rem != m_playHandlesToRemove.end() )
 	{
-		playHandleVector::iterator it = qFind( m_playHandles.begin(),
+		PlayHandleList::Iterator it = qFind( m_playHandles.begin(),
 						m_playHandles.end(), *it_rem );
 
 		if( it != m_playHandles.end() )
@@ -601,26 +605,25 @@ const surroundSampleFrame * mixer::renderNextBuffer( void )
 	clearAudioBuffer( m_writeBuf, m_framesPerPeriod );
 
 	// prepare master mix (clear internal buffers etc.)
-	engine::getFxMixer()->prepareMasterMix();
+	engine::fxMixer()->prepareMasterMix();
 
 	// create play-handles for new notes, samples etc.
 	engine::getSong()->processNextBuffer();
 
 
 	// STAGE 1: run and render all play handles
-	FILL_JOB_QUEUE(playHandleVector,m_playHandles,
-					mixerWorkerThread::PlayHandle,
+	FILL_JOB_QUEUE(PlayHandleList,m_playHandles,
+					MixerWorkerThread::PlayHandle,
 					!( *it )->done());
 	START_JOBS();
-	m_workers[0]->processJobQueue();
 	WAIT_FOR_JOBS();
 
 	// removed all play handles which are done
-	for( playHandleVector::iterator it = m_playHandles.begin();
+	for( PlayHandleList::Iterator it = m_playHandles.begin();
 						it != m_playHandles.end(); )
 	{
 		if( ( *it )->affinityMatters() &&
-				( *it )->affinity() != QThread::currentThread() )
+			( *it )->affinity() != QThread::currentThread() )
 		{
 			++it;
 			continue;
@@ -638,23 +641,21 @@ const surroundSampleFrame * mixer::renderNextBuffer( void )
 
 
 	// STAGE 2: process effects of all instrument- and sampletracks
-	FILL_JOB_QUEUE(QVector<audioPort*>,m_audioPorts,
-					mixerWorkerThread::AudioPortEffects,1);
+	FILL_JOB_QUEUE(QVector<AudioPort*>,m_audioPorts,
+					MixerWorkerThread::AudioPortEffects,1);
 	START_JOBS();
-	m_workers[0]->processJobQueue();
 	WAIT_FOR_JOBS();
 
 
 	// STAGE 3: process effects in FX mixer
-	FILL_JOB_QUEUE(QVector<fx_ch_t>,__fx_channel_jobs,
-					mixerWorkerThread::EffectChannel,1);
+	FILL_JOB_QUEUE_PARAM(QVector<fx_ch_t>,__fx_channel_jobs,
+					MixerWorkerThread::EffectChannel,1);
 	START_JOBS();
-	m_workers[0]->processJobQueue();
 	WAIT_FOR_JOBS();
 
 
 	// STAGE 4: do master mix in FX mixer
-	engine::getFxMixer()->masterMix( m_writeBuf );
+	engine::fxMixer()->masterMix( m_writeBuf );
 
 	unlock();
 
@@ -662,8 +663,8 @@ const surroundSampleFrame * mixer::renderNextBuffer( void )
 	emit nextAudioBuffer();
 
 	// and trigger LFOs
-	envelopeAndLFOParameters::triggerLFO();
-	controller::triggerFrameCounter();
+	EnvelopeAndLfoParameters::instances()->trigger();
+	Controller::triggerFrameCounter();
 
 	const float new_cpu_load = timer.elapsed() / 10000.0f *
 				processingSampleRate() / m_framesPerPeriod;
@@ -676,13 +677,13 @@ const surroundSampleFrame * mixer::renderNextBuffer( void )
 
 
 
-// removes all play-handles. this is neccessary, when the song is stopped ->
+// removes all play-handles. this is necessary, when the song is stopped ->
 // all remaining notes etc. would be played until their end
-void mixer::clear( void )
+void mixer::clear()
 {
 	// TODO: m_midiClient->noteOffAll();
 	lock();
-	for( playHandleVector::iterator it = m_playHandles.begin();
+	for( PlayHandleList::Iterator it = m_playHandles.begin();
 					it != m_playHandles.end(); ++it )
 	{
 		// we must not delete instrument-play-handles as they exist
@@ -702,7 +703,7 @@ void mixer::bufferToPort( const sampleFrame * _buf,
 					const fpp_t _frames,
 					const f_cnt_t _offset,
 					stereoVolumeVector _vv,
-						audioPort * _port )
+						AudioPort * _port )
 {
 	const int start_frame = _offset % m_framesPerPeriod;
 	int end_frame = start_frame + _frames;
@@ -732,12 +733,12 @@ void mixer::bufferToPort( const sampleFrame * _buf,
 								_vv.vol[1];
 		}
 		// we used both buffers so set flags
-		_port->m_bufferUsage = audioPort::BothBuffers;
+		_port->m_bufferUsage = AudioPort::BothBuffers;
 	}
-	else if( _port->m_bufferUsage == audioPort::NoUsage )
+	else if( _port->m_bufferUsage == AudioPort::NoUsage )
 	{
 		// only first buffer touched
-		_port->m_bufferUsage = audioPort::FirstBuffer;
+		_port->m_bufferUsage = AudioPort::FirstBuffer;
 	}
 	_port->unlockSecondBuffer();
 }
@@ -821,7 +822,7 @@ void mixer::changeQuality( const struct qualitySettings & _qs )
 
 
 
-void mixer::setAudioDevice( audioDevice * _dev )
+void mixer::setAudioDevice( AudioDevice * _dev )
 {
 	stopProcessing();
 
@@ -846,7 +847,7 @@ void mixer::setAudioDevice( audioDevice * _dev )
 
 
 
-void mixer::setAudioDevice( audioDevice * _dev,
+void mixer::setAudioDevice( AudioDevice * _dev,
 				const struct qualitySettings & _qs,
 				bool _needs_fifo )
 {
@@ -876,7 +877,7 @@ void mixer::setAudioDevice( audioDevice * _dev,
 
 
 
-void mixer::restoreAudioDevice( void )
+void mixer::restoreAudioDevice()
 {
 	if( m_oldAudioDev != NULL )
 	{
@@ -894,9 +895,9 @@ void mixer::restoreAudioDevice( void )
 
 
 
-void mixer::removeAudioPort( audioPort * _port )
+void mixer::removeAudioPort( AudioPort * _port )
 {
-	QVector<audioPort *>::iterator it = qFind( m_audioPorts.begin(),
+	QVector<AudioPort *>::Iterator it = qFind( m_audioPorts.begin(),
 							m_audioPorts.end(),
 							_port );
 	if( it != m_audioPorts.end() )
@@ -918,7 +919,7 @@ void mixer::removePlayHandle( playHandle * _ph )
 	if( _ph->affinityMatters() &&
 				_ph->affinity() == QThread::currentThread() )
 	{
-		playHandleVector::iterator it =
+		PlayHandleList::Iterator it =
 				qFind( m_playHandles.begin(),
 						m_playHandles.end(), _ph );
 		if( it != m_playHandles.end() )
@@ -940,7 +941,7 @@ void mixer::removePlayHandle( playHandle * _ph )
 void mixer::removePlayHandles( track * _track )
 {
 	lock();
-	playHandleVector::iterator it = m_playHandles.begin();
+	PlayHandleList::Iterator it = m_playHandles.begin();
 	while( it != m_playHandles.end() )
 	{
 		if( ( *it )->isFromTrack( _track ) )
@@ -959,24 +960,24 @@ void mixer::removePlayHandles( track * _track )
 
 
 
-audioDevice * mixer::tryAudioDevices( void )
+AudioDevice * mixer::tryAudioDevices()
 {
 	bool success_ful = false;
-	audioDevice * dev = NULL;
+	AudioDevice * dev = NULL;
 	QString dev_name = configManager::inst()->value( "mixer", "audiodev" );
 
-	if( dev_name == audioDummy::name() )
+	if( dev_name == AudioDummy::name() )
 	{
 		dev_name = "";
 	}
 
 #ifdef LMMS_HAVE_ALSA
-	if( dev_name == audioALSA::name() || dev_name == "" )
+	if( dev_name == AudioAlsa::name() || dev_name == "" )
 	{
-		dev = new audioALSA( success_ful, this );
+		dev = new AudioAlsa( success_ful, this );
 		if( success_ful )
 		{
-			m_audioDevName = audioALSA::name();
+			m_audioDevName = AudioAlsa::name();
 			return dev;
 		}
 		delete dev;
@@ -985,12 +986,12 @@ audioDevice * mixer::tryAudioDevices( void )
 
 
 #ifdef LMMS_HAVE_PORTAUDIO
-	if( dev_name == audioPortAudio::name() || dev_name == "" )
+	if( dev_name == AudioPortAudio::name() || dev_name == "" )
 	{
-		dev = new audioPortAudio( success_ful, this );
+		dev = new AudioPortAudio( success_ful, this );
 		if( success_ful )
 		{
-			m_audioDevName = audioPortAudio::name();
+			m_audioDevName = AudioPortAudio::name();
 			return dev;
 		}
 		delete dev;
@@ -999,12 +1000,12 @@ audioDevice * mixer::tryAudioDevices( void )
 
 
 #ifdef LMMS_HAVE_PULSEAUDIO
-	if( dev_name == audioPulseAudio::name() || dev_name == "" )
+	if( dev_name == AudioPulseAudio::name() || dev_name == "" )
 	{
-		dev = new audioPulseAudio( success_ful, this );
+		dev = new AudioPulseAudio( success_ful, this );
 		if( success_ful )
 		{
-			m_audioDevName = audioPulseAudio::name();
+			m_audioDevName = AudioPulseAudio::name();
 			return dev;
 		}
 		delete dev;
@@ -1013,12 +1014,12 @@ audioDevice * mixer::tryAudioDevices( void )
 
 
 #ifdef LMMS_HAVE_OSS
-	if( dev_name == audioOSS::name() || dev_name == "" )
+	if( dev_name == AudioOss::name() || dev_name == "" )
 	{
-		dev = new audioOSS( success_ful, this );
+		dev = new AudioOss( success_ful, this );
 		if( success_ful )
 		{
-			m_audioDevName = audioOSS::name();
+			m_audioDevName = AudioOss::name();
 			return dev;
 		}
 		delete dev;
@@ -1027,12 +1028,12 @@ audioDevice * mixer::tryAudioDevices( void )
 
 
 #ifdef LMMS_HAVE_JACK
-	if( dev_name == audioJACK::name() || dev_name == "" )
+	if( dev_name == AudioJack::name() || dev_name == "" )
 	{
-		dev = new audioJACK( success_ful, this );
+		dev = new AudioJack( success_ful, this );
 		if( success_ful )
 		{
-			m_audioDevName = audioJACK::name();
+			m_audioDevName = AudioJack::name();
 			return dev;
 		}
 		delete dev;
@@ -1041,12 +1042,12 @@ audioDevice * mixer::tryAudioDevices( void )
 
 
 #ifdef LMMS_HAVE_SDL
-	if( dev_name == audioSDL::name() || dev_name == "" )
+	if( dev_name == AudioSdl::name() || dev_name == "" )
 	{
-		dev = new audioSDL( success_ful, this );
+		dev = new AudioSdl( success_ful, this );
 		if( success_ful )
 		{
-			m_audioDevName = audioSDL::name();
+			m_audioDevName = AudioSdl::name();
 			return dev;
 		}
 		delete dev;
@@ -1065,37 +1066,37 @@ audioDevice * mixer::tryAudioDevices( void )
 		"driver\nYou can render your songs and listen to the output "
 		"files...\n" );
 
-	m_audioDevName = audioDummy::name();
+	m_audioDevName = AudioDummy::name();
 
-	return new audioDummy( success_ful, this );
+	return new AudioDummy( success_ful, this );
 }
 
 
 
 
-midiClient * mixer::tryMidiClients( void )
+MidiClient * mixer::tryMidiClients()
 {
 	QString client_name = configManager::inst()->value( "mixer",
 								"mididev" );
 
 #ifdef LMMS_HAVE_ALSA
-	if( client_name == midiALSASeq::name() || client_name == "" )
+	if( client_name == MidiAlsaSeq::name() || client_name == "" )
 	{
-		midiALSASeq * malsas = new midiALSASeq;
+		MidiAlsaSeq * malsas = new MidiAlsaSeq;
 		if( malsas->isRunning() )
 		{
-			m_midiClientName = midiALSASeq::name();
+			m_midiClientName = MidiAlsaSeq::name();
 			return malsas;
 		}
 		delete malsas;
 	}
 
-	if( client_name == midiALSARaw::name() || client_name == "" )
+	if( client_name == MidiAlsaRaw::name() || client_name == "" )
 	{
-		midiALSARaw * malsar = new midiALSARaw;
+		MidiAlsaRaw * malsar = new MidiAlsaRaw;
 		if( malsar->isRunning() )
 		{
-			m_midiClientName = midiALSARaw::name();
+			m_midiClientName = MidiAlsaRaw::name();
 			return malsar;
 		}
 		delete malsar;
@@ -1103,12 +1104,12 @@ midiClient * mixer::tryMidiClients( void )
 #endif
 
 #ifdef LMMS_HAVE_OSS
-	if( client_name == midiOSS::name() || client_name == "" )
+	if( client_name == MidiOss::name() || client_name == "" )
 	{
-		midiOSS * moss = new midiOSS;
+		MidiOss * moss = new MidiOss;
 		if( moss->isRunning() )
 		{
-			m_midiClientName = midiOSS::name();
+			m_midiClientName = MidiOss::name();
 			return moss;
 		}
 		delete moss;
@@ -1116,12 +1117,12 @@ midiClient * mixer::tryMidiClients( void )
 #endif
 
 #ifdef LMMS_BUILD_WIN32
-	if( client_name == midiWinMM::name() || client_name == "" )
+	if( client_name == MidiWinMM::name() || client_name == "" )
 	{
-		midiWinMM * mwmm = new midiWinMM;
+		MidiWinMM * mwmm = new MidiWinMM;
 //		if( moss->isRunning() )
 		{
-			m_midiClientName = midiWinMM::name();
+			m_midiClientName = MidiWinMM::name();
 			return mwmm;
 		}
 		delete mwmm;
@@ -1131,9 +1132,9 @@ midiClient * mixer::tryMidiClients( void )
 	printf( "Couldn't create MIDI-client, neither with ALSA nor with "
 		"OSS. Will use dummy-MIDI-client.\n" );
 
-	m_midiClientName = midiDummy::name();
+	m_midiClientName = MidiDummy::name();
 
-	return new midiDummy;
+	return new MidiDummy;
 }
 
 
@@ -1154,7 +1155,7 @@ mixer::fifoWriter::fifoWriter( mixer * _mixer, fifo * _fifo ) :
 
 
 
-void mixer::fifoWriter::finish( void )
+void mixer::fifoWriter::finish()
 {
 	m_writing = false;
 }
@@ -1162,7 +1163,7 @@ void mixer::fifoWriter::finish( void )
 
 
 
-void mixer::fifoWriter::run( void )
+void mixer::fifoWriter::run()
 {
 #if 0
 #ifdef LMMS_BUILD_LINUX
