@@ -1,9 +1,7 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * note.cpp - implementation of class note
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -38,7 +36,7 @@
 
 
 note::note( const midiTime & _length, const midiTime & _pos,
-		int _key, volume _volume, panning _panning,
+		int _key, volume_t _volume, panning_t _panning,
 						detuningHelper * _detuning ) :
 	m_selected( false ),
 	m_oldKey( tLimit( _key, 0, NumKeys ) ),
@@ -49,10 +47,11 @@ note::note( const midiTime & _length, const midiTime & _pos,
 	m_volume( tLimit( _volume, MinVolume, MaxVolume ) ),
 	m_panning( tLimit( _panning, PanningLeft, PanningRight ) ),
 	m_length( _length ),
-	m_pos( _pos )
+	m_pos( _pos ),
+	m_detuning( NULL )
 {
-	//saveJournallingState( FALSE );
-//	setJournalling( FALSE );
+	//saveJournallingState( false );
+//	setJournalling( false );
 	if( _detuning )
 	{
 		m_detuning = sharedObject::ref( _detuning );
@@ -68,7 +67,7 @@ note::note( const midiTime & _length, const midiTime & _pos,
 
 
 note::note( const note & _note ) :
-	serializingObject( _note ),
+	SerializingObject( _note ),
 	m_selected( _note.m_selected ),
 	m_oldKey( _note.m_oldKey ),
 	m_oldPos( _note.m_oldPos ),
@@ -78,9 +77,17 @@ note::note( const note & _note ) :
 	m_volume( _note.m_volume ),
 	m_panning( _note.m_panning ),
 	m_length( _note.m_length ),
-	m_pos( _note.m_pos )
+	m_pos( _note.m_pos ),
+	m_detuning( NULL )
 {
-	m_detuning = sharedObject::ref( _note.m_detuning );
+	if( _note.m_detuning )
+	{
+		m_detuning = sharedObject::ref( _note.m_detuning );
+	}
+	else
+	{
+		createDetuning();
+	}
 }
 
 
@@ -88,7 +95,10 @@ note::note( const note & _note ) :
 
 note::~note()
 {
-	sharedObject::unref( m_detuning );
+	if( m_detuning )
+	{
+		sharedObject::unref( m_detuning );
+	}
 }
 
 
@@ -122,9 +132,9 @@ void note::setKey( const int _key )
 
 
 
-void note::setVolume( const volume _volume )
+void note::setVolume( const volume_t _volume )
 {
-	const volume v = tLimit( _volume, MinVolume, MaxVolume );
+	const volume_t v = tLimit( _volume, MinVolume, MaxVolume );
 //	addJournalEntry( journalEntry( ChangeVolume, (int) m_volume - v ) );
 	m_volume = v;
 }
@@ -132,9 +142,9 @@ void note::setVolume( const volume _volume )
 
 
 
-void note::setPanning( const panning _panning )
+void note::setPanning( const panning_t _panning )
 {
-	const panning p = tLimit( _panning, PanningLeft, PanningRight );
+	const panning_t p = tLimit( _panning, PanningLeft, PanningRight );
 //	addJournalEntry( journalEntry( ChangePanning, (int) m_panning - p ) );
 	m_panning = p;
 }
@@ -211,7 +221,7 @@ void note::loadSettings( const QDomElement & _this )
 
 /*void note::undoStep( journalEntry & _je )
 {
-	saveJournallingState( FALSE );
+	saveJournallingState( false );
 	switch( static_cast<Actions>( _je.actionID() ) )
 	{
 		case ChangeKey:
@@ -223,7 +233,7 @@ void note::loadSettings( const QDomElement & _this )
 			break;
 
 		case ChangePanning:
-			setVolume( getPanning() - _je.data().toInt() );
+			setPanning( getPanning() - _je.data().toInt() );
 			break;
 
 		case ChangeLength:
@@ -249,7 +259,7 @@ void note::redoStep( journalEntry & _je )
 
 
 
-void note::editDetuningPattern( void )
+void note::editDetuningPattern()
 {
 	m_detuning->getAutomationPattern()->openInAutomationEditor();
 }
@@ -257,7 +267,7 @@ void note::editDetuningPattern( void )
 
 
 
-void note::createDetuning( void )
+void note::createDetuning()
 {
 	m_detuning = new detuningHelper;
 	(void) m_detuning->getAutomationPattern();
@@ -267,12 +277,11 @@ void note::createDetuning( void )
 
 
 
-bool note::hasDetuningInfo( void ) const
+bool note::hasDetuningInfo() const
 {
-	return( m_detuning && m_detuning->hasAutomation() );
+	return m_detuning && m_detuning->hasAutomation();
 }
 
 
 
 
-#endif
