@@ -1,10 +1,8 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * sample_buffer.cpp - container-class sampleBuffer
  *
- * Copyright (c) 2005-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
- * 
+ * Copyright (c) 2005-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or
@@ -64,10 +62,9 @@
 #include "templates.h"
 
 
-
 sampleBuffer::sampleBuffer( const QString & _audio_file,
 							bool _is_base64_data ) :
-	m_audioFile( ( _is_base64_data == TRUE ) ? "" : _audio_file ),
+	m_audioFile( ( _is_base64_data == true ) ? "" : _audio_file ),
 	m_origData( NULL ),
 	m_origFrames( 0 ),
 	m_data( NULL ),
@@ -77,11 +74,11 @@ sampleBuffer::sampleBuffer( const QString & _audio_file,
 	m_loopStartFrame( 0 ),
 	m_loopEndFrame( 0 ),
 	m_amplification( 1.0f ),
-	m_reversed( FALSE ),
+	m_reversed( false ),
 	m_frequency( BaseFreq ),
 	m_sampleRate( engine::getMixer()->baseSampleRate() )
 {
-	if( _is_base64_data == TRUE )
+	if( _is_base64_data == true )
 	{
 		loadFromBase64( _audio_file );
 	}
@@ -102,7 +99,7 @@ sampleBuffer::sampleBuffer( const sampleFrame * _data, const f_cnt_t _frames ) :
 	m_loopStartFrame( 0 ),
 	m_loopEndFrame( 0 ),
 	m_amplification( 1.0f ),
-	m_reversed( FALSE ),
+	m_reversed( false ),
 	m_frequency( BaseFreq ),
 	m_sampleRate( engine::getMixer()->baseSampleRate() )
 {
@@ -129,7 +126,7 @@ sampleBuffer::sampleBuffer( const f_cnt_t _frames ) :
 	m_loopStartFrame( 0 ),
 	m_loopEndFrame( 0 ),
 	m_amplification( 1.0f ),
-	m_reversed( FALSE ),
+	m_reversed( false ),
 	m_frequency( BaseFreq ),
 	m_sampleRate( engine::getMixer()->baseSampleRate() )
 {
@@ -165,29 +162,36 @@ void sampleBuffer::update( bool _keep_settings )
 		delete[] m_data;
 	}
 
-	if( m_audioFile == "" && m_origData != NULL && m_origFrames > 0 )
+	if( m_audioFile.isEmpty() && m_origData != NULL && m_origFrames > 0 )
 	{
 		// TODO: reverse- and amplification-property is not covered
 		// by following code...
 		m_data = new sampleFrame[m_origFrames];
 		memcpy( m_data, m_origData, m_origFrames * BYTES_PER_FRAME );
-		if( _keep_settings == FALSE )
+		if( _keep_settings == false )
 		{
 			m_frames = m_origFrames;
 			m_loopStartFrame = m_startFrame = 0;
 			m_loopEndFrame = m_endFrame = m_frames;
 		}
 	}
-	else if( m_audioFile != "" )
+	else if( !m_audioFile.isEmpty() )
 	{
 		QString file = tryToMakeAbsolute( m_audioFile );
-		char * f = qstrdup( file.toAscii().constData() );
+		char * f = qstrdup( file.toUtf8().constData() );
 		int_sample_t * buf = NULL;
 		ch_cnt_t channels = DEFAULT_CHANNELS;
 		sample_rate_t samplerate = engine::getMixer()->baseSampleRate();
-
 		m_frames = 0;
 
+		if( QFileInfo( file ).size() > 100*1024*1024 )
+		{
+			qWarning( "refusing to load sample files bigger "
+								"than 100 MB" );
+		}
+		else
+		{
+
 		if( m_frames == 0 )
 		{
 			m_frames = decodeSampleSF( f, buf, channels,
@@ -207,6 +211,7 @@ void sampleBuffer::update( bool _keep_settings )
 		}
 
 		delete[] f;
+		}
 
 		if( m_frames > 0 && buf != NULL )
 		{
@@ -295,7 +300,7 @@ void sampleBuffer::normalizeSampleRate( const sample_rate_t _src_sr,
 		delete resampled;
 	}
 
-	if( _keep_settings == FALSE )
+	if( _keep_settings == false )
 	{
 		// update frame-variables
 		m_loopStartFrame = m_startFrame = 0;
@@ -338,7 +343,7 @@ f_cnt_t sampleBuffer::decodeSampleSF( const char * _f,
 				"sample %s: %s\n", _f, sf_strerror( NULL ) );
 #endif
 	}
-	return( frames );
+	return frames;
 }
 
 
@@ -350,8 +355,8 @@ f_cnt_t sampleBuffer::decodeSampleSF( const char * _f,
 
 size_t qfileReadCallback( void * _ptr, size_t _size, size_t _n, void * _udata )
 {
-	return( static_cast<QFile *>( _udata )->read( (char*) _ptr,
-								_size * _n ) );
+	return static_cast<QFile *>( _udata )->read( (char*) _ptr,
+								_size * _n );
 }
 
 
@@ -373,7 +378,7 @@ int qfileSeekCallback( void * _udata, ogg_int64_t _offset, int _whence )
 	{
 		f->seek( _offset );
 	}
-	return( 0 );
+	return 0;
 }
 
 
@@ -382,7 +387,7 @@ int qfileSeekCallback( void * _udata, ogg_int64_t _offset, int _whence )
 int qfileCloseCallback( void * _udata )
 {
 	delete static_cast<QFile *>( _udata );
-	return( 0 );
+	return 0;
 }
 
 
@@ -390,7 +395,7 @@ int qfileCloseCallback( void * _udata )
 
 long qfileTellCallback( void * _udata )
 {
-	return( static_cast<QFile *>( _udata )->pos() );
+	return static_cast<QFile *>( _udata )->pos();
 }
 
 
@@ -414,10 +419,10 @@ f_cnt_t sampleBuffer::decodeSampleOGGVorbis( const char * _f,
 	f_cnt_t frames = 0;
 
 	QFile * f = new QFile( _f );
-	if( f->open( QFile::ReadOnly ) == FALSE )
+	if( f->open( QFile::ReadOnly ) == false )
 	{
 		delete f;
-		return( 0 );
+		return 0;
 	}
 
 	int err = ov_open_callbacks( f, &vf, NULL, 0, callbacks );
@@ -448,7 +453,7 @@ f_cnt_t sampleBuffer::decodeSampleOGGVorbis( const char * _f,
 				break;
 		}
 		delete f;
-		return( 0 );
+		return 0;
 	}
 
 	ov_pcm_seek( &vf, 0 );
@@ -479,7 +484,7 @@ f_cnt_t sampleBuffer::decodeSampleOGGVorbis( const char * _f,
 
 	ov_clear( &vf );
 
-	return( frames );
+	return frames;
 }
 #endif
 
@@ -492,7 +497,7 @@ f_cnt_t sampleBuffer::decodeSampleDS( const char * _f,
 						sample_rate_t & _samplerate )
 {
 	DrumSynth ds;
-	return( ds.GetDSFileSamples( _f, _buf, _channels ) );
+	return ds.GetDSFileSamples( _f, _buf, _channels );
 }
 
 
@@ -509,7 +514,7 @@ bool sampleBuffer::play( sampleFrame * _ab, handleState * _state,
 
 	if( m_endFrame == 0 || _frames == 0 )
 	{
-		return( FALSE );
+		return false;
 	}
 
 	const double freq_factor = (double) _freq / (double) m_frequency *
@@ -521,7 +526,7 @@ bool sampleBuffer::play( sampleFrame * _ab, handleState * _state,
 								freq_factor );
 	if( total_frames_for_current_pitch == 0 )
 	{
-		return( FALSE );
+		return false;
 	}
 
 	// this holds the number of the first frame to play
@@ -544,14 +549,14 @@ bool sampleBuffer::play( sampleFrame * _ab, handleState * _state,
 	{
 		if( play_frame >= m_endFrame )
 		{
-			return( FALSE );
+			return false;
 		}
 		frames_for_loop = static_cast<f_cnt_t>(
 					( m_endFrame - play_frame ) /
 								freq_factor );
 		if( frames_for_loop == 0 )
 		{
-			return( FALSE );
+			return false;
 		}
 	}
 
@@ -571,7 +576,7 @@ bool sampleBuffer::play( sampleFrame * _ab, handleState * _state,
 		src_data.input_frames = fragment_size;
 		src_data.output_frames = _frames;
 		src_data.src_ratio = 1.0 / freq_factor;
-		src_data.end_of_input = _state->m_eof;
+		src_data.end_of_input = 0;
 		int error = src_process( _state->m_resamplingData,
 								&src_data );
 		if( error )
@@ -584,7 +589,6 @@ bool sampleBuffer::play( sampleFrame * _ab, handleState * _state,
 			printf( "sampleBuffer: not enough frames: %ld / %d\n",
 					src_data.output_frames_gen, _frames );
 		}
-		_state->m_eof = src_data.end_of_input;
 		// Advance
 		play_frame += src_data.input_frames_used;
 		if( _looped )
@@ -613,7 +617,7 @@ bool sampleBuffer::play( sampleFrame * _ab, handleState * _state,
 
 	_state->m_frameIndex = play_frame;
 
-	return( TRUE );
+	return true;
 
 }
 
@@ -627,14 +631,14 @@ sampleFrame * sampleBuffer::getSampleFragment( f_cnt_t _start,
 	{
 		if( _start + _frames <= m_loopEndFrame )
 		{
-			return( m_data + _start );
+			return m_data + _start;
 		}
 	}
 	else
 	{
 		if( _start + _frames <= m_endFrame )
 		{
-			return( m_data + _start );
+			return m_data + _start;
 		}
 	}
 
@@ -661,7 +665,7 @@ sampleFrame * sampleBuffer::getSampleFragment( f_cnt_t _start,
 							BYTES_PER_FRAME );
 	}
 
-	return( *_tmp );
+	return *_tmp;
 }
 
 
@@ -671,10 +675,10 @@ f_cnt_t sampleBuffer::getLoopedIndex( f_cnt_t _index ) const
 {
 	if( _index < m_loopEndFrame )
 	{
-		return( _index );
+		return _index;
 	}
-	return( m_loopStartFrame + ( _index - m_loopStartFrame )
-				% ( m_loopEndFrame - m_loopStartFrame ) );
+	return m_loopStartFrame + ( _index - m_loopStartFrame )
+				% ( m_loopEndFrame - m_loopStartFrame );
 }
 
 
@@ -716,18 +720,18 @@ void sampleBuffer::visualize( QPainter & _p, const QRect & _dr,
 
 
 
-QString sampleBuffer::openAudioFile( void ) const
+QString sampleBuffer::openAudioFile() const
 {
 	QFileDialog ofd( NULL, tr( "Open audio file" ) );
 
 	QString dir;
-	if( m_audioFile != "" )
+	if( !m_audioFile.isEmpty() )
 	{
 		QString f = m_audioFile;
 		if( QFileInfo( f ).isRelative() )
 		{
 			f = configManager::inst()->userSamplesDir() + f;
-			if( QFileInfo( f ).exists() == FALSE )
+			if( QFileInfo( f ).exists() == false )
 			{
 				f = configManager::inst()->factorySamplesDir() +
 								m_audioFile;
@@ -761,7 +765,7 @@ QString sampleBuffer::openAudioFile( void ) const
 		//<< tr( "MOD-Files (*.mod)" )
 		;
 	ofd.setFilters( types );
-	if( m_audioFile != "" )
+	if( !m_audioFile.isEmpty() )
 	{
 		// select previously opened file
 		ofd.selectFile( QFileInfo( m_audioFile ).fileName() );
@@ -771,12 +775,12 @@ QString sampleBuffer::openAudioFile( void ) const
 	{
 		if( ofd.selectedFiles().isEmpty() )
 		{
-			return( "" );
+			return QString::null;
 		}
-		return( tryToMakeRelative( ofd.selectedFiles()[0] ) );
+		return tryToMakeRelative( ofd.selectedFiles()[0] );
 	}
 
-	return( "" );
+	return QString::null;
 }
 
 
@@ -787,7 +791,7 @@ QString sampleBuffer::openAudioFile( void ) const
 FLAC__StreamEncoderWriteStatus flacStreamEncoderWriteCallback(
 					const FLAC__StreamEncoder *
 								/*_encoder*/,
-					const FLAC__byte _buffer[], 
+					const FLAC__byte _buffer[],
 					unsigned int/* _samples*/,
 					unsigned int _bytes,
 					unsigned int/* _current_frame*/,
@@ -795,13 +799,13 @@ FLAC__StreamEncoderWriteStatus flacStreamEncoderWriteCallback(
 {
 /*	if( _bytes == 0 )
 	{
-		return( FLAC__STREAM_ENCODER_WRITE_STATUS_OK );
+		return FLAC__STREAM_ENCODER_WRITE_STATUS_OK;
 	}*/
-	return( ( static_cast<QBuffer *>( _client_data )->write(
+	return ( static_cast<QBuffer *>( _client_data )->write(
 				(const char *) _buffer, _bytes ) ==
 								(int) _bytes ) ?
 				FLAC__STREAM_ENCODER_WRITE_STATUS_OK :
-				FLAC__STREAM_ENCODER_WRITE_STATUS_FATAL_ERROR );
+				FLAC__STREAM_ENCODER_WRITE_STATUS_FATAL_ERROR;
 }
 
 
@@ -826,8 +830,8 @@ QString & sampleBuffer::toBase64( QString & _dst ) const
 	FLAC__StreamEncoder * flac_enc = FLAC__stream_encoder_new();
 	FLAC__stream_encoder_set_channels( flac_enc, DEFAULT_CHANNELS );
 	FLAC__stream_encoder_set_blocksize( flac_enc, FRAMES_PER_BUF );
-/*	FLAC__stream_encoder_set_do_exhaustive_model_search( flac_enc, TRUE );
-	FLAC__stream_encoder_set_do_mid_side_stereo( flac_enc, TRUE );*/
+/*	FLAC__stream_encoder_set_do_exhaustive_model_search( flac_enc, true );
+	FLAC__stream_encoder_set_do_mid_side_stereo( flac_enc, true );*/
 	FLAC__stream_encoder_set_sample_rate( flac_enc,
 					engine::getMixer()->sampleRate() );
 	QBuffer ba_writer;
@@ -877,7 +881,7 @@ QString & sampleBuffer::toBase64( QString & _dst ) const
 
 #endif	/* LMMS_HAVE_FLAC_STREAM_ENCODER_H */
 
-	return( _dst );
+	return _dst;
 }
 
 
@@ -900,7 +904,7 @@ sampleBuffer * sampleBuffer::resample( sampleFrame * _data,
 					DEFAULT_CHANNELS, &error ) ) != NULL )
 	{
 		SRC_DATA src_data;
-		src_data.end_of_input = 0;
+		src_data.end_of_input = 1;
 		src_data.data_in = _data[0];
 		src_data.data_out = dst_buf[0];
 		src_data.input_frames = _frames;
@@ -918,7 +922,7 @@ sampleBuffer * sampleBuffer::resample( sampleFrame * _data,
 		printf( "Error: src_new() failed in sample_buffer.cpp!\n" );
 	}
 	dst_sb->update();
-	return( dst_sb );
+	return dst_sb;
 }
 
 
@@ -956,11 +960,11 @@ FLAC__StreamDecoderReadStatus flacStreamDecoderReadCallback(
 	if( res > 0 )
 	{
 		*_bytes = res;
-		return( FLAC__STREAM_DECODER_READ_STATUS_CONTINUE );
+		return FLAC__STREAM_DECODER_READ_STATUS_CONTINUE;
 
 	}
 	*_bytes = 0;
-	return( FLAC__STREAM_DECODER_READ_STATUS_END_OF_STREAM );
+	return FLAC__STREAM_DECODER_READ_STATUS_END_OF_STREAM;
 }
 
 
@@ -977,14 +981,14 @@ FLAC__StreamDecoderWriteStatus flacStreamDecoderWriteCallback(
 	{
 		printf( "channels != 2 in "
 					"flacStreamDecoderWriteCallback()\n" );
-		return( FLAC__STREAM_DECODER_WRITE_STATUS_ABORT );
+		return FLAC__STREAM_DECODER_WRITE_STATUS_ABORT;
 	}
 
 	if( _frame->header.bits_per_sample != 16 )
 	{
 		printf( "bits_per_sample != 16 in "
 					"flacStreamDecoderWriteCallback()\n" );
-		return( FLAC__STREAM_DECODER_WRITE_STATUS_ABORT );
+		return FLAC__STREAM_DECODER_WRITE_STATUS_ABORT;
 	}
 
 	const f_cnt_t frames = _frame->header.blocksize;
@@ -998,8 +1002,8 @@ FLAC__StreamDecoderWriteStatus flacStreamDecoderWriteCallback(
 		static_cast<flacStreamDecoderClientData *>(
 					_client_data )->write_buffer->write(
 				(const char *) sframe, sizeof( sframe ) );
-	} 
-	return( FLAC__STREAM_DECODER_WRITE_STATUS_CONTINUE );
+	}
+	return FLAC__STREAM_DECODER_WRITE_STATUS_CONTINUE;
 }
 
 
@@ -1066,14 +1070,14 @@ void sampleBuffer::loadFromBase64( const QString & _data )
 	orig_data = ba_writer.buffer();
 	printf("%d\n", (int) orig_data.size() );
 
-	m_origFrames = orig_data.size() / sizeof( sampleFrame ); 
+	m_origFrames = orig_data.size() / sizeof( sampleFrame );
 	delete[] m_origData;
 	m_origData = new sampleFrame[m_origFrames];
 	memcpy( m_origData, orig_data.data(), orig_data.size() );
 
 #else /* LMMS_HAVE_FLAC_STREAM_DECODER_H */
 
-	m_origFrames = dsize / sizeof( sampleFrame ); 
+	m_origFrames = dsize / sizeof( sampleFrame );
 	delete[] m_origData;
 	m_origData = new sampleFrame[m_origFrames];
 	memcpy( m_origData, dst, dsize );
@@ -1082,7 +1086,7 @@ void sampleBuffer::loadFromBase64( const QString & _data )
 
 	delete[] dst;
 
-	m_audioFile = "";
+	m_audioFile = QString();
 	update();
 }
 
@@ -1112,7 +1116,7 @@ void sampleBuffer::setEndFrame( const f_cnt_t _e )
 void sampleBuffer::setAmplification( float _a )
 {
 	m_amplification = _a;
-	update( TRUE );
+	update( true );
 }
 
 
@@ -1121,7 +1125,7 @@ void sampleBuffer::setAmplification( float _a )
 void sampleBuffer::setReversed( bool _on )
 {
 	m_reversed = _on;
-	update( TRUE );
+	update( true );
 }
 
 
@@ -1129,7 +1133,7 @@ void sampleBuffer::setReversed( bool _on )
 
 QString sampleBuffer::tryToMakeRelative( const QString & _file )
 {
-	if( QFileInfo( _file ).isRelative() == FALSE )
+	if( QFileInfo( _file ).isRelative() == false )
 	{
 		QString f = QString( _file ).replace( QDir::separator(), '/' );
 		QString fsd = configManager::inst()->factorySamplesDir();
@@ -1138,14 +1142,14 @@ QString sampleBuffer::tryToMakeRelative( const QString & _file )
 		usd.replace( QDir::separator(), '/' );
 		if( f.startsWith( fsd ) )
 		{
-			return( QString( f ).mid( fsd.length() ) );
+			return QString( f ).mid( fsd.length() );
 		}
 		else if( f.startsWith( usd ) )
 		{
-			return( QString( f ).mid( usd.length() ) );
+			return QString( f ).mid( usd.length() );
 		}
 	}
-	return( _file );
+	return _file;
 }
 
 
@@ -1155,16 +1159,16 @@ QString sampleBuffer::tryToMakeAbsolute( const QString & _file )
 {
 	if( QFileInfo( _file ).isAbsolute() )
 	{
-		return( _file );
+		return _file;
 	}
 
 	QString f = configManager::inst()->userSamplesDir() + _file;
 	if( QFileInfo( f ).exists() )
 	{
-		return( f );
+		return f;
 	}
 
-	return( configManager::inst()->factorySamplesDir() + _file );
+	return configManager::inst()->factorySamplesDir() + _file;
 }
 
 
@@ -1176,12 +1180,11 @@ QString sampleBuffer::tryToMakeAbsolute( const QString & _file )
 
 sampleBuffer::handleState::handleState( bool _varying_pitch ) :
 	m_frameIndex( 0 ),
-	m_varyingPitch( _varying_pitch ),
-	m_eof( 0 )
+	m_varyingPitch( _varying_pitch )
 {
 	int error;
 	if( ( m_resamplingData = src_new(/*
-		( engine::getMixer()->highQuality() == TRUE ) ?
+		( engine::getMixer()->highQuality() == true ) ?
 					SRC_SINC_FASTEST :*/
 					SRC_LINEAR,
 					DEFAULT_CHANNELS, &error ) ) == NULL )
@@ -1204,4 +1207,4 @@ sampleBuffer::handleState::~handleState()
 #include "moc_sample_buffer.cxx"
 
 
-#endif
+/* vim: set tw=0 noexpandtab: */
