@@ -1,9 +1,9 @@
 /*
- * track.cpp - implementation of classes concerning tracks -> neccessary for
+ * track.cpp - implementation of classes concerning tracks -> necessary for
  *             all track-like objects (beat/bassline, sample-track...)
  *
- * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
- * 
+ * Copyright (c) 2004-2010 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or
@@ -52,15 +52,15 @@
 #include "bb_editor.h"
 #include "bb_track.h"
 #include "bb_track_container.h"
-#include "clipboard.h"
+#include "Clipboard.h"
 #include "embed.h"
 #include "engine.h"
 #include "gui_templates.h"
-#include "instrument_track.h"
-#include "main_window.h"
+#include "InstrumentTrack.h"
+#include "MainWindow.h"
 #include "mmp.h"
 #include "pixmap_button.h"
-#include "project_journal.h"
+#include "ProjectJournal.h"
 #include "sample_track.h"
 #include "song.h"
 #include "string_pair_drag.h"
@@ -106,7 +106,7 @@ textFloat * trackContentObjectView::s_textFloat = NULL;
  * \param _track The track that will contain the new object
  */
 trackContentObject::trackContentObject( track * _track ) :
-	model( _track ),
+	Model( _track ),
 	m_track( _track ),
 	m_name( QString::null ),
 	m_startPosition(),
@@ -155,7 +155,7 @@ void trackContentObject::movePosition( const midiTime & _pos )
 {
 	if( m_startPosition != _pos )
 	{
-		addJournalEntry( journalEntry( Move, m_startPosition - _pos ) );
+		addJournalEntry( JournalEntry( Move, m_startPosition - _pos ) );
 		m_startPosition = _pos;
 		engine::getSong()->updateLength();
 	}
@@ -176,7 +176,7 @@ void trackContentObject::changeLength( const midiTime & _length )
 {
 	if( m_length != _length )
 	{
-		addJournalEntry( journalEntry( Resize, m_length - _length ) );
+		addJournalEntry( JournalEntry( Resize, m_length - _length ) );
 		m_length = _length;
 		engine::getSong()->updateLength();
 	}
@@ -194,7 +194,7 @@ void trackContentObject::changeLength( const midiTime & _length )
  *
  * \param _je The journal entry to undo
  */
-void trackContentObject::undoStep( journalEntry & _je )
+void trackContentObject::undoStep( JournalEntry & _je )
 {
 	saveJournallingState( false );
 	switch( _je.actionID() )
@@ -218,9 +218,9 @@ void trackContentObject::undoStep( journalEntry & _je )
  *
  * \param _je The journal entry to redo
  */
-void trackContentObject::redoStep( journalEntry & _je )
+void trackContentObject::redoStep( JournalEntry & _je )
 {
-	journalEntry je( _je.actionID(), -_je.data().toInt() );
+	JournalEntry je( _je.actionID(), -_je.data().toInt() );
 	undoStep( je );
 }
 
@@ -231,9 +231,9 @@ void trackContentObject::redoStep( journalEntry & _je )
  *
  *  Copies this track content object to the clipboard.
  */
-void trackContentObject::copy( void )
+void trackContentObject::copy()
 {
-	clipboard::copy( this );
+	Clipboard::copy( this );
 }
 
 
@@ -245,11 +245,13 @@ void trackContentObject::copy( void )
  *
  * \param _je The journal entry to undo
  */
-void trackContentObject::paste( void )
+void trackContentObject::paste()
 {
-	if( clipboard::getContent( nodeName() ) != NULL )
+	if( Clipboard::getContent( nodeName() ) != NULL )
 	{
-		restoreState( *( clipboard::getContent( nodeName() ) ) );
+		const midiTime pos = startPosition();
+		restoreState( *( Clipboard::getContent( nodeName() ) ) );
+		movePosition( pos );
 	}
 }
 
@@ -264,7 +266,7 @@ void trackContentObject::paste( void )
  *
  * \param _je The journal entry to undo
  */
-void trackContentObject::toggleMute( void )
+void trackContentObject::toggleMute()
 {
 	m_mutedModel.setValue( !m_mutedModel.value() );
 	emit dataChanged();
@@ -290,7 +292,7 @@ void trackContentObject::toggleMute( void )
 trackContentObjectView::trackContentObjectView( trackContentObject * _tco,
 							trackView * _tv ) :
 	selectableObject( _tv->getTrackContentWidget() ),
-	modelView( NULL, this ),
+	ModelView( NULL, this ),
 	m_tco( _tco ),
 	m_trackView( _tv ),
 	m_action( NoAction ),
@@ -354,9 +356,9 @@ trackContentObjectView::~trackContentObjectView()
  * \todo What the hell is a TCO here - track content object?  And in
  *  what circumstance are they fixed?
  */
-bool trackContentObjectView::fixedTCOs( void )
+bool trackContentObjectView::fixedTCOs()
 {
-	return( m_trackView->getTrackContainerView()->fixedTCOs() );
+	return m_trackView->getTrackContainerView()->fixedTCOs();
 }
 
 
@@ -369,10 +371,10 @@ bool trackContentObjectView::fixedTCOs( void )
  *
  * \return Boolean state of whether the QWidget was able to close.
  */
-bool trackContentObjectView::close( void )
+bool trackContentObjectView::close()
 {
 	m_trackView->getTrackContentWidget()->removeTCOView( this );
-	return( QWidget::close() );
+	return QWidget::close();
 }
 
 
@@ -385,7 +387,7 @@ bool trackContentObjectView::close( void )
  *  scheduled for later deletion rather than closed immediately.
  *
  */
-void trackContentObjectView::remove( void )
+void trackContentObjectView::remove()
 {
 	// delete ourself
 	close();
@@ -400,7 +402,7 @@ void trackContentObjectView::remove( void )
  *  Perform the 'cut' action of the clipboard - copies the track content
  *  object to the clipboard and then removes it from the track.
  */
-void trackContentObjectView::cut( void )
+void trackContentObjectView::cut()
 {
 	m_tco->copy();
 	remove();
@@ -416,7 +418,7 @@ void trackContentObjectView::cut( void )
  *  the track content object's length in pixels adding in the border.
  *
  */
-void trackContentObjectView::updateLength( void )
+void trackContentObjectView::updateLength()
 {
 	if( fixedTCOs() )
 	{
@@ -442,7 +444,7 @@ void trackContentObjectView::updateLength( void )
  *  view's length.
  *
  */
-void trackContentObjectView::updatePosition( void )
+void trackContentObjectView::updatePosition()
 {
 	m_trackView->getTrackContentWidget()->changePosition();
 	// moving a TCO can result in change of song-length etc.,
@@ -578,7 +580,7 @@ void trackContentObjectView::mousePressEvent( QMouseEvent * _me )
 					mmp.toString(), thumbnail, this );
 	}
 	else if( _me->button() == Qt::LeftButton &&
-		/*	engine::getMainWindow()->isShiftPressed() == false &&*/
+		/*	engine::mainWindow()->isShiftPressed() == false &&*/
 							fixedTCOs() == false )
 	{
 		// move or resize
@@ -777,7 +779,7 @@ void trackContentObjectView::mouseReleaseEvent( QMouseEvent * _me )
 	if( m_action == Move || m_action == Resize )
 	{
 		m_tco->setJournalling( true );
-		m_tco->addJournalEntry( journalEntry( m_action, m_oldTime -
+		m_tco->addJournalEntry( JournalEntry( m_action, m_oldTime -
 			( ( m_action == Move ) ?
 				m_tco->startPosition() : m_tco->length() ) ) );
 	}
@@ -832,9 +834,9 @@ void trackContentObjectView::contextMenuEvent( QContextMenuEvent * _cme )
  *
  * \return the number of pixels per tact (bar).
  */
-float trackContentObjectView::pixelsPerTact( void )
+float trackContentObjectView::pixelsPerTact()
 {
-	return( m_trackView->getTrackContainerView()->pixelsPerTact() );
+	return m_trackView->getTrackContainerView()->pixelsPerTact();
 }
 
 
@@ -873,6 +875,8 @@ trackContentWidget::trackContentWidget( trackView * _parent ) :
 	connect( _parent->getTrackContainerView(),
 			SIGNAL( positionChanged( const midiTime & ) ),
 			this, SLOT( changePosition( const midiTime & ) ) );
+
+	updateBackground();
 }
 
 
@@ -889,6 +893,60 @@ trackContentWidget::~trackContentWidget()
 
 
 
+void trackContentWidget::updateBackground()
+{
+	const int tactsPerBar = 4;
+	const trackContainerView * tcv = m_trackView->getTrackContainerView();
+
+	// Assume even-pixels-per-tact. Makes sense, should be like this anyways
+	int ppt = static_cast<int>( tcv->pixelsPerTact() );
+
+    int w = ppt * tactsPerBar;
+    int h = height();
+    m_background = QPixmap( w * 2, height() );
+    QPainter pmp( &m_background );
+
+    QLinearGradient grad( 0, 1, 0, h-2 );
+    pmp.fillRect( 0, 0, 1, h, QColor( 96, 96, 96 ) );
+    pmp.fillRect( 1, 0, w+1, h, QColor( 128, 128, 128 ) );
+    grad.setColorAt( 0.0, QColor( 64, 64, 64 ) );
+    grad.setColorAt( 0.3, QColor( 128, 128, 128 ) );
+    grad.setColorAt( 0.5, QColor( 128, 128, 128 ) );
+    grad.setColorAt( 0.95, QColor( 160, 160, 160 ) );
+    pmp.fillRect( 0, 1, w, h-2, grad );
+
+    QLinearGradient grad2( 0,1, 0, h-2 );
+    pmp.fillRect( w+1, 0, w , h, QColor( 96, 96, 96 ) );
+    grad2.setColorAt( 0.0, QColor( 48, 48, 48 ) );
+    grad2.setColorAt( 0.3, QColor( 96, 96, 96 ) );
+    grad2.setColorAt( 0.5, QColor( 96, 96, 96 ) );
+    grad2.setColorAt( 0.95, QColor( 120, 120, 120 ) );
+    pmp.fillRect( w, 1, w , h-2, grad2 );
+
+    // draw vertical lines
+    pmp.setPen( QPen( QColor( 0, 0, 0, 112 ), 1 ) );
+    for( float x = 0.5; x < w * 2; x += ppt )
+    {
+        pmp.drawLine( QLineF( x, 1.0, x, h-2.0 ) );
+    }
+    pmp.drawLine( 0, 1, w*2, 1 );
+
+    pmp.setPen( QPen( QColor( 255, 255, 255, 32 ), 1 ) );
+    for( float x = 1.5; x < w * 2; x += ppt )
+    {
+        pmp.drawLine( QLineF( x, 1.0, x, h-2.0 ) );
+    }
+    pmp.drawLine( 0, h-2, w*2, h-2 );
+
+    pmp.end();
+
+    // Force redraw
+	update();
+}
+
+
+
+
 /*! \brief Adds a trackContentObjectView to this widget.
  *
  *  Adds a(nother) trackContentObjectView to our list of views.  We also
@@ -901,7 +959,7 @@ void trackContentWidget::addTCOView( trackContentObjectView * _tcov )
 	trackContentObject * tco = _tcov->getTrackContentObject();
 /*	QMap<QString, QVariant> map;
 	map["id"] = tco->id();
-	addJournalEntry( journalEntry( AddTrackContentObject, map ) );*/
+	addJournalEntry( JournalEntry( AddTrackContentObject, map ) );*/
 
 	m_tcoViews.push_back( _tcov );
 
@@ -931,7 +989,7 @@ void trackContentWidget::removeTCOView( trackContentObjectView * _tcov )
 		_tcov->getTrackContentObject()->saveState( mmp, mmp.content() );
 		map["id"] = _tcov->getTrackContentObject()->id();
 		map["state"] = mmp.toString();
-		addJournalEntry( journalEntry( RemoveTrackContentObject,
+		addJournalEntry( JournalEntry( RemoveTrackContentObject,
 								map ) );*/
 
 		m_tcoViews.erase( it );
@@ -945,7 +1003,7 @@ void trackContentWidget::removeTCOView( trackContentObjectView * _tcov )
 /*! \brief Update ourselves by updating all the tCOViews attached.
  *
  */
-void trackContentWidget::update( void )
+void trackContentWidget::update()
 {
 	for( tcoViewVector::iterator it = m_tcoViews.begin();
 				it != m_tcoViews.end(); ++it )
@@ -1148,60 +1206,14 @@ void trackContentWidget::paintEvent( QPaintEvent * _pe )
 
 
 
-/*! \brief Resize the trackContentWidget
+/*! \brief Updates the background tile pixmap on size changes.
  *
- * \param _re the resize event to respond to
+ * \param resizeEvent the resize event to pass to base class
  */
-void trackContentWidget::resizeEvent( QResizeEvent * _re )
+void trackContentWidget::resizeEvent( QResizeEvent * resizeEvent )
 {
-    // Update backgroud
-	const int tactsPerBar = 4;
-	const trackContainerView * tcv = m_trackView->getTrackContainerView();
-
-	// Assume even-pixels-per-tact. Makes sense, should be like this anyways
-	int ppt = static_cast<int>( tcv->pixelsPerTact() );
-
-    int w = ppt * tactsPerBar;
-    int h = height();
-    m_background = QPixmap( w * 2, height() );
-    QPainter pmp( &m_background );
-
-    QLinearGradient grad( 0, 1, 0, h-2 );
-    pmp.fillRect( 0, 0, 1, h, QColor( 96, 96, 96 ) );
-    pmp.fillRect( 1, 0, w+1, h, QColor( 128, 128, 128 ) );
-    grad.setColorAt( 0.0, QColor( 64, 64, 64 ) );
-    grad.setColorAt( 0.3, QColor( 128, 128, 128 ) );
-    grad.setColorAt( 0.5, QColor( 128, 128, 128 ) );
-    grad.setColorAt( 0.95, QColor( 160, 160, 160 ) );
-    pmp.fillRect( 0, 1, w, h-2, grad );
-
-    QLinearGradient grad2( 0,1, 0, h-2 );
-    pmp.fillRect( w+1, 0, w , h, QColor( 96, 96, 96 ) );
-    grad2.setColorAt( 0.0, QColor( 48, 48, 48 ) );
-    grad2.setColorAt( 0.3, QColor( 96, 96, 96 ) );
-    grad2.setColorAt( 0.5, QColor( 96, 96, 96 ) );
-    grad2.setColorAt( 0.95, QColor( 120, 120, 120 ) );
-    pmp.fillRect( w, 1, w , h-2, grad2 );
-
-    // draw vertical lines
-    pmp.setPen( QPen( QColor( 0, 0, 0, 112 ), 1 ) );
-    for( float x = 0.5; x < w * 2; x += ppt )
-    {
-        pmp.drawLine( QLineF( x, 1.0, x, h-2.0 ) );
-    }
-    pmp.drawLine( 0, 1, w*2, 1 );
-
-    pmp.setPen( QPen( QColor( 255, 255, 255, 32 ), 1 ) );
-    for( float x = 1.5; x < w * 2; x += ppt )
-    {
-        pmp.drawLine( QLineF( x, 1.0, x, h-2.0 ) );
-    }
-    pmp.drawLine( 0, h-2, w*2, h-2 );
-
-    pmp.end();
-
-    // Force redraw
-	update();
+	updateBackground();
+	QWidget::resizeEvent( resizeEvent );
 }
 
 
@@ -1211,7 +1223,7 @@ void trackContentWidget::resizeEvent( QResizeEvent * _re )
  *
  * \param _je the details of the edit journal
  */
-void trackContentWidget::undoStep( journalEntry & _je )
+void trackContentWidget::undoStep( JournalEntry & _je )
 {
 	saveJournallingState( false );
 	switch( _je.actionID() )
@@ -1221,10 +1233,8 @@ void trackContentWidget::undoStep( journalEntry & _je )
 			QMap<QString, QVariant> map = _je.data().toMap();
 			trackContentObject * tco =
 				dynamic_cast<trackContentObject *>(
-			engine::getProjectJournal()->getJournallingObject(
-							map["id"].toInt() ) );
-			multimediaProject mmp(
-					multimediaProject::JournalData );
+			engine::projectJournal()->journallingObject( map["id"].toInt() ) );
+			multimediaProject mmp( multimediaProject::JournalData );
 			tco->saveState( mmp, mmp.content() );
 			map["state"] = mmp.toString();
 			_je.data() = map;
@@ -1234,13 +1244,11 @@ void trackContentWidget::undoStep( journalEntry & _je )
 
 		case RemoveTrackContentObject:
 		{
-			trackContentObject * tco = getTrack()->createTCO(
-								midiTime( 0 ) );
+			trackContentObject * tco = getTrack()->createTCO( midiTime( 0 ) );
 			multimediaProject mmp(
 				_je.data().toMap()["state"].
 					toString().toUtf8() );
-			tco->restoreState(
-				mmp.content().firstChild().toElement() );
+			tco->restoreState( mmp.content().firstChild().toElement() );
 			break;
 		}
 	}
@@ -1254,7 +1262,7 @@ void trackContentWidget::undoStep( journalEntry & _je )
  *
  * \param _je the entry in the edit journal to redo.
  */
-void trackContentWidget::redoStep( journalEntry & _je )
+void trackContentWidget::redoStep( JournalEntry & _je )
 {
 	switch( _je.actionID() )
 	{
@@ -1279,9 +1287,9 @@ void trackContentWidget::redoStep( journalEntry & _je )
 /*! \brief Return the track shown by the trackContentWidget
  *
  */
-track * trackContentWidget::getTrack( void )
+track * trackContentWidget::getTrack()
 {
-	return( m_trackView->getTrack() );
+	return m_trackView->getTrack();
 }
 
 
@@ -1293,11 +1301,11 @@ track * trackContentWidget::getTrack( void )
  */
 midiTime trackContentWidget::getPosition( int _mouse_x )
 {
-	return( midiTime( m_trackView->getTrackContainerView()->
+	return midiTime( m_trackView->getTrackContainerView()->
 					currentPosition() + _mouse_x *
 						midiTime::ticksPerTact() /
 			static_cast<int>( m_trackView->
-				getTrackContainerView()->pixelsPerTact() ) ) );
+				getTrackContainerView()->pixelsPerTact() ) );
 }
 
 
@@ -1310,8 +1318,7 @@ midiTime trackContentWidget::endPosition( const midiTime & _pos_start )
 {
 	const float ppt = m_trackView->getTrackContainerView()->pixelsPerTact();
 	const int w = width();
-	return( _pos_start + static_cast<int>( w * midiTime::ticksPerTact() /
-									ppt ) );
+	return _pos_start + static_cast<int>( w * midiTime::ticksPerTact() / ppt );
 }
 
 
@@ -1466,7 +1473,7 @@ void trackOperationsWidget::paintEvent( QPaintEvent * _pe )
 /*! \brief Clone this track
  *
  */
-void trackOperationsWidget::cloneTrack( void )
+void trackOperationsWidget::cloneTrack()
 {
 	engine::getMixer()->lock();
 	m_trackView->getTrack()->clone();
@@ -1479,7 +1486,7 @@ void trackOperationsWidget::cloneTrack( void )
 /*! \brief Remove this track from the track list
  *
  */
-void trackOperationsWidget::removeTrack( void )
+void trackOperationsWidget::removeTrack()
 {
 	emit trackRemovalScheduled( m_trackView );
 }
@@ -1492,7 +1499,7 @@ void trackOperationsWidget::removeTrack( void )
  *  For all track types, we have the Clone and Remove options.
  *  For instrument-tracks we also offer the MIDI-control-menu
  */
-void trackOperationsWidget::updateMenu( void )
+void trackOperationsWidget::updateMenu()
 {
 	QMenu * to_menu = m_trackOps->menu();
 	to_menu->clear();
@@ -1503,10 +1510,10 @@ void trackOperationsWidget::updateMenu( void )
 						tr( "Remove this track" ),
 						this, SLOT( removeTrack() ) );
 
-	if( dynamic_cast<instrumentTrackView *>( m_trackView ) )
+	if( dynamic_cast<InstrumentTrackView *>( m_trackView ) )
 	{
 		to_menu->addSeparator();
-		to_menu->addMenu( dynamic_cast<instrumentTrackView *>(
+		to_menu->addMenu( dynamic_cast<InstrumentTrackView *>(
 						m_trackView )->midiMenu() );
 	}
 }
@@ -1530,7 +1537,7 @@ void trackOperationsWidget::updateMenu( void )
  * \todo check the definitions of all the properties - are they OK?
  */
 track::track( TrackTypes _type, trackContainer * _tc ) :
-	model( _tc ),                   /*!< The track model */
+	Model( _tc ),                   /*!< The track Model */
 	m_trackContainer( _tc ),        /*!< The track container object */
 	m_type( _type ),                /*!< The track type */
 	m_name(),                       /*!< The track's name */
@@ -1583,7 +1590,7 @@ track * track::create( TrackTypes _tt, trackContainer * _tc )
 
 	switch( _tt )
 	{
-		case InstrumentTrack: t = new instrumentTrack( _tc ); break;
+		case InstrumentTrack: t = new ::InstrumentTrack( _tc ); break;
 		case BBTrack: t = new bbTrack( _tc ); break;
 		case SampleTrack: t = new sampleTrack( _tc ); break;
 //		case EVENT_TRACK:
@@ -1596,7 +1603,7 @@ track * track::create( TrackTypes _tt, trackContainer * _tc )
 
 	_tc->updateAfterTrackAdd();
 
-	return( t );
+	return t;
 }
 
 
@@ -1616,7 +1623,7 @@ track * track::create( const QDomElement & _this, trackContainer * _tc )
 	{
 		t->restoreState( _this );
 	}
-	return( t );
+	return t;
 }
 
 
@@ -1625,7 +1632,7 @@ track * track::create( const QDomElement & _this, trackContainer * _tc )
 /*! \brief Clone a track from this track
  *
  */
-void track::clone( void )
+void track::clone()
 {
 	QDomDocument doc;
 	QDomElement parent = doc.createElement( "clone" );
@@ -1662,7 +1669,7 @@ void track::saveSettings( QDomDocument & _doc, QDomElement & _this )
 //	_this.setAttribute( "height", m_trackView->height() );
 
 	QDomElement ts_de = _doc.createElement( nodeName() );
-	// let actual track (instrumentTrack, bbTrack, sampleTrack etc.) save
+	// let actual track (InstrumentTrack, bbTrack, sampleTrack etc.) save
 	// its settings
 	_this.appendChild( ts_de );
 	saveTrackSpecificSettings( _doc, ts_de );
@@ -1791,8 +1798,11 @@ void track::removeTCO( trackContentObject * _tco )
 	if( it != m_trackContentObjects.end() )
 	{
 		m_trackContentObjects.erase( it );
-		engine::getSong()->updateLength();
-		engine::getSong()->setModified();
+		if( engine::getSong() )
+		{
+			engine::getSong()->updateLength();
+			engine::getSong()->setModified();
+		}
 	}
 }
 
@@ -1803,9 +1813,9 @@ void track::removeTCO( trackContentObject * _tco )
  *
  *  \return the number of trackContentObjects we currently contain.
  */
-int track::numOfTCOs( void )
+int track::numOfTCOs()
 {
-	return( m_trackContentObjects.size() );
+	return m_trackContentObjects.size();
 }
 
 
@@ -1827,11 +1837,11 @@ trackContentObject * track::getTCO( int _tco_num )
 {
 	if( _tco_num < m_trackContentObjects.size() )
 	{
-		return( m_trackContentObjects[_tco_num] );
+		return m_trackContentObjects[_tco_num];
 	}
 	printf( "called track::getTCO( %d ), "
 			"but TCO %d doesn't exist\n", _tco_num, _tco_num );
-	return( createTCO( _tco_num * midiTime::ticksPerTact() ) );
+	return createTCO( _tco_num * midiTime::ticksPerTact() );
 	
 }
 
@@ -1853,12 +1863,12 @@ int track::getTCONum( trackContentObject * _tco )
 	{
 /*		if( getTCO( i ) == _tco )
 		{
-			return( i );
+			return i;
 		}*/
-		return( it - m_trackContentObjects.begin() );
+		return it - m_trackContentObjects.begin();
 	}
 	qWarning( "track::getTCONum(...) -> _tco not found!\n" );
-	return( 0 );
+	return 0;
 }
 
 
@@ -1990,7 +2000,7 @@ void track::removeTact( const midiTime & _pos )
  *  keeping track of the latest time found in ticks.  Then we return
  *  that in bars by dividing by the number of ticks per bar.
  */
-tact_t track::length( void ) const
+tact_t track::length() const
 {
 	// find last end-position
 	tick_t last = 0;
@@ -2015,7 +2025,7 @@ tact_t track::length( void ) const
  *  is already soloed.  Then we have to save the mute state of all tracks,
  *  and set our mute state to on and all the others to off.
  */
-void track::toggleSolo( void )
+void track::toggleSolo()
 {
 	const trackContainer::trackList & tl = m_trackContainer->tracks();
 
@@ -2077,7 +2087,7 @@ void track::toggleSolo( void )
  */
 trackView::trackView( track * _track, trackContainerView * _tcv ) :
 	QWidget( _tcv->contentWidget() ),   /*!< The Track Container View's content widget. */
-	modelView( NULL, this ),            /*!< The model view of this track */
+	ModelView( NULL, this ),            /*!< The model view of this track */
 	m_track( _track ),                  /*!< The track we're displaying */
 	m_trackContainerView( _tcv ),       /*!< The track Container View we're displayed in */
 	m_trackOperationsWidget( this ),    /*!< Our trackOperationsWidget */
@@ -2158,7 +2168,7 @@ void trackView::resizeEvent( QResizeEvent * _re )
 /*! \brief Update this track View and all its content objects.
  *
  */
-void trackView::update( void )
+void trackView::update()
 {
 	m_trackContentWidget.update();
 	if( !m_trackContainerView->fixedTCOs() )
@@ -2174,10 +2184,10 @@ void trackView::update( void )
 /*! \brief Close this track View.
  *
  */
-bool trackView::close( void )
+bool trackView::close()
 {
 	m_trackContainerView->removeTrackView( this );
-	return( QWidget::close() );
+	return QWidget::close();
 }
 
 
@@ -2186,14 +2196,14 @@ bool trackView::close( void )
 /*! \brief Register that the model of this track View has changed.
  *
  */
-void trackView::modelChanged( void )
+void trackView::modelChanged()
 {
 	m_track = castModel<track>();
 	assert( m_track != NULL );
 	connect( m_track, SIGNAL( destroyedTrack() ), this, SLOT( close() ) );
 	m_trackOperationsWidget.m_muteBtn->setModel( &m_track->m_mutedModel );
 	m_trackOperationsWidget.m_soloBtn->setModel( &m_track->m_soloModel );
-	modelView::modelChanged();
+	ModelView::modelChanged();
 }
 
 
@@ -2203,7 +2213,7 @@ void trackView::modelChanged( void )
  *
  *  \param _je the Journal Entry to undo.
  */
-void trackView::undoStep( journalEntry & _je )
+void trackView::undoStep( JournalEntry & _je )
 {
 	saveJournallingState( false );
 	switch( _je.actionID() )
@@ -2235,9 +2245,9 @@ void trackView::undoStep( journalEntry & _je )
  *
  *  \param _je the Journal Event to redo.
  */
-void trackView::redoStep( journalEntry & _je )
+void trackView::redoStep( JournalEntry & _je )
 {
-	journalEntry je( _je.actionID(), -_je.data().toInt() );
+	JournalEntry je( _je.actionID(), -_je.data().toInt() );
 	undoStep( je );
 }
 
@@ -2376,7 +2386,7 @@ void trackView::mouseMoveEvent( QMouseEvent * _me )
 			{
 				m_trackContainerView->moveTrackViewDown( this );
 			}
-			addJournalEntry( journalEntry( MoveTrack, _me->y() ) );
+			addJournalEntry( JournalEntry( MoveTrack, _me->y() ) );
 		}
 	}
 	else if( m_action == ResizeTrack )
