@@ -24,10 +24,8 @@
  *
  */
 
-
 #include "automation_editor.h"
 
-
 #include <QtGui/QApplication>
 #include <QtGui/QButtonGroup>
 #include <QtGui/QKeyEvent>
@@ -48,7 +46,7 @@
 
 
 #include "song_editor.h"
-#include "main_window.h"
+#include "MainWindow.h"
 #include "embed.h"
 #include "engine.h"
 #include "pixmap_button.h"
@@ -72,11 +70,12 @@ QPixmap * automationEditor::s_toolSelect = NULL;
 QPixmap * automationEditor::s_toolMove = NULL;
 
 
-automationEditor::automationEditor( void ) :
+automationEditor::automationEditor() :
 	QWidget(),
 	m_zoomingXModel(),
 	m_zoomingYModel(),
 	m_quantizeModel(),
+	m_patternMutex( QMutex::Recursive ),
 	m_pattern( NULL ),
 	m_minLevel( 0 ),
 	m_maxLevel( 0 ),
@@ -94,6 +93,10 @@ automationEditor::automationEditor( void ) :
 	m_editMode( DRAW ),
 	m_scrollBack( FALSE )
 {
+	connect( this, SIGNAL( currentPatternChanged() ),
+				this, SLOT( updateAfterPatternChange() ),
+				Qt::QueuedConnection );
+
 	// init pixmaps
 	if( s_toolDraw == NULL )
 	{
@@ -223,7 +226,7 @@ automationEditor::automationEditor( void ) :
 			"'Shift+E' on your keyboard to activate this mode." ) );
 	m_selectButton->setWhatsThis(
 		tr( "Click here and select-mode will be activated. In this "
-			"mode you can select values. This is neccessary "
+			"mode you can select values. This is necessary "
 			"if you want to cut, copy, paste, delete, or move "
 			"values. You can also press 'Shift+S' on your keyboard "
 			"to activate this mode." ) );
@@ -308,7 +311,7 @@ automationEditor::automationEditor( void ) :
 	m_quantizeComboBox->setFixedSize( 60, 22 );
 
 	// TODO: leak
-	comboBoxModel * quantize_model = new comboBoxModel( /* this */ );
+	ComboBoxModel * quantize_model = new ComboBoxModel( /* this */ );
 	for( int i = 0; i < 7; ++i )
 	{
 		quantize_model->addItem( "1/" + QString::number( 1 << i ) );
@@ -357,9 +360,9 @@ automationEditor::automationEditor( void ) :
 	setMinimumSize( tb_layout->minimumSize().width(), 128 );
 
 	// add us to workspace
-	if( engine::getMainWindow()->workspace() )
+	if( engine::mainWindow()->workspace() )
 	{
-		engine::getMainWindow()->workspace()->addSubWindow( this );
+		engine::mainWindow()->workspace()->addSubWindow( this );
 		parentWidget()->resize( INITIAL_WIDTH, INITIAL_HEIGHT );
 		parentWidget()->hide();
 	}
@@ -375,6 +378,8 @@ automationEditor::automationEditor( void ) :
 
 automationEditor::~automationEditor()
 {
+	m_zoomingXModel.disconnect();
+	m_zoomingYModel.disconnect();
 }
 
 
@@ -382,10 +387,39 @@ automationEditor::~automationEditor()
 
 void automationEditor::setCurrentPattern( automationPattern * _new_pattern )
 {
+	m_patternMutex.lock();
 	m_pattern = _new_pattern;
+	m_patternMutex.unlock();
+
+	emit currentPatternChanged();
+}
+
+
+
+
+void automationEditor::saveSettings( QDomDocument & _doc, QDomElement & _this )
+{
+	MainWindow::saveWidgetState( this, _this );
+}
+
+
+
+
+void automationEditor::loadSettings( const QDomElement & _this )
+{
+	MainWindow::restoreWidgetState( this, _this );
+}
+
+
+
+
+void automationEditor::updateAfterPatternChange()
+{
+	QMutexLocker m( &m_patternMutex );
+
 	m_currentPosition = 0;
 
-	if( validPattern() == FALSE )
+	if( !validPattern() )
 	{
 		setWindowTitle( tr( "Automation Editor - no pattern" ) );
 		m_minLevel = m_maxLevel = m_scrollLevel = 0;
@@ -403,8 +437,7 @@ void automationEditor::setCurrentPattern( automationPattern * _new_pattern )
 	// of levels and so on...)
 	resizeEvent( NULL );
 
-	setWindowTitle( tr( "Automation Editor - %1" ).arg(
-							m_pattern->name() ) );
+	setWindowTitle( tr( "Automation Editor - %1" ).arg( m_pattern->name() ) );
 
 	update();
 }
@@ -412,17 +445,16 @@ void automationEditor::setCurrentPattern( automationPattern * _new_pattern )
 
 
 
-void automationEditor::saveSettings( QDomDocument & _doc, QDomElement & _this )
+void automationEditor::update()
 {
-	mainWindow::saveWidgetState( this, _this );
-}
+	QWidget::update();
 
-
-
-
-void automationEditor::loadSettings( const QDomElement & _this )
-{
-	mainWindow::restoreWidgetState( this, _this );
+	QMutexLocker m( &m_patternMutex );
+	// Note detuning?
+	if( m_pattern && !m_pattern->getTrack() )
+	{
+		engine::getPianoRoll()->update();
+	}
 }
 
 
@@ -450,7 +482,7 @@ inline void automationEditor::drawValueRect( QPainter & _p,
 
 
 
-void automationEditor::removeSelection( void )
+void automationEditor::removeSelection()
 {
 	m_selectStartTick = 0;
 	m_selectedTick = 0;
@@ -691,7 +723,8 @@ void automationEditor::drawLine( int _x0, float _y0, int _x1, float _y1 )
 
 void automationEditor::mousePressEvent( QMouseEvent * _me )
 {
-	if( validPattern() == FALSE )
+	QMutexLocker m( &m_patternMutex );
+	if( !validPattern() )
 	{
 		return;
 	}
@@ -854,7 +887,8 @@ void automationEditor::mouseReleaseEvent( QMouseEvent * _me )
 
 void automationEditor::mouseMoveEvent( QMouseEvent * _me )
 {
-	if( validPattern() == FALSE )
+	QMutexLocker m( &m_patternMutex );
+	if( !validPattern() )
 	{
 		update();
 		return;
@@ -1228,6 +1262,8 @@ inline void automationEditor::drawCross( QPainter & _p )
 
 void automationEditor::paintEvent( QPaintEvent * _pe )
 {
+	QMutexLocker m( &m_patternMutex );
+
 	QStyleOption opt;
 	opt.initFrom( this );
 	QPainter p( this );
@@ -1249,7 +1285,7 @@ void automationEditor::paintEvent( QPaintEvent * _pe )
 	Qt::Alignment text_flags =
 		(Qt::Alignment)( Qt::AlignRight | Qt::AlignVCenter );
 
-	if( m_pattern )
+	if( validPattern() )
 	{
 		if( m_y_auto )
 		{
@@ -1398,7 +1434,7 @@ void automationEditor::paintEvent( QPaintEvent * _pe )
 		qSwap<float>( selLevel_start, selLevel_end );
 	}
 
-	if( validPattern() == TRUE )
+	if( validPattern() )
 	{
 		timeMap & time_map = m_pattern->getTimeMap();
 		timeMap::iterator it = time_map.begin();
@@ -1534,7 +1570,7 @@ void automationEditor::paintEvent( QPaintEvent * _pe )
 	p.drawRect( x + VALUES_WIDTH, y, w, h );
 
 	// TODO: Get this out of paint event
-	int l = ( validPattern() == TRUE )? (int) m_pattern->length() : 0;
+	int l = validPattern() ? (int) m_pattern->length() : 0;
 
 	// reset scroll-range
 	if( m_leftRightScroll->maximum() != l )
@@ -1543,7 +1579,7 @@ void automationEditor::paintEvent( QPaintEvent * _pe )
 		m_leftRightScroll->setPageStep( l );
 	}
 
-	if( validPattern() == TRUE )
+	if( validPattern() )
 	{
 		drawCross( p );
 	}
@@ -1670,18 +1706,22 @@ float automationEditor::getLevel( int _y )
 
 
 
-inline bool automationEditor::inBBEditor( void )
+inline bool automationEditor::inBBEditor()
 {
-	return( m_pattern->getTrack()->getTrackContainer()
+	QMutexLocker m( &m_patternMutex );
+	return( validPattern() &&
+				m_pattern->getTrack()->getTrackContainer()
 					== engine::getBBTrackContainer() );
 }
 
 
 
 
-void automationEditor::play( void )
+void automationEditor::play()
 {
-	if( validPattern() == FALSE )
+	QMutexLocker m( &m_patternMutex );
+
+	if( !validPattern() )
 	{
 		return;
 	}
@@ -1753,8 +1793,10 @@ void automationEditor::play( void )
 
 
 
-void automationEditor::stop( void )
+void automationEditor::stop()
 {
+	QMutexLocker m( &m_patternMutex );
+
 	if( !validPattern() )
 	{
 		return;
@@ -1795,7 +1837,7 @@ void automationEditor::verScrolled( int _new_pos )
 
 
 
-void automationEditor::drawButtonToggled( void )
+void automationEditor::drawButtonToggled()
 {
 	m_editMode = DRAW;
 	removeSelection();
@@ -1805,7 +1847,7 @@ void automationEditor::drawButtonToggled( void )
 
 
 
-void automationEditor::eraseButtonToggled( void )
+void automationEditor::eraseButtonToggled()
 {
 	m_editMode = ERASE;
 	removeSelection();
@@ -1815,7 +1857,7 @@ void automationEditor::eraseButtonToggled( void )
 
 
 
-void automationEditor::selectButtonToggled( void )
+void automationEditor::selectButtonToggled()
 {
 	m_editMode = SELECT;
 	removeSelection();
@@ -1825,7 +1867,7 @@ void automationEditor::selectButtonToggled( void )
 
 
 
-void automationEditor::moveButtonToggled( void )
+void automationEditor::moveButtonToggled()
 {
 	m_editMode = MOVE;
 	m_selValuesForMove.clear();
@@ -1836,9 +1878,10 @@ void automationEditor::moveButtonToggled( void )
 
 
 
-void automationEditor::selectAll( void )
+void automationEditor::selectAll()
 {
-	if( validPattern() == FALSE )
+	QMutexLocker m( &m_patternMutex );
+	if( !validPattern() )
 	{
 		return;
 	}
@@ -1876,7 +1919,8 @@ void automationEditor::selectAll( void )
 // returns vector with pointers to all selected values
 void automationEditor::getSelectedValues( timeMap & _selected_values )
 {
-	if( validPattern() == FALSE )
+	QMutexLocker m( &m_patternMutex );
+	if( !validPattern() )
 	{
 		return;
 	}
@@ -1918,7 +1962,7 @@ void automationEditor::getSelectedValues( timeMap & _selected_values )
 
 
 
-void automationEditor::copySelectedValues( void )
+void automationEditor::copySelectedValues()
 {
 	m_valuesToCopy.clear();
 
@@ -1942,9 +1986,10 @@ void automationEditor::copySelectedValues( void )
 
 
 
-void automationEditor::cutSelectedValues( void )
+void automationEditor::cutSelectedValues()
 {
-	if( validPattern() == FALSE )
+	QMutexLocker m( &m_patternMutex );
+	if( !validPattern() )
 	{
 		return;
 	}
@@ -1973,14 +2018,10 @@ void automationEditor::cutSelectedValues( void )
 
 
 
-void automationEditor::pasteValues( void )
+void automationEditor::pasteValues()
 {
-	if( validPattern() == FALSE )
-	{
-		return;
-	}
-
-	if( !m_valuesToCopy.isEmpty() )
+	QMutexLocker m( &m_patternMutex );
+	if( validPattern() && !m_valuesToCopy.isEmpty() )
 	{
 		for( timeMap::iterator it = m_valuesToCopy.begin();
 					it != m_valuesToCopy.end(); ++it )
@@ -2000,9 +2041,10 @@ void automationEditor::pasteValues( void )
 
 
 
-void automationEditor::deleteSelectedValues( void )
+void automationEditor::deleteSelectedValues()
 {
-	if( validPattern() == FALSE )
+	QMutexLocker m( &m_patternMutex );
+	if( !validPattern() )
 	{
 		return;
 	}
@@ -2056,7 +2098,7 @@ void automationEditor::updatePosition( const midiTime & _t )
 
 
 
-void automationEditor::zoomingXChanged( void )
+void automationEditor::zoomingXChanged()
 {
 	const QString & zfac = m_zoomingXModel.currentText();
 	m_ppt = zfac.left( zfac.length() - 1 ).toInt() * DEFAULT_PPT / 100;
@@ -2070,7 +2112,7 @@ void automationEditor::zoomingXChanged( void )
 
 
 
-void automationEditor::zoomingYChanged( void )
+void automationEditor::zoomingYChanged()
 {
 	const QString & zfac = m_zoomingYModel.currentText();
 	m_y_auto = zfac == "Auto";
@@ -2088,7 +2130,7 @@ void automationEditor::zoomingYChanged( void )
 
 
 
-int automationEditor::quantization( void ) const
+int automationEditor::quantization() const
 {
 	return( DefaultTicksPerTact /
 		m_quantizeComboBox->model()->currentText().right(
@@ -2099,7 +2141,7 @@ int automationEditor::quantization( void ) const
 
 
 
-void automationEditor::updateTopBottomLevels( void )
+void automationEditor::updateTopBottomLevels()
 {
 	if( m_y_auto )
 	{
@@ -2146,19 +2188,6 @@ void automationEditor::updateTopBottomLevels( void )
 
 
 
-void automationEditor::update( void )
-{
-	QWidget::update();
-	// Note detuning?
-	if( m_pattern && !m_pattern->getTrack() )
-	{
-		engine::getPianoRoll()->update();
-	}
-}
-
-
-
-
 #include "moc_automation_editor.cxx"
 
 
