@@ -2,9 +2,9 @@
  * piano_roll.cpp - implementation of piano-roll which is used for actual
  *                  writing of melodies
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * Copyright (c) 2008 Andrew Kelley <superjoe30/at/gmail/dot/com>
- * 
+ *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or
@@ -24,9 +24,6 @@
  *
  */
 
-
-#include "piano_roll.h"
-
 #include <QtGui/QApplication>
 #include <QtGui/QButtonGroup>
 #include <QtGui/QClipboard>
@@ -35,31 +32,32 @@
 #include <QtGui/QLayout>
 #include <QtGui/QMdiArea>
 #include <QtGui/QPainter>
+#include <QtGui/QScrollBar>
 #include <QtGui/QStyleOption>
 #include <QtGui/QWheelEvent>
 #include <QString>
 #include <QSignalMapper>
 
-
 #ifndef __USE_XOPEN
 #define __USE_XOPEN
 #endif
 
 #include <math.h>
 
-
-#include "clipboard.h"
+#include "piano_roll.h"
+#include "bb_track_container.h"
+#include "Clipboard.h"
 #include "combobox.h"
 #include "debug.h"
 #include "detuning_helper.h"
 #include "embed.h"
 #include "gui_templates.h"
-#include "instrument_track.h"
-#include "main_window.h"
+#include "InstrumentTrack.h"
+#include "MainWindow.h"
 #include "midi.h"
 #include "mmp.h"
 #include "pattern.h"
-#include "piano.h"
+#include "Piano.h"
 #include "pixmap_button.h"
 #include "song.h"
 #include "song_editor.h"
@@ -136,7 +134,7 @@ pianoRoll::pianoRollKeyTypes pianoRoll::prKeyOrder[] =
 const int DEFAULT_PR_PPT = KEY_LINE_HEIGHT * DefaultStepsPerTact;
 
 
-pianoRoll::pianoRoll( void ) :
+pianoRoll::pianoRoll() :
 	m_nemStr( QVector<QString>() ),
 	m_noteEditMenu( NULL ),
 	m_signalMapper( NULL ),
@@ -149,6 +147,12 @@ pianoRoll::pianoRoll( void ) :
 	m_currentNote( NULL ),
 	m_action( ActionNone ),
 	m_noteEditMode( NoteEditVolume ),
+	m_moveBoundaryLeft( 0 ),
+	m_moveBoundaryTop( 0 ),
+	m_moveBoundaryRight( 0 ),
+	m_moveBoundaryBottom( 0 ),
+	m_mouseDownKey( 0 ),
+	m_mouseDownTick( 0 ),
 	m_lastMouseX( 0 ),
 	m_lastMouseY( 0 ),
 	m_oldNotesEditHeight( 100 ),
@@ -235,6 +239,17 @@ pianoRoll::pianoRoll( void ) :
 	connect( m_timeLine, SIGNAL( positionChanged( const midiTime & ) ),
 			this, SLOT( updatePosition( const midiTime & ) ) );
 
+	// update timeline when in record-accompany mode
+	connect( engine::getSong()->getPlayPos( song::Mode_PlaySong ).m_timeLine,
+				SIGNAL( positionChanged( const midiTime & ) ),
+			this,
+			SLOT( updatePositionAccompany( const midiTime & ) ) );
+	// TODO
+/*	connect( engine::getSong()->getPlayPos( song::Mode_PlayBB ).m_timeLine,
+				SIGNAL( positionChanged( const midiTime & ) ),
+			this,
+			SLOT( updatePositionAccompany( const midiTime & ) ) );*/
+
 
 	m_toolBar = new QWidget( this );
 	m_toolBar->setFixedHeight( 32 );
@@ -431,7 +446,7 @@ pianoRoll::pianoRoll( void ) :
 	note_len_lbl->setPixmap( embed::getIconPixmap( "note" ) );
 
 	m_noteLenModel.addItem( tr( "Last note" ),
-					new pixmapLoader( "edit_draw" ) );
+					new PixmapLoader( "edit_draw" ) );
 	const QString pixmaps[] = { "whole", "half", "quarter", "eighth",
 						"sixteenth", "thirtysecond", "triplethalf", 
 						"tripletquarter", "tripleteighth", 
@@ -440,12 +455,12 @@ pianoRoll::pianoRoll( void ) :
 	for( int i = 0; i < NUM_EVEN_LENGTHS; ++i )
 	{
 		m_noteLenModel.addItem( "1/" + QString::number( 1 << i ),
-				new pixmapLoader( "note_" + pixmaps[i] ) );
+				new PixmapLoader( "note_" + pixmaps[i] ) );
 	}
 	for( int i = 0; i < NUM_TRIPLET_LENGTHS; ++i )
 	{
 		m_noteLenModel.addItem( "1/" + QString::number( (1 << i) * 3 ),
-				new pixmapLoader( "note_" + pixmaps[i+NUM_EVEN_LENGTHS] ) );
+				new PixmapLoader( "note_" + pixmaps[i+NUM_EVEN_LENGTHS] ) );
 	}
 	m_noteLenModel.setValue( 0 );
 	m_noteLenComboBox = new comboBox( m_toolBar );
@@ -497,9 +512,9 @@ pianoRoll::pianoRoll( void ) :
 	setMinimumSize( tb_layout->minimumSize().width(), 160 );
 
 	// add us to workspace
-	if( engine::getMainWindow()->workspace() )
+	if( engine::mainWindow()->workspace() )
 	{
-		engine::getMainWindow()->workspace()->addSubWindow( this );
+		engine::mainWindow()->workspace()->addSubWindow( this );
 		parentWidget()->resize( INITIAL_PIANOROLL_WIDTH,
 						INITIAL_PIANOROLL_HEIGHT );
 		parentWidget()->hide();
@@ -531,7 +546,7 @@ void pianoRoll::setCurrentPattern( pattern * _new_pattern )
 {
 	if( validPattern() )
 	{
-		m_pattern->getInstrumentTrack()->disconnect( this );
+		m_pattern->instrumentTrack()->disconnect( this );
 	}
 
 	m_pattern = _new_pattern;
@@ -550,13 +565,13 @@ void pianoRoll::setCurrentPattern( pattern * _new_pattern )
 
 	m_leftRightScroll->setValue( 0 );
 
-	const noteVector & notes = m_pattern->notes();
+	const NoteVector & notes = m_pattern->notes();
 	int central_key = 0;
 	if( notes.empty() == false )
 	{
 		// determine the central key so that we can scroll to it
 		int total_notes = 0;
-		for( noteVector::const_iterator it = notes.begin();
+		for( NoteVector::ConstIterator it = notes.begin();
 						it != notes.end(); ++it )
 		{
 			if( ( *it )->length() > 0 )
@@ -579,11 +594,12 @@ void pianoRoll::setCurrentPattern( pattern * _new_pattern )
 	// of start-notes and so on...)
 	resizeEvent( NULL );
 
-	// and now connect to noteDone()-signal of channel so that
-	// we receive note-off-events from it's midi-port for recording it
-	connect( m_pattern->getInstrumentTrack(),
-			SIGNAL( noteDone( const note & ) ),
-			this, SLOT( recordNote( const note & ) ) );
+	connect( m_pattern->instrumentTrack(),
+			SIGNAL( noteOn( const note & ) ),
+			this, SLOT( startRecordNote( const note & ) ) );
+	connect( m_pattern->instrumentTrack(),
+			SIGNAL( noteOff( const note & ) ),
+			this, SLOT( finishRecordNote( const note & ) ) );
 
 	setWindowTitle( tr( "Piano-Roll - %1" ).arg( m_pattern->name() ) );
 
@@ -595,7 +611,7 @@ void pianoRoll::setCurrentPattern( pattern * _new_pattern )
 
 void pianoRoll::saveSettings( QDomDocument & _doc, QDomElement & _this )
 {
-	mainWindow::saveWidgetState( this, _this );
+	MainWindow::saveWidgetState( this, _this );
 }
 
 
@@ -603,7 +619,7 @@ void pianoRoll::saveSettings( QDomDocument & _doc, QDomElement & _this )
 
 void pianoRoll::loadSettings( const QDomElement & _this )
 {
-	mainWindow::restoreWidgetState( this, _this );
+	MainWindow::restoreWidgetState( this, _this );
 }
 
 
@@ -706,7 +722,7 @@ inline void pianoRoll::drawDetuningInfo( QPainter & _p, note * _n, int _x,
 	_p.setPen( QColor( 0xFF, 0xDF, 0x20 ) );
 
 	timeMap & map = _n->detuning()->getAutomationPattern()->getTimeMap();
-	for( timeMap::const_iterator it = map.begin(); it != map.end(); ++it )
+	for( timeMap::ConstIterator it = map.begin(); it != map.end(); ++it )
 	{
 		Sint32 pos_ticks = it.key();
 		if( pos_ticks > _n->length() )
@@ -727,7 +743,7 @@ inline void pianoRoll::drawDetuningInfo( QPainter & _p, note * _n, int _x,
 
 
 
-void pianoRoll::removeSelection( void )
+void pianoRoll::removeSelection()
 {
 	m_selectStartTick = 0;
 	m_selectedTick = 0;
@@ -740,15 +756,15 @@ void pianoRoll::removeSelection( void )
 
 
 
-void pianoRoll::clearSelectedNotes( void )
+void pianoRoll::clearSelectedNotes()
 {
 	if( m_pattern != NULL )
 	{
 		// get note-vector of current pattern
-		const noteVector & notes = m_pattern->notes();
+		const NoteVector & notes = m_pattern->notes();
 
 		// will be our iterator in the following loop
-		noteVector::const_iterator it = notes.begin();
+		NoteVector::ConstIterator it = notes.begin();
 		while( it != notes.end() )
 		{	
 			( *it )->setSelected( false );
@@ -781,8 +797,8 @@ void pianoRoll::closeEvent( QCloseEvent * _ce )
 void pianoRoll::shiftSemiTone( int amount ) // shift notes by amount semitones
 {
 	bool useAllNotes = ! isSelection();
-	const noteVector & notes = m_pattern->notes();
-	for( noteVector::const_iterator it = notes.begin(); it != notes.end();
+	const NoteVector & notes = m_pattern->notes();
+	for( NoteVector::ConstIterator it = notes.begin(); it != notes.end();
 									++it )
 	{
 		// if none are selected, move all notes, otherwise
@@ -805,14 +821,26 @@ void pianoRoll::shiftSemiTone( int amount ) // shift notes by amount semitones
 void pianoRoll::shiftPos( int amount ) //shift notes pos by amount
 {
 	bool useAllNotes = ! isSelection();
-	const noteVector & notes = m_pattern->notes();
-	for( noteVector::const_iterator it = notes.begin(); it != notes.end();
+	const NoteVector & notes = m_pattern->notes();
+	
+	bool first = true;
+	for( NoteVector::ConstIterator it = notes.begin(); it != notes.end();
 									++it )
 	{
 		// if none are selected, move all notes, otherwise
 		// only move selected notes
-		if( useAllNotes || ( *it )->selected() )
+		if( ( *it )->selected() || (useAllNotes && ( *it )->length() > 0) )
 		{
+			// don't let notes go to out of bounds
+			if( first )
+			{
+				m_moveBoundaryLeft = ( *it )->pos();
+				if( m_moveBoundaryLeft + amount < 0 )
+				{
+					amount += 0 - (amount + m_moveBoundaryLeft);
+				}	
+				first = false;
+			}
 			( *it )->setPos( ( *it )->pos() + amount );
 		}
 	}
@@ -825,10 +853,10 @@ void pianoRoll::shiftPos( int amount ) //shift notes pos by amount
 
 
 
-bool pianoRoll::isSelection( void ) const // are any notes selected?
+bool pianoRoll::isSelection() const // are any notes selected?
 {
-	const noteVector & notes = m_pattern->notes();
-	for( noteVector::const_iterator it = notes.begin(); it != notes.end();
+	const NoteVector & notes = m_pattern->notes();
+	for( NoteVector::ConstIterator it = notes.begin(); it != notes.end();
 									++it )
 	{
 		if( ( *it )->selected() )
@@ -842,12 +870,12 @@ bool pianoRoll::isSelection( void ) const // are any notes selected?
 
 
 
-int pianoRoll::selectionCount( void ) const // how many notes are selected?
+int pianoRoll::selectionCount() const // how many notes are selected?
 {
 	int sum = 0;
 	
-	const noteVector & notes = m_pattern->notes();
-	for( noteVector::const_iterator it = notes.begin(); it != notes.end();
+	const NoteVector & notes = m_pattern->notes();
+	for( NoteVector::ConstIterator it = notes.begin(); it != notes.end();
 									++it )
 	{
 		if( ( *it )->selected() )
@@ -865,14 +893,13 @@ void pianoRoll::keyPressEvent( QKeyEvent * _ke )
 {
 	if( validPattern() && _ke->modifiers() == Qt::NoModifier )
 	{
-		int key_num = pianoView::getKeyFromScancode(
-						_ke->nativeScanCode() ) +
-				( DefaultOctave - 1 ) * KeysPerOctave;
+		const int key_num = PianoView::getKeyFromKeyEvent( _ke ) +
+					( DefaultOctave - 1 ) * KeysPerOctave;
 
 		if( _ke->isAutoRepeat() == false && key_num > -1 )
 		{
-			m_pattern->getInstrumentTrack()->
-					getPiano()->handleKeyPress( key_num );
+			m_pattern->instrumentTrack()->
+				getPiano()->handleKeyPress( key_num );
 		}
 	}
 
@@ -1172,14 +1199,13 @@ void pianoRoll::keyReleaseEvent( QKeyEvent * _ke )
 {
 	if( validPattern() && _ke->modifiers() == Qt::NoModifier )
 	{
-		int key_num = pianoView::getKeyFromScancode(
-						_ke->nativeScanCode() ) +
-				( DefaultOctave - 1 ) * KeysPerOctave;
+		const int key_num = PianoView::getKeyFromKeyEvent( _ke ) +
+					( DefaultOctave - 1 ) * KeysPerOctave;
 
 		if( _ke->isAutoRepeat() == false && key_num > -1 )
 		{
-			m_pattern->getInstrumentTrack()->
-					getPiano()->handleKeyRelease( key_num );
+			m_pattern->instrumentTrack()->
+				getPiano()->handleKeyRelease( key_num );
 		}
 	}
 	switch( _ke->key() )
@@ -1266,7 +1292,7 @@ void pianoRoll::mousePressEvent( QMouseEvent * _me )
 		return;
 	}
 
-	if( m_editMode == ModeOpen && noteUnderMouse() )
+	if( m_editMode == ModeEditDetuning && noteUnderMouse() )
 	{
 		noteUnderMouse()->editDetuningPattern();
 		return;
@@ -1318,10 +1344,10 @@ void pianoRoll::mousePressEvent( QMouseEvent * _me )
 
 
 			// get note-vector of current pattern
-			const noteVector & notes = m_pattern->notes();
+			const NoteVector & notes = m_pattern->notes();
 
 			// will be our iterator in the following loop
-			noteVector::const_iterator it = notes.begin();
+			NoteVector::ConstIterator it = notes.begin();
 
 			// loop through whole note-vector...
 			while( it != notes.end() )
@@ -1459,6 +1485,10 @@ void pianoRoll::mousePressEvent( QMouseEvent * _me )
 				{
 					clearSelectedNotes();
 					m_currentNote->setSelected( true );
+					m_moveBoundaryLeft = m_currentNote->pos().getTicks();
+					m_moveBoundaryRight = m_currentNote->pos() + m_currentNote->length();
+					m_moveBoundaryBottom = m_currentNote->key();
+					m_moveBoundaryTop = m_currentNote->key();	
 				}
 
 				
@@ -1575,7 +1605,7 @@ void pianoRoll::mousePressEvent( QMouseEvent * _me )
 			if( ! m_recording && ! engine::getSong()->isPlaying() )
 			{
 				int v = ( (float) x ) / ( (float) WHITE_KEY_WIDTH ) * 127;
-				m_pattern->getInstrumentTrack()->processInEvent(
+				m_pattern->instrumentTrack()->processInEvent(
 							midiEvent( MidiNoteOn, 0, key_num, v ),
 							midiTime() );
 			}
@@ -1630,7 +1660,7 @@ void pianoRoll::testPlayNote( note * n )
 					! engine::getSong()->isPlaying() )
 	{
 		n->setIsPlaying( true );
-		m_pattern->getInstrumentTrack()->processInEvent(
+		m_pattern->instrumentTrack()->processInEvent(
 			midiEvent( MidiNoteOn, 0, n->key(), 
 				  n->getVolume() * 127 / 100 ), midiTime() );
 		
@@ -1638,10 +1668,7 @@ void pianoRoll::testPlayNote( note * n )
 				panningToMidi( n->getPanning() ) );
 		
 		evt.m_metaEvent = MidiNotePanning;
-		m_pattern->getInstrumentTrack()->processInEvent(
-							evt, midiTime() );		
-		m_pattern->getInstrumentTrack()->processInEvent( evt,
-								midiTime() );
+		m_pattern->instrumentTrack()->processInEvent( evt, midiTime() );
 	}
 }
 
@@ -1650,8 +1677,8 @@ void pianoRoll::testPlayNote( note * n )
 
 void pianoRoll::pauseTestNotes( bool _pause )
 {
-	const noteVector & notes = m_pattern->notes();
-	noteVector::const_iterator it = notes.begin();
+	const NoteVector & notes = m_pattern->notes();
+	NoteVector::ConstIterator it = notes.begin();
 	while( it != notes.end() )
 	{
 		if( ( *it )->isPlaying() )
@@ -1659,7 +1686,7 @@ void pianoRoll::pauseTestNotes( bool _pause )
 			if( _pause )
 			{
 				// stop note
-				m_pattern->getInstrumentTrack()->
+				m_pattern->instrumentTrack()->
 					processInEvent(
 						midiEvent( MidiNoteOff, 0, 
 							  ( *it )->key(), 0 ),
@@ -1683,7 +1710,7 @@ void pianoRoll::pauseTestNotes( bool _pause )
 void pianoRoll::testPlayKey( int _key, int _vol, int _pan )
 {
 	// turn off old key
-	m_pattern->getInstrumentTrack()->processInEvent(
+	m_pattern->instrumentTrack()->processInEvent(
 				midiEvent( MidiNoteOff, 0, m_lastKey, 0 ),
 								midiTime() );
 	
@@ -1691,7 +1718,7 @@ void pianoRoll::testPlayKey( int _key, int _vol, int _pan )
 	m_lastKey = _key;
 	
 	// play new key
-	m_pattern->getInstrumentTrack()->processInEvent(
+	m_pattern->instrumentTrack()->processInEvent(
 				midiEvent( MidiNoteOn, 0, _key, _vol ),
 								midiTime() );
 	
@@ -1732,11 +1759,9 @@ void pianoRoll::computeSelectedNotes(bool shift)
 	//int y_base = noteEditTop() - 1;
 	if( validPattern() == true )
 	{
-		const noteVector & notes = m_pattern->notes();
+		const NoteVector & notes = m_pattern->notes();
 
-		QPolygon volumeHandles;
-
-		for( noteVector::const_iterator it = notes.begin();
+		for( NoteVector::ConstIterator it = notes.begin();
 						it != notes.end(); ++it )
 		{
 			// make a new selection unless they're holding shift
@@ -1828,14 +1853,14 @@ void pianoRoll::mouseReleaseEvent( QMouseEvent * _me )
 	if( validPattern() == true )
 	{
 		// turn off all notes that are playing
-		const noteVector & notes = m_pattern->notes();
+		const NoteVector & notes = m_pattern->notes();
 
-		noteVector::const_iterator it = notes.begin();
+		NoteVector::ConstIterator it = notes.begin();
 		while( it != notes.end() )
 		{
 			if( ( *it )->isPlaying() )
 			{
-				m_pattern->getInstrumentTrack()->
+				m_pattern->instrumentTrack()->
 					processInEvent(
 						midiEvent( MidiNoteOff, 0,
 							( *it )->key(), 0 ), 
@@ -1847,7 +1872,7 @@ void pianoRoll::mouseReleaseEvent( QMouseEvent * _me )
 		}
 		
 		// stop playing keys that we let go of
-		m_pattern->getInstrumentTrack()->processInEvent(
+		m_pattern->instrumentTrack()->processInEvent(
 				midiEvent( MidiNoteOff, 0, m_lastKey, 0 ),
 								midiTime() );
 				
@@ -1961,15 +1986,15 @@ void pianoRoll::mouseMoveEvent( QMouseEvent * _me )
 					midiTime::ticksPerTact() / m_ppt + m_currentPosition;
 
 			// get note-vector of current pattern
-			const noteVector & notes = m_pattern->notes();
+			const NoteVector & notes = m_pattern->notes();
 
 			// determine what volume/panning to set note to
-			volume vol = tLimit<int>( MinVolume +
+			volume_t vol = tLimit<int>( MinVolume +
 							( ( (float)noteEditBottom() ) - ( (float)_me->y() ) ) / 
 							( (float)( noteEditBottom() - noteEditTop() ) ) * 
 							( MaxVolume - MinVolume ),
 										MinVolume, MaxVolume );
-			panning pan = tLimit<int>( PanningLeft +
+			panning_t pan = tLimit<int>( PanningLeft +
 							( (float)( noteEditBottom() - _me->y() ) ) /
 							( (float)( noteEditBottom() - noteEditTop() ) ) * 
 							( (float)( PanningRight - PanningLeft ) ),
@@ -1988,7 +2013,7 @@ void pianoRoll::mouseMoveEvent( QMouseEvent * _me )
 			
 			// loop through vector
 			bool use_selection = isSelection();
-			noteVector::const_iterator it = notes.begin();
+			NoteVector::ConstIterator it = notes.begin();
 			while( it != notes.end() )
 			{
 				if( ( *it )->pos().getTicks() >= ticks_start 
@@ -2005,7 +2030,7 @@ void pianoRoll::mouseMoveEvent( QMouseEvent * _me )
 					if( m_noteEditMode == NoteEditVolume )
 					{
 						( *it )->setVolume( vol );
-						m_pattern->getInstrumentTrack()->processInEvent(
+						m_pattern->instrumentTrack()->processInEvent(
 							midiEvent( 
 							  MidiKeyPressure, 
 							  0, 
@@ -2019,7 +2044,7 @@ void pianoRoll::mouseMoveEvent( QMouseEvent * _me )
 						midiEvent evt( MidiMetaEvent, 0, 
 									  ( *it )->key(), panningToMidi( pan ) );
 						evt.m_metaEvent = MidiNotePanning;
-						m_pattern->getInstrumentTrack()->processInEvent(
+						m_pattern->instrumentTrack()->processInEvent(
 									evt, midiTime() );
 					}
 				}
@@ -2028,7 +2053,7 @@ void pianoRoll::mouseMoveEvent( QMouseEvent * _me )
 					if( ( *it )->isPlaying() )
 					{
 						// mouse not over this note, stop playing it.
-						m_pattern->getInstrumentTrack()->processInEvent(
+						m_pattern->instrumentTrack()->processInEvent(
 							midiEvent( MidiNoteOff, 0,
 							( *it )->key(), 0 ), midiTime() );
 						
@@ -2049,10 +2074,10 @@ void pianoRoll::mouseMoveEvent( QMouseEvent * _me )
 						m_ppt + m_currentPosition;
 
 			// get note-vector of current pattern
-			const noteVector & notes = m_pattern->notes();
+			const NoteVector & notes = m_pattern->notes();
 
 			// will be our iterator in the following loop
-			noteVector::const_iterator it = notes.begin();
+			NoteVector::ConstIterator it = notes.begin();
 
 			// loop through whole note-vector...
 			while( it != notes.end() )
@@ -2169,10 +2194,10 @@ void pianoRoll::mouseMoveEvent( QMouseEvent * _me )
 
 
 			// get note-vector of current pattern
-			const noteVector & notes = m_pattern->notes();
+			const NoteVector & notes = m_pattern->notes();
 
 			// will be our iterator in the following loop
-			noteVector::const_iterator it = notes.begin();
+			NoteVector::ConstIterator it = notes.begin();
 
 			// loop through whole note-vector...
 			while( it != notes.end() )
@@ -2349,10 +2374,10 @@ void pianoRoll::dragNotes( int x, int y, bool alt )
 	}
 	
 	// get note-vector of current pattern
-	const noteVector & notes = m_pattern->notes();
+	const NoteVector & notes = m_pattern->notes();
 
 	// will be our iterator in the following loop
-	noteVector::const_iterator it = notes.begin();
+	NoteVector::ConstIterator it = notes.begin();
 	while( it != notes.end() )
 	{
 		if( ( *it )->selected() )
@@ -2678,14 +2703,14 @@ void pianoRoll::paintEvent( QPaintEvent * _pe )
 				width() - WHITE_KEY_WIDTH,
 				height() - PR_TOP_MARGIN );
 
-		const noteVector & notes = m_pattern->notes();
+		const NoteVector & notes = m_pattern->notes();
 
 		const int visible_keys = ( keyAreaBottom()-keyAreaTop() ) /
 							KEY_LINE_HEIGHT + 2;
 	
 		QPolygon editHandles;
 
-		for( noteVector::const_iterator it = notes.begin();
+		for( NoteVector::ConstIterator it = notes.begin();
 						it != notes.end(); ++it )
 		{
 			Sint32 len_ticks = ( *it )->length();
@@ -2852,11 +2877,13 @@ void pianoRoll::paintEvent( QPaintEvent * _pe )
 			break;
 		case ModeErase: cursor = s_toolErase; break;
 		case ModeSelect: cursor = s_toolSelect; break;
-		//case ModeMove: cursor = s_toolMove; break;
-		case ModeOpen: cursor = s_toolOpen; break;
+		case ModeEditDetuning: cursor = s_toolOpen; break;
 	}
-	p.drawPixmap( mapFromGlobal( QCursor::pos() ) + QPoint( 8, 8 ),
+	if( cursor != NULL )
+	{
+		p.drawPixmap( mapFromGlobal( QCursor::pos() ) + QPoint( 8, 8 ),
 								*cursor );
+	}
 }
 
 
@@ -2959,7 +2986,20 @@ int pianoRoll::getKey( int _y ) const
 
 
 
-void pianoRoll::play( void )
+song::PlayModes pianoRoll::desiredPlayModeForAccompany() const
+{
+	if( m_pattern->getTrack()->getTrackContainer() ==
+					engine::getBBTrackContainer() )
+	{
+		return song::Mode_PlayBB;
+	}
+	return song::Mode_PlaySong;
+}
+
+
+
+
+void pianoRoll::play()
 {
 	if( validPattern() == false )
 	{
@@ -2996,7 +3036,7 @@ void pianoRoll::play( void )
 
 
 
-void pianoRoll::record( void )
+void pianoRoll::record()
 {
 	if( engine::getSong()->isPlaying() )
 	{
@@ -3015,7 +3055,7 @@ void pianoRoll::record( void )
 
 
 
-void pianoRoll::recordAccompany( void )
+void pianoRoll::recordAccompany()
 {
 	if( engine::getSong()->isPlaying() )
 	{
@@ -3027,7 +3067,7 @@ void pianoRoll::recordAccompany( void )
 	}
 
 	m_recording = true;
-	
+
 	if( m_pattern->getTrack()->getTrackContainer() == engine::getSong() )
 	{
 		engine::getSong()->play();
@@ -3042,7 +3082,7 @@ void pianoRoll::recordAccompany( void )
 
 
 
-void pianoRoll::stop( void )
+void pianoRoll::stop()
 {
 	engine::getSong()->stop();
 	m_playButton->setIcon( embed::getIconPixmap( "play" ) );
@@ -3054,17 +3094,57 @@ void pianoRoll::stop( void )
 
 
 
-void pianoRoll::recordNote( const note & _n )
+void pianoRoll::startRecordNote( const note & _n )
 {
-	if( m_recording == true && validPattern() == true )
+	if( m_recording == true && validPattern() == true &&
+		engine::getSong()->isPlaying() &&
+			( engine::getSong()->playMode() ==
+					desiredPlayModeForAccompany() ||
+				engine::getSong()->playMode() ==
+					song::Mode_PlayPattern ) )
 	{
-		note n( _n.length(), engine::getSong()->getPlayPos(
-				engine::getSong()->playMode() ) - _n.length(),
+		midiTime sub;
+		if( engine::getSong()->playMode() == song::Mode_PlaySong )
+		{
+			sub = m_pattern->startPosition();
+		}
+		note n( 1, engine::getSong()->getPlayPos(
+					engine::getSong()->playMode() ) - sub,
 				_n.key(), _n.getVolume(), _n.getPanning() );
-		n.quantizeLength( quantization() );
-		m_pattern->addNote( n );
-		update();
-		engine::getSong()->setModified();
+		if( n.pos() >= 0 )
+		{
+			m_recordingNotes << n;
+		}
+	}
+}
+
+
+
+
+void pianoRoll::finishRecordNote( const note & _n )
+{
+	if( m_recording == true && validPattern() == true &&
+		engine::getSong()->isPlaying() &&
+			( engine::getSong()->playMode() ==
+					desiredPlayModeForAccompany() ||
+				engine::getSong()->playMode() ==
+					song::Mode_PlayPattern ) )
+	{
+		for( QList<note>::Iterator it = m_recordingNotes.begin();
+					it != m_recordingNotes.end(); ++it )
+		{
+			if( it->key() == _n.key() )
+			{
+				note n( _n.length(), it->pos(),
+						it->key(), it->getVolume(),
+						it->getPanning() );
+				n.quantizeLength( quantization() );
+				m_pattern->addNote( n );
+				update();
+				m_recordingNotes.erase( it );
+				break;
+			}
+		}
 	}
 }
 
@@ -3092,7 +3172,7 @@ void pianoRoll::verScrolled( int _new_pos )
 
 
 
-void pianoRoll::drawButtonToggled( void )
+void pianoRoll::drawButtonToggled()
 {
 	m_editMode = ModeDraw;
 	update();
@@ -3101,7 +3181,7 @@ void pianoRoll::drawButtonToggled( void )
 
 
 
-void pianoRoll::eraseButtonToggled( void )
+void pianoRoll::eraseButtonToggled()
 {
 	m_editMode = ModeErase;
 	update();
@@ -3110,7 +3190,7 @@ void pianoRoll::eraseButtonToggled( void )
 
 
 
-void pianoRoll::selectButtonToggled( void )
+void pianoRoll::selectButtonToggled()
 {
 	m_editMode = ModeSelect;
 	update();
@@ -3118,27 +3198,27 @@ void pianoRoll::selectButtonToggled( void )
 
 
 
-void pianoRoll::detuneButtonToggled( void )
+void pianoRoll::detuneButtonToggled()
 {
-	m_editMode = ModeOpen;
+	m_editMode = ModeEditDetuning;
 	update();
 }
 
 
 
-void pianoRoll::selectAll( void )
+void pianoRoll::selectAll()
 {
 	if( validPattern() == false )
 	{
 		return;
 	}
 
-	const noteVector & notes = m_pattern->notes();
+	const NoteVector & notes = m_pattern->notes();
 
 	// if first_time = true, we HAVE to set the vars for select
 	bool first_time = true;
 
-	for( noteVector::const_iterator it = notes.begin(); it != notes.end();
+	for( NoteVector::ConstIterator it = notes.begin(); it != notes.end();
 									++it )
 	{
 		Uint32 len_ticks = ( *it )->length();
@@ -3185,16 +3265,16 @@ void pianoRoll::selectAll( void )
 
 
 // returns vector with pointers to all selected notes
-void pianoRoll::getSelectedNotes( noteVector & _selected_notes )
+void pianoRoll::getSelectedNotes( NoteVector & _selected_notes )
 {
 	if( validPattern() == false )
 	{
 		return;
 	}
 
-	const noteVector & notes = m_pattern->notes();
+	const NoteVector & notes = m_pattern->notes();
 
-	for( noteVector::const_iterator it = notes.begin(); it != notes.end();
+	for( NoteVector::ConstIterator it = notes.begin(); it != notes.end();
 									++it )
 	{
 		if( ( *it )->selected() )
@@ -3207,14 +3287,14 @@ void pianoRoll::getSelectedNotes( noteVector & _selected_notes )
 
 
 
-void pianoRoll::copy_to_clipboard( const noteVector & _notes ) const
+void pianoRoll::copy_to_clipboard( const NoteVector & _notes ) const
 {
 	multimediaProject mmp( multimediaProject::ClipboardData );
 	QDomElement note_list = mmp.createElement( "note-list" );
 	mmp.content().appendChild( note_list );
 
 	midiTime start_pos( _notes.front()->pos().getTact(), 0 );
-	for( noteVector::const_iterator it = _notes.begin(); it != _notes.end();
+	for( NoteVector::ConstIterator it = _notes.begin(); it != _notes.end();
 									++it )
 	{
 		note clip_note( **it );
@@ -3223,7 +3303,7 @@ void pianoRoll::copy_to_clipboard( const noteVector & _notes ) const
 	}
 
 	QMimeData * clip_content = new QMimeData;
-	clip_content->setData( clipboard::mimeType(), mmp.toString().toUtf8() );
+	clip_content->setData( Clipboard::mimeType(), mmp.toString().toUtf8() );
 	QApplication::clipboard()->setMimeData( clip_content,
 							QClipboard::Clipboard );
 }
@@ -3231,9 +3311,9 @@ void pianoRoll::copy_to_clipboard( const noteVector & _notes ) const
 
 
 
-void pianoRoll::copySelectedNotes( void )
+void pianoRoll::copySelectedNotes()
 {
-	noteVector selected_notes;
+	NoteVector selected_notes;
 	getSelectedNotes( selected_notes );
 
 	if( selected_notes.empty() == false )
@@ -3245,14 +3325,14 @@ void pianoRoll::copySelectedNotes( void )
 
 
 
-void pianoRoll::cutSelectedNotes( void )
+void pianoRoll::cutSelectedNotes()
 {
 	if( validPattern() == false )
 	{
 		return;
 	}
 
-	noteVector selected_notes;
+	NoteVector selected_notes;
 	getSelectedNotes( selected_notes );
 
 	if( selected_notes.empty() == false )
@@ -3261,7 +3341,7 @@ void pianoRoll::cutSelectedNotes( void )
 
 		engine::getSong()->setModified();
 
-		for( noteVector::iterator it = selected_notes.begin();
+		for( NoteVector::Iterator it = selected_notes.begin();
 					it != selected_notes.end(); ++it )
 		{
 			// note (the memory of it) is also deleted by
@@ -3277,7 +3357,7 @@ void pianoRoll::cutSelectedNotes( void )
 
 
 
-void pianoRoll::pasteNotes( void )
+void pianoRoll::pasteNotes()
 {
 	if( validPattern() == false )
 	{
@@ -3286,11 +3366,11 @@ void pianoRoll::pasteNotes( void )
 
 	QString value = QApplication::clipboard()
 				->mimeData( QClipboard::Clipboard )
-						->data( clipboard::mimeType() );
+						->data( Clipboard::mimeType() );
 
 	if( !value.isEmpty() )
 	{
-		multimediaProject mmp( value, false );
+		multimediaProject mmp( value.toUtf8() );
 
 		QDomNodeList list = mmp.elementsByTagName(
 							note::classNodeName() );
@@ -3315,6 +3395,8 @@ void pianoRoll::pasteNotes( void )
 		// we only have to do the following lines if we pasted at
 		// least one note...
 		engine::getSong()->setModified();
+		m_ctrlMode = ModeDraw;
+		m_drawButton->setChecked( true );
 		update();
 		engine::getSongEditor()->update();
 	}
@@ -3323,7 +3405,7 @@ void pianoRoll::pasteNotes( void )
 
 
 
-void pianoRoll::deleteSelectedNotes( void )
+void pianoRoll::deleteSelectedNotes()
 {
 	if( validPattern() == false )
 	{
@@ -3334,10 +3416,10 @@ void pianoRoll::deleteSelectedNotes( void )
 	
 	
 	// get note-vector of current pattern
-	const noteVector & notes = m_pattern->notes();
+	const NoteVector & notes = m_pattern->notes();
 
 	// will be our iterator in the following loop
-	noteVector::const_iterator it = notes.begin();
+	NoteVector::ConstIterator it = notes.begin();
 	while( it != notes.end() )
 	{
 		if( ( *it )->selected() )
@@ -3367,6 +3449,27 @@ void pianoRoll::deleteSelectedNotes( void )
 
 
 
+void pianoRoll::autoScroll( const midiTime & _t )
+{
+	const int w = width() - WHITE_KEY_WIDTH;
+	if( _t > m_currentPosition + w * midiTime::ticksPerTact() / m_ppt )
+	{
+		m_leftRightScroll->setValue( _t.getTact() *
+					midiTime::ticksPerTact() );
+	}
+	else if( _t < m_currentPosition )
+	{
+		midiTime t = qMax( _t - w * midiTime::ticksPerTact() *
+					midiTime::ticksPerTact() / m_ppt, 0 );
+		m_leftRightScroll->setValue( t.getTact() *
+						midiTime::ticksPerTact() );
+	}
+	m_scrollBack = false;
+}
+
+
+
+
 void pianoRoll::updatePosition( const midiTime & _t )
 {
 	if( ( engine::getSong()->isPlaying() &&
@@ -3375,28 +3478,37 @@ void pianoRoll::updatePosition( const midiTime & _t )
 		m_timeLine->autoScroll() == timeLine::AutoScrollEnabled ) ||
 							m_scrollBack == true )
 	{
-		const int w = width() - WHITE_KEY_WIDTH;
-		if( _t > m_currentPosition + w * midiTime::ticksPerTact() /
-									m_ppt )
-		{
-			m_leftRightScroll->setValue( _t.getTact() *
-						midiTime::ticksPerTact() );
-		}
-		else if( _t < m_currentPosition )
-		{
-			midiTime t = qMax( _t - w * midiTime::ticksPerTact() *
-					midiTime::ticksPerTact() / m_ppt, 0 );
-			m_leftRightScroll->setValue( t.getTact() *
-						midiTime::ticksPerTact() );
-		}
-		m_scrollBack = false;
+		autoScroll( _t );
 	}
 }
 
 
 
 
-void pianoRoll::zoomingChanged( void )
+void pianoRoll::updatePositionAccompany( const midiTime & _t )
+{
+	song * s = engine::getSong();
+
+	if( m_recording && validPattern() &&
+					s->playMode() != song::Mode_PlayPattern )
+	{
+		midiTime pos = _t;
+		if( s->playMode() != song::Mode_PlayBB )
+		{
+			pos -= m_pattern->startPosition();
+		}
+		if( (int) pos > 0 )
+		{
+			s->getPlayPos( song::Mode_PlayPattern ).setTicks( pos );
+			autoScroll( pos );
+		}
+	}
+}
+
+
+
+
+void pianoRoll::zoomingChanged()
 {
 	const QString & zfac = m_zoomingModel.currentText();
 	m_ppt = zfac.left( zfac.length() - 1 ).toInt() * DEFAULT_PR_PPT / 100;
@@ -3411,7 +3523,7 @@ void pianoRoll::zoomingChanged( void )
 
 
 
-void pianoRoll::quantizeChanged( void )
+void pianoRoll::quantizeChanged()
 {
 	if( m_quantizeModel.value() == 0 && 
 			m_noteLenModel.value() == 0 ) 
@@ -3424,7 +3536,7 @@ void pianoRoll::quantizeChanged( void )
 }
 
 
-int pianoRoll::quantization( void ) const
+int pianoRoll::quantization() const
 {
 	if( m_quantizeModel.value() == 0 )
 	{
@@ -3438,7 +3550,7 @@ int pianoRoll::quantization( void ) const
 
 
 
-midiTime pianoRoll::newNoteLen( void ) const
+midiTime pianoRoll::newNoteLen() const
 {
 	if( m_noteLenModel.value() == 0 )
 	{
@@ -3452,35 +3564,26 @@ midiTime pianoRoll::newNoteLen( void ) const
 
 
 
-bool pianoRoll::mouseOverNote( void )
+bool pianoRoll::mouseOverNote()
 {
-	return validPattern() &&
-			noteIteratorUnderMouse() != m_pattern->notes().end();
+	return validPattern() && noteUnderMouse() != NULL;
 }
 
 
 
 
-note * pianoRoll::noteUnderMouse( void )
-{
-	return *noteIteratorUnderMouse();
-}
-
-
-
-
-noteVector::const_iterator pianoRoll::noteIteratorUnderMouse( void )
+note * pianoRoll::noteUnderMouse()
 {
 	QPoint pos = mapFromGlobal( QCursor::pos() );
 
 	// get note-vector of current pattern
-	const noteVector & notes = m_pattern->notes();
+	const NoteVector & notes = m_pattern->notes();
 
 	if( pos.x() <= WHITE_KEY_WIDTH || pos.x() > width() - SCROLLBAR_SIZE
 		|| pos.y() < PR_TOP_MARGIN
 		|| pos.y() > keyAreaBottom() )
 	{
-		return notes.end();
+		return NULL;
 	}
 
 	int key_num = getKey( pos.y() );
@@ -3488,7 +3591,7 @@ noteVector::const_iterator pianoRoll::noteIteratorUnderMouse( void )
 			midiTime::ticksPerTact() / m_ppt + m_currentPosition;
 
 	// will be our iterator in the following loop
-	noteVector::const_iterator it = notes.begin();
+	NoteVector::ConstIterator it = notes.begin();
 
 	// loop through whole note-vector...
 	while( it != notes.end() )
@@ -3504,11 +3607,12 @@ noteVector::const_iterator pianoRoll::noteIteratorUnderMouse( void )
 		++it;
 	}
 
-	return it;
+	return *it;
 }
 
 
 
+
 #include "moc_piano_roll.cxx"
 
 
