@@ -1,10 +1,8 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * song_editor.cpp - basic window for song-editing
  *
- * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
- * 
+ * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +22,6 @@
  *
  */
 
-
 #include <QtGui/QAction>
 #include <QtGui/QButtonGroup>
 #include <QtGui/QKeyEvent>
@@ -42,15 +39,16 @@
 #include "cpuload_widget.h"
 #include "embed.h"
 #include "lcd_spinbox.h"
-#include "main_window.h"
-#include "meter_dialog.h"
+#include "MainWindow.h"
+#include "MeterDialog.h"
 #include "mmp.h"
 #include "text_float.h"
 #include "timeline.h"
 #include "tool_button.h"
 #include "tooltip.h"
 #include "visualization_widget.h"
-#include "audio_device.h"
+#include "AudioDevice.h"
+#include "piano_roll.h"
 
 
 
@@ -76,7 +74,7 @@ void positionLine::paintEvent( QPaintEvent * _pe )
 songEditor::songEditor( song * _song, songEditor * & _engine_ptr ) :
 	trackContainerView( _song ),
 	m_s( _song ),
-	m_scrollBack( FALSE )
+	m_scrollBack( false )
 {
 	_engine_ptr = this;
 
@@ -102,9 +100,9 @@ songEditor::songEditor( song * _song, songEditor * & _engine_ptr ) :
 
 
 	// add some essential widgets to global tool-bar 
-	QWidget * tb = engine::getMainWindow()->toolBar();
+	QWidget * tb = engine::mainWindow()->toolBar();
 
-	engine::getMainWindow()->addSpacingToToolBar( 10 );
+	engine::mainWindow()->addSpacingToToolBar( 10 );
 
 	m_tempoSpinBox = new lcdSpinBox( 3, tb, tr( "Tempo" ) );
 	m_tempoSpinBox->setModel( &m_s->m_tempoModel );
@@ -119,10 +117,9 @@ songEditor::songEditor( song * _song, songEditor * & _engine_ptr ) :
 			"should be played within a minute (or how many measures "
 			"should be played within four minutes)." ) );
 
-	int col = engine::getMainWindow()->addWidgetToToolBar( m_tempoSpinBox,
-									0 );
-
+	engine::mainWindow()->addWidgetToToolBar( m_tempoSpinBox, 0 );
 
+#if 0
 	toolButton * hq_btn = new toolButton( embed::getIconPixmap( "hq_mode" ),
 						tr( "High quality mode" ),
 						NULL, NULL, tb );
@@ -130,17 +127,17 @@ songEditor::songEditor( song * _song, songEditor * & _engine_ptr ) :
 	connect( hq_btn, SIGNAL( toggled( bool ) ),
 			this, SLOT( setHighQuality( bool ) ) );
 	hq_btn->setFixedWidth( 42 );
-	engine::getMainWindow()->addWidgetToToolBar( hq_btn, 1, col );
+	engine::mainWindow()->addWidgetToToolBar( hq_btn, 1, col );
+#endif
+
+	engine::mainWindow()->addSpacingToToolBar( 10 );
 
 
-	engine::getMainWindow()->addSpacingToToolBar( 10 );
-
-
-	m_timeSigDisplay = new meterDialog( this, TRUE );
+	m_timeSigDisplay = new MeterDialog( this, TRUE );
 	m_timeSigDisplay->setModel( &m_s->m_timeSigModel );
-	engine::getMainWindow()->addWidgetToToolBar( m_timeSigDisplay );
+	engine::mainWindow()->addWidgetToToolBar( m_timeSigDisplay );
 
-	engine::getMainWindow()->addSpacingToToolBar( 10 );
+	engine::mainWindow()->addSpacingToToolBar( 10 );
 	
 
 	QLabel * master_vol_lbl = new QLabel( tb );
@@ -169,11 +166,11 @@ songEditor::songEditor( song * _song, songEditor * & _engine_ptr ) :
 	m_mvsStatus->setTitle( tr( "Master volume" ) );
 	m_mvsStatus->setPixmap( embed::getIconPixmap( "master_volume" ) );
 
-	engine::getMainWindow()->addWidgetToToolBar( master_vol_lbl );
-	engine::getMainWindow()->addWidgetToToolBar( m_masterVolumeSlider );
+	engine::mainWindow()->addWidgetToToolBar( master_vol_lbl );
+	engine::mainWindow()->addWidgetToToolBar( m_masterVolumeSlider );
 
 
-	engine::getMainWindow()->addSpacingToToolBar( 10 );
+	engine::mainWindow()->addSpacingToToolBar( 10 );
 
 
 	QLabel * master_pitch_lbl = new QLabel( tb );
@@ -201,10 +198,10 @@ songEditor::songEditor( song * _song, songEditor * & _engine_ptr ) :
 	m_mpsStatus->setTitle( tr( "Master pitch" ) );
 	m_mpsStatus->setPixmap( embed::getIconPixmap( "master_pitch" ) );
 
-	engine::getMainWindow()->addWidgetToToolBar( master_pitch_lbl );
-	engine::getMainWindow()->addWidgetToToolBar( m_masterPitchSlider );
+	engine::mainWindow()->addWidgetToToolBar( master_pitch_lbl );
+	engine::mainWindow()->addWidgetToToolBar( m_masterPitchSlider );
 
-	engine::getMainWindow()->addSpacingToToolBar( 10 );
+	engine::mainWindow()->addSpacingToToolBar( 10 );
 
 	// create widget for visualization- and cpu-load-widget
 	QWidget * vc_w = new QWidget( tb );
@@ -219,13 +216,13 @@ songEditor::songEditor( song * _song, songEditor * & _engine_ptr ) :
 	vcw_layout->addWidget( new cpuloadWidget( vc_w ) );
 	vcw_layout->addStretch();
 
-	engine::getMainWindow()->addWidgetToToolBar( vc_w );
+	engine::mainWindow()->addWidgetToToolBar( vc_w );
 
 
 	// create own toolbar
 	m_toolBar = new QWidget( this );
 	m_toolBar->setFixedHeight( 32 );
-	m_toolBar->setAutoFillBackground( TRUE );
+	m_toolBar->setAutoFillBackground( true );
 	QPalette pal;
 	pal.setBrush( m_toolBar->backgroundRole(), 
 				embed::getIconPixmap( "toolbar_bg" ) );
@@ -289,19 +286,19 @@ songEditor::songEditor( song * _song, songEditor * & _engine_ptr ) :
 								"edit_draw" ),
 							tr( "Draw mode" ),
 							NULL, NULL, m_toolBar );
-	m_drawModeButton->setCheckable( TRUE );
-	m_drawModeButton->setChecked( TRUE );
+	m_drawModeButton->setCheckable( true );
+	m_drawModeButton->setChecked( true );
 
 	m_editModeButton = new toolButton( embed::getIconPixmap(
 								"edit_select" ),
 					tr( "Edit mode (select and move)" ),
 							NULL, NULL, m_toolBar );
-	m_editModeButton->setCheckable( TRUE );
+	m_editModeButton->setCheckable( true );
 
 	QButtonGroup * tool_button_group = new QButtonGroup( this );
 	tool_button_group->addButton( m_drawModeButton );
 	tool_button_group->addButton( m_editModeButton );
-	tool_button_group->setExclusive( TRUE );
+	tool_button_group->setExclusive( true );
 
 #if 0
 #warning TODO
@@ -341,7 +338,7 @@ songEditor::songEditor( song * _song, songEditor * & _engine_ptr ) :
 	m_zoomingComboBox->model()->setInitValue(
 			m_zoomingComboBox->model()->findText( "100%" ) );
 	connect( m_zoomingComboBox->model(), SIGNAL( dataChanged() ),
-					this, SLOT( zoomingChanged( void ) ) );
+					this, SLOT( zoomingChanged() ) );
 
 
 	tb_layout->addSpacing( 5 );
@@ -373,10 +370,12 @@ songEditor::songEditor( song * _song, songEditor * & _engine_ptr ) :
 	static_cast<QVBoxLayout *>( layout() )->addWidget( m_leftRightScroll );
 	connect( m_leftRightScroll, SIGNAL( valueChanged( int ) ),
 					this, SLOT( scrolled( int ) ) );
+	connect( m_s, SIGNAL( lengthChanged( int ) ),
+			this, SLOT( updateScrollBar( int ) ) );
 
 
-	engine::getMainWindow()->workspace()->addSubWindow( this );
-	parentWidget()->setAttribute( Qt::WA_DeleteOnClose, FALSE );
+	engine::mainWindow()->workspace()->addSubWindow( this );
+	parentWidget()->setAttribute( Qt::WA_DeleteOnClose, false );
 	parentWidget()->resize( 600, 300 );
 	parentWidget()->move( 5, 5 );
 	parentWidget()->show();
@@ -411,9 +410,10 @@ void songEditor::scrolled( int _new_pos )
 
 
 
-void songEditor::play( void )
+void songEditor::play()
 {
 	m_s->play();
+	engine::getPianoRoll()->stopRecording();
 	if( m_s->playMode() == song::Mode_PlaySong )
 	{
 		m_playButton->setIcon( embed::getIconPixmap( "pause" ) );
@@ -427,7 +427,7 @@ void songEditor::play( void )
 
 
 
-void songEditor::record( void )
+void songEditor::record()
 {
 	m_s->record();
 }
@@ -435,7 +435,7 @@ void songEditor::record( void )
 
 
 
-void songEditor::recordAccompany( void )
+void songEditor::recordAccompany()
 {
 	m_s->playAndRecord();
 }
@@ -443,9 +443,10 @@ void songEditor::recordAccompany( void )
 
 
 
-void songEditor::stop( void )
+void songEditor::stop()
 {
 	m_s->stop();
+	engine::getPianoRoll()->stopRecording();
 	m_playButton->setIcon( embed::getIconPixmap( "play" ) );
 }
 
@@ -455,20 +456,20 @@ void songEditor::stop( void )
 void songEditor::keyPressEvent( QKeyEvent * _ke )
 {
 	if( /*_ke->modifiers() & Qt::ShiftModifier*/
-		engine::getMainWindow()->isShiftPressed() == TRUE &&
+		engine::mainWindow()->isShiftPressed() == TRUE &&
 						_ke->key() == Qt::Key_Insert )
 	{
 		m_s->insertBar();
 	}
 	else if(/* _ke->modifiers() & Qt::ShiftModifier &&*/
-			engine::getMainWindow()->isShiftPressed() == TRUE &&
+			engine::mainWindow()->isShiftPressed() == TRUE &&
 						_ke->key() == Qt::Key_Delete )
 	{
 		m_s->removeBar();
 	}
 	else if( _ke->key() == Qt::Key_Left )
 	{
-		tick t = m_s->currentTick() - midiTime::ticksPerTact();
+		tick_t t = m_s->currentTick() - midiTime::ticksPerTact();
 		if( t >= 0 )
 		{
 			m_s->setPlayPos( t, song::Mode_PlaySong );
@@ -476,7 +477,7 @@ void songEditor::keyPressEvent( QKeyEvent * _ke )
 	}
 	else if( _ke->key() == Qt::Key_Right )
 	{
-		tick t = m_s->currentTick() + midiTime::ticksPerTact();
+		tick_t t = m_s->currentTick() + midiTime::ticksPerTact();
 		if( t < MaxSongLength )
 		{
 			m_s->setPlayPos( t, song::Mode_PlaySong );
@@ -506,18 +507,9 @@ void songEditor::keyPressEvent( QKeyEvent * _ke )
 
 
 
-void songEditor::paintEvent( QPaintEvent * _pe )
-{
-	m_leftRightScroll->setMaximum( m_s->length() );
-	trackContainerView::paintEvent( _pe );
-}
-
-
-
-
 void songEditor::wheelEvent( QWheelEvent * _we )
 {
-	if( engine::getMainWindow()->isCtrlPressed() == TRUE )
+	if( engine::mainWindow()->isCtrlPressed() == TRUE )
 	{
 		if( _we->delta() > 0 )
 		{
@@ -541,7 +533,7 @@ void songEditor::wheelEvent( QWheelEvent * _we )
 		// and make sure, all TCO's are resized and relocated
 		realignTracks();
 	} 
-	else if( engine::getMainWindow()->isShiftPressed() == TRUE )
+	else if( engine::mainWindow()->isShiftPressed() == TRUE )
 	{
 		m_leftRightScroll->setValue( m_leftRightScroll->value() -
 							_we->delta() / 30 );
@@ -643,11 +635,19 @@ void songEditor::masterPitchReleased( void )
 
 
 
+void songEditor::updateScrollBar( int _len )
+{
+	m_leftRightScroll->setMaximum( _len );
+}
+
+
+
+
 void songEditor::updatePosition( const midiTime & _t )
 {
 	if( ( m_s->isPlaying() && m_s->m_playMode == song::Mode_PlaySong 
 		  && m_timeLine->autoScroll() == timeLine::AutoScrollEnabled) ||
-							m_scrollBack == TRUE )
+							m_scrollBack == true )
 	{
 		const int w = width() - DEFAULT_SETTINGS_WIDGET_WIDTH
 							- TRACK_OP_WIDTH;
@@ -664,7 +664,7 @@ void songEditor::updatePosition( const midiTime & _t )
 									0 );
 			m_leftRightScroll->setValue( t.getTact() );
 		}
-		m_scrollBack = FALSE;
+		m_scrollBack = false;
 	}
 
 	const int x = m_s->m_playPos[song::Mode_PlaySong].m_timeLine->
@@ -685,7 +685,7 @@ void songEditor::updatePosition( const midiTime & _t )
 
 
 
-void songEditor::zoomingChanged( void )
+void songEditor::zoomingChanged()
 {
 	const QString & zfac = m_zoomingComboBox->model()->currentText();
 	setPixelsPerTact( zfac.left( zfac.length() - 1 ).toInt() *
@@ -698,7 +698,7 @@ void songEditor::zoomingChanged( void )
 
 
 
-bool songEditor::allowRubberband( void ) const
+bool songEditor::allowRubberband() const
 {
 	return( m_editModeButton->isChecked() );
 }
@@ -709,4 +709,4 @@ bool songEditor::allowRubberband( void ) const
 #include "moc_song_editor.cxx"
 
 
-#endif
+/* vim: set tw=0 noexpandtab: */
