@@ -1,5 +1,3 @@
-#ifndef SINGLE_SOURCE_COMPILE
-
 /*
  * caption_menu.cpp - context menu with a caption
  *
@@ -34,7 +32,7 @@ captionMenu::captionMenu( const QString & _title, QWidget * _parent ) :
 	QMenu( _title, _parent )
 {
 	QAction * caption = addAction( _title );
-	caption->setEnabled( FALSE );
+	caption->setEnabled( false );
 }
 
 
@@ -50,4 +48,3 @@ captionMenu::~captionMenu()
 #include "moc_caption_menu.cxx"
 
 
-#endif
