@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2004-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * Copyright (c) 2005-2007 Danny McRae <khjklujn/at/yahoo.com>
- * 
+ *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or
@@ -23,7 +23,6 @@
  *
  */
 
-
 #include <QtXml/QDomElement>
 #include <QtCore/QTimer>
 #include <QtGui/QMenu>
@@ -34,10 +33,8 @@
 #include <QtGui/QPushButton>
 #include <QtAlgorithms>
 
-
-
 #include "pattern.h"
-#include "instrument_track.h"
+#include "InstrumentTrack.h"
 #include "templates.h"
 #include "gui_templates.h"
 #include "embed.h"
@@ -46,12 +43,12 @@
 #include "track_container.h"
 #include "rename_dialog.h"
 #include "sample_buffer.h"
-#include "audio_sample_recorder.h"
+#include "AudioSampleRecorder.h"
 #include "song.h"
 #include "tooltip.h"
 #include "bb_track_container.h"
 #include "string_pair_drag.h"
-#include "main_window.h"
+#include "MainWindow.h"
 
 
 QPixmap * patternView::s_stepBtnOn = NULL;
@@ -62,7 +59,7 @@ QPixmap * patternView::s_frozen = NULL;
 
 
 
-pattern::pattern( instrumentTrack * _instrument_track ) :
+pattern::pattern( InstrumentTrack * _instrument_track ) :
 	trackContentObject( _instrument_track ),
 	m_instrumentTrack( _instrument_track ),
 	m_patternType( BeatPattern ),
@@ -115,7 +112,7 @@ pattern::~pattern()
 
 
 
-void pattern::init( void )
+void pattern::init()
 {
 	connect( engine::getSong(), SIGNAL( timeSignatureChanged( int, int ) ),
 				this, SLOT( changeTimeSignature() ) );
@@ -130,7 +127,7 @@ void pattern::init( void )
 
 
 
-midiTime pattern::length( void ) const
+midiTime pattern::length() const
 {
 	if( m_patternType == BeatPattern )
 	{
@@ -155,7 +152,7 @@ midiTime pattern::length( void ) const
 
 
 
-midiTime pattern::beatPatternLength( void ) const
+midiTime pattern::beatPatternLength() const
 {
 	tick_t max_length = midiTime::ticksPerTact();
 
@@ -269,7 +266,7 @@ note * pattern::rearrangeNote( const note * _note_to_proc,
 
 
 
-void pattern::rearrangeAllNotes( void )
+void pattern::rearrangeAllNotes()
 {
 	// sort notes by start time	
 	qSort(m_notes.begin(), m_notes.end(), note::lessThan );
@@ -277,7 +274,7 @@ void pattern::rearrangeAllNotes( void )
 
 
 
-void pattern::clearNotes( void )
+void pattern::clearNotes()
 {
 	engine::getMixer()->lock();
 	for( NoteVector::Iterator it = m_notes.begin(); it != m_notes.end();
@@ -324,7 +321,7 @@ void pattern::setType( PatternTypes _new_pattern_type )
 
 
 
-void pattern::checkType( void )
+void pattern::checkType()
 {
 	NoteVector::Iterator it = m_notes.begin();
 	while( it != m_notes.end() )
@@ -430,7 +427,7 @@ void pattern::loadSettings( const QDomElement & _this )
 
 
 
-void pattern::clear( void )
+void pattern::clear()
 {
 	clearNotes();
 	ensureBeatNotes();
@@ -439,7 +436,7 @@ void pattern::clear( void )
 
 
 
-void pattern::freeze( void )
+void pattern::freeze()
 {
 	if( engine::getSong()->isPlaying() )
 	{
@@ -467,7 +464,7 @@ void pattern::freeze( void )
 
 
 
-void pattern::unfreeze( void )
+void pattern::unfreeze()
 {
 	if( m_frozenPattern != NULL )
 	{
@@ -480,7 +477,7 @@ void pattern::unfreeze( void )
 
 
 
-void pattern::abortFreeze( void )
+void pattern::abortFreeze()
 {
 	m_freezeAborted = true;
 }
@@ -534,7 +531,7 @@ trackContentObjectView * pattern::createView( trackView * _tv )
 
 
 
-void pattern::ensureBeatNotes( void )
+void pattern::ensureBeatNotes()
 {
 	// make sure, that all step-note exist
 	for( int i = 0; i < m_steps; ++i )
@@ -564,7 +561,7 @@ void pattern::ensureBeatNotes( void )
 
 
 
-void pattern::updateBBTrack( void )
+void pattern::updateBBTrack()
 {
 	if( getTrack()->getTrackContainer() == engine::getBBTrackContainer() )
 	{
@@ -575,7 +572,7 @@ void pattern::updateBBTrack( void )
 
 
 
-bool pattern::empty( void )
+bool pattern::empty()
 {
 	for( NoteVector::ConstIterator it = m_notes.begin();
 						it != m_notes.end(); ++it )
@@ -591,7 +588,7 @@ bool pattern::empty( void )
 
 
 
-void pattern::changeTimeSignature( void )
+void pattern::changeTimeSignature()
 {
 	midiTime last_pos = midiTime::ticksPerTact();
 	for( NoteVector::ConstIterator cit = m_notes.begin();
@@ -687,7 +684,7 @@ void patternFreezeStatusDialog::closeEvent( QCloseEvent * _ce )
 
 
 
-void patternFreezeStatusDialog::cancelBtnClicked( void )
+void patternFreezeStatusDialog::cancelBtnClicked()
 {
 	emit( aborted() );
 	done( -1 );
@@ -696,7 +693,7 @@ void patternFreezeStatusDialog::cancelBtnClicked( void )
 
 
 
-void patternFreezeStatusDialog::updateProgress( void )
+void patternFreezeStatusDialog::updateProgress()
 {
 	if( m_progress < 0 )
 	{
@@ -737,14 +734,14 @@ patternFreezeThread::~patternFreezeThread()
 
 
 
-void patternFreezeThread::run( void )
+void patternFreezeThread::run()
 {
 	// create and install audio-sample-recorder
 	bool b;
 	// we cannot create local copy, because at a later stage
 	// mixer::restoreAudioDevice(...) deletes old audio-dev and thus
-	// audioSampleRecorder would be destroyed two times...
-	audioSampleRecorder * freeze_recorder = new audioSampleRecorder(
+	// AudioSampleRecorder would be destroyed two times...
+	AudioSampleRecorder * freeze_recorder = new AudioSampleRecorder(
 							DEFAULT_CHANNELS, b,
 							engine::getMixer() );
 	engine::getMixer()->setAudioDevice( freeze_recorder );
@@ -869,7 +866,7 @@ patternView::~patternView()
 
 
 
-void patternView::update( void )
+void patternView::update()
 {
 	m_needsUpdate = true;
 	m_pat->changeLength( m_pat->length() );
@@ -879,7 +876,7 @@ void patternView::update( void )
 
 
 
-void patternView::openInPianoRoll( void )
+void patternView::openInPianoRoll()
 {
 	engine::getPianoRoll()->setCurrentPattern( m_pat );
 	engine::getPianoRoll()->parentWidget()->show();
@@ -889,7 +886,7 @@ void patternView::openInPianoRoll( void )
 
 
 
-void patternView::resetName( void )
+void patternView::resetName()
 {
 	m_pat->setName( m_pat->m_instrumentTrack->name() );
 }
@@ -897,7 +894,7 @@ void patternView::resetName( void )
 
 
 
-void patternView::changeName( void )
+void patternView::changeName()
 {
 	QString s = m_pat->name();
 	renameDialog rename_dlg( s );
@@ -1304,7 +1301,7 @@ void patternView::paintEvent( QPaintEvent * )
 		p.setPen( QColor( 32, 240, 32 ) );
 	}
 
-	if( m_pat->name() != m_pat->getInstrumentTrack()->name() )
+	if( m_pat->name() != m_pat->instrumentTrack()->name() )
 	{
 		p.drawText( 2, p.fontMetrics().height() - 1, m_pat->name() );
 	}
